<?php
/**
 * lauv functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package lauv
 */

if ( ! function_exists( 'lauv_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function lauv_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on lauv, use a find and replace
	 * to change 'lauv' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'lauv', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'navigation' => esc_html__( 'Primary navigation', 'lauv' ),
		'side-navigation' => esc_html__( 'Side navigation', 'lauv' ),
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// Add theme support for WooCommerce.
	add_theme_support( 'woocommerce' );

	if ( ! isset( $content_width ) ) $content_width = 900;
}
endif;
add_action( 'after_setup_theme', 'lauv_setup' ); 

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function lauv_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'lauv' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'lauv' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'lauv_widgets_init' );

/*
Remove default woocommerce css
*/
add_filter( 'woocommerce_enqueue_styles', '__return_false' );

/**
 * Add Google fonts.
 */
if(!class_exists('WPBakeryShortCode')) {
	function lauv_fonts_url() {
	    $font_url = add_query_arg( 'family', 'Roboto:100,100i,300,300i,400,400i,500,500i,700,700i,900,900i', "//fonts.googleapis.com/css" );
	    return $font_url;
	}
}

/**
 * Enqueue scripts and styles.
 */
function lauv_scripts() {
	wp_enqueue_style( 'lauv-style-default', get_stylesheet_uri() );

	if(!class_exists('WPBakeryShortCode')) {
		wp_enqueue_style( 'lauv-fonts', lauv_fonts_url(), array(), '1.0.0' );
	}

	if(function_exists('vc_icon_element_fonts_enqueue')) {
		vc_icon_element_fonts_enqueue( 'fontawesome' );
	} else {
		wp_enqueue_style( 'lauv-font-awesomesd', get_template_directory_uri() . '/css/font-awesome.min.css');
		wp_enqueue_style( 'lauv-iconsss', get_template_directory_uri() . '/css/iconfont.css');
	}

	wp_enqueue_style( 'lauv-frontend-grid', get_template_directory_uri() . '/css/frontend-grid.css');

	wp_enqueue_style( 'photoswipe', get_template_directory_uri() . '/css/photoswipe.css');

	wp_enqueue_style( 'photoswipe-default-skin', get_template_directory_uri() . '/css/default-skin.css');

	wp_enqueue_style( 'lauv-circle-animations', get_template_directory_uri() . '/css/circle_animations.css');

	wp_enqueue_style( 'lauv-style', get_template_directory_uri() . '/css/style.css');

	wp_enqueue_style( 'woocommerce-general', get_template_directory_uri() . '/css/woocommerce.css');

	wp_enqueue_style( 'woocommerce-layout', get_template_directory_uri() . '/css/woocommerce-layout.css');

	wp_add_inline_style( 'lauv-style', do_action('inline_css') );

	wp_enqueue_style( 'lauv-mobile', get_template_directory_uri() . '/css/mobile.css');

	wp_enqueue_script( 'lauv-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array('jquery'), '', true );

	wp_enqueue_script( 'lauv-load-posts', get_template_directory_uri() . '/js/load-posts.js', array('jquery'), '', true );

	wp_enqueue_script( 'imagesloaded' );

	wp_enqueue_script( 'isotope', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array('jquery'), '', true );

	wp_enqueue_script( 'photoswipe', get_template_directory_uri() . '/js/photoswipe.min.js', array('jquery'), '', true );

	wp_enqueue_script( 'photoswipe-ui-default', get_template_directory_uri() . '/js/photoswipe-ui-default.min.js', array('jquery'), '', true );

	wp_enqueue_script( 'lauv-script', get_template_directory_uri() . '/js/script.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'lauv_scripts', 100 );

function lauv_add_editor_styles() {
	add_editor_style( get_template_directory_uri() . '/css/style.css' );
}
add_action( 'current_screen', 'lauv_add_editor_styles' );

add_action( 'admin_enqueue_scripts', 'load_admin_styles', 1000 );
function load_admin_styles() {
	wp_enqueue_style( 'lauv-font-awesomesd', get_template_directory_uri() . '/css/font-awesome.min.css');
	wp_enqueue_style( 'lauv-backend', get_template_directory_uri() . '/css/admin.css', array(), '1.0', false );
	wp_enqueue_style( 'lauv-shortcode-icons', get_template_directory_uri() . '/css/shortcode-icons.css', array(), '1.0', false );
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Video Parser.
 */
require get_template_directory() . '/inc/video-parser.php';

/**
 * Load TGM file.
 */
require get_template_directory() . '/tgm/tgm.php';

/**
 * Load Breadcrumbs.
 */
require get_template_directory() . '/inc/breadcrumbs.php';

/**
 * Load ACF.
 */
require get_template_directory() . '/inc/acf.php';
define( 'ACF_LITE', true );

/**
 * Load Theme Settings.
 */
require get_template_directory() . '/theme-settings/config.php';

/**
 * Site pagination.
 */
function lauv_wp_corenavi($max_count = '') {
	global $wp_query;
	$pages = '';
	if(isset($max_count) && $max_count > 0) {
		$max = $max_count;
	} else {
		$max = $wp_query->max_num_pages;
	}

	if(get_query_var('paged') != 0) {
		$paged = get_query_var('paged');
	} else {
		$paged = get_query_var('page');
	}

	if (!$current = $paged) $current = 1;
	$a['base'] = str_replace(999999999, '%#%', get_pagenum_link(999999999));
	$a['total'] = $max;
	$a['current'] = $current;

	$a['mid_size'] = 5;
	$a['end_size'] = 1;
	$a['prev_text'] = '<';
	$a['next_text'] = '>';

	$html = "";
	if ($max > 1) $html .= '<div class="pagination col-xs-12">';
	$html .= paginate_links($a);
	if ($max > 1) $html .= '</div>';

	return $html;
}

add_action( 'admin_init', 'lauv_hide_editor' );

function lauv_hide_editor() {

        // Get the Post ID.
        if ( isset ( $_GET['post'] ) )
        $post_id = $_GET['post'];
        else if ( isset ( $_POST['post_ID'] ) )
        $post_id = $_POST['post_ID'];

    if( !isset ( $post_id ) || empty ( $post_id ) )
        return;

    // Get the name of the Page Template file.
    $template_file = get_post_meta($post_id, '_wp_page_template', true);

    if($template_file == 'page-coming-soon.php'){ // edit the template name
        remove_post_type_support('page', 'editor');
    }

}

add_filter('get_the_excerpt', 'shortcode_unautop');
add_filter('get_the_excerpt', 'do_shortcode');

add_action( 'vc_before_init', 'lauv_vc_before_init_actions' );
 
function lauv_vc_before_init_actions() {
    if( function_exists('vc_set_shortcodes_templates_dir') ){ 
        vc_set_shortcodes_templates_dir( get_template_directory() . '/vc-elements' );
    }
}

function lauv_load_custom_fonts($init) {
	global $lauv_theme;

	$array = '';

	if ( isset($lauv_theme) && !empty($lauv_theme) ) {
		if(isset($lauv_theme['body-font-face']['font-family']) && !empty($lauv_theme['body-font-face']['font-family'])) {
			$array .= $lauv_theme['body-font-face']['font-family'].'='.$lauv_theme['body-font-face']['font-family'].';';
		}
		if(isset($lauv_theme['additional-font-face']['font-family']) && !empty($lauv_theme['additional-font-face']['font-family'])) {
			$array .= $lauv_theme['additional-font-face']['font-family'].'='.$lauv_theme['additional-font-face']['font-family'].';';
		}
		if(isset($lauv_theme['additional-font-face2']['font-family']) && !empty($lauv_theme['additional-font-face2']['font-family'])) {
			$array .= $lauv_theme['additional-font-face2']['font-family'].'='.$lauv_theme['additional-font-face2']['font-family'].';';
		}
		if(isset($lauv_theme['additional-font-face3']['font-family']) && !empty($lauv_theme['additional-font-face3']['font-family'])) {
			$array .= $lauv_theme['additional-font-face3']['font-family'].'='.$lauv_theme['additional-font-face3']['font-family'].';';
		}
		if(isset($lauv_theme['additional-font-face4']['font-family']) && !empty($lauv_theme['additional-font-face4']['font-family'])) {
			$array .= $lauv_theme['additional-font-face4']['font-family'].'='.$lauv_theme['additional-font-face4']['font-family'].';';
		}
	}

    $font_formats = isset($init['font_formats']) ? $init['font_formats'] : 'Andale Mono=andale mono,times;Arial=arial,helvetica,sans-serif;Arial Black=arial black,avant garde;Book Antiqua=book antiqua,palatino;Comic Sans MS=comic sans ms,sans-serif;Courier New=courier new,courier;Georgia=georgia,palatino;Helvetica=helvetica;Impact=impact,chicago;Symbol=symbol;Tahoma=tahoma,arial,helvetica,sans-serif;Terminal=terminal,monaco;Times New Roman=times new roman,times;Trebuchet MS=trebuchet ms,geneva;Verdana=verdana,geneva;Webdings=webdings;Wingdings=wingdings,zapf dingbats';
	
	$init['fontsize_formats'] = "10px 11px 12px 13px 14px 15px 16px 17px 18px 19px 20px 21px 22px 23px 24px 25px 26px 27px 28px 29px 30px 32px 33px 34px 35px 36px 37px 38px 39px 40px";

	if(isset($array) && !empty($array)) {
		trim($array, ';');
		$custom_fonts = ';'.$array;

	    $init['font_formats'] = $font_formats . $custom_fonts;

	    return $init;
	} else {
		return false;
	}
}
add_filter('tiny_mce_before_init', 'lauv_load_custom_fonts');

function lauv_styles() {
	global $lauv_theme;

	$style = array();

	$style['site_mode'] = 'light';

	$style['header_style'] = 'logo_left';
	$style['header_color_mode'] = 'light';
	$style['header_color_mode_404'] = 'light';
	$style['header_color_mode_coming_soon'] = 'light';
	$style['header_container'] = 'container';
	$style['navigation_type'] = 'visible_menu';
	$style['css_classes'] = '';
	
	$style['working_time'] = '';
	$style['phone_number'] = '';

	$style['logo_content'] = get_bloginfo( 'name' );
	$style['logo_default_url'] = '';
	$style['logo_light_url'] = '';
	$style['logo_dark_url']  = '';
	$style['logo_dark_url_scheme2']  = '';

	$style['google_maps_api_key'] = '';

	$style['cart'] = 'yes';
	$style['header_social_buttons'] = 'yes';
	$style['header_space'] = 'yes';
	$style['footer'] = 'show';
	$style['footer_logo'] = 'show';
	$style['footer_social_buttons'] = 'show';
	$style['copyright_text']  = '';
	$style['contacts_text']  = '';
	$style['address_text']  = '';
	$style['sidebar_desc']  = '';
	$style['sidebar_contacts']  = '';
	$style['sidebar_copyright_text']  = '';

	$style['social_target'] = '_self';
	$style['social_buttons_content'] = '';

	$style['404_bg'] = '';
	$style['404_page_text'] = __('<span>404 error</span><br>This page doesn`t exist', 'lauv');

	$style['coming_soon_heading'] = esc_html__('coming soon', 'lauv');
	$style['coming_soon_subscribe_desc'] = esc_html__('subscribe for more', 'lauv');
	$style['coming_soon_bg'] = '';
	$style['coming_soon_subscribe_code'] = '';

	$style['project_style'] = 'slider';
	$style['project_image'] = 'full';
	$style['project_client_name'] = '';
	$style['project_year'] = '';
	$style['single_post_image_show'] = 'yes';

	$style['blog_feature_image'] = 'show';
	$style['blog_date'] = 'show';
	$style['blog_like'] = 'show';
	$style['blog_comment_count'] = 'show';

	$style['preloader_show'] = '1';
	$style['preloader_type'] = '1';
	$style['preloader_label1'] = '';
	$style['preloader_label2'] = '';
	$style['preloader_img'] = '';
	$style['download_link'] = 'yes';
	$style['project_details'] = 'yes';

	$style['right_click_disable'] = '0';
	$style['right_click_disable_message'] = __('<p style="text-align: center"><strong><span style="font-size: 18px">Content is protected. Right-click function is disabled.</span></strong></p>', 'lauv');

	$style['protected_message'] = esc_html__( 'This content is password protected. To view it please enter your password below:', 'lauv' );

	if ( isset($lauv_theme) && !empty($lauv_theme) ) {
		if(isset($lauv_theme['single_post_image_show']) && $lauv_theme['single_post_image_show'] == '1') {
			$style['single_post_image_show'] = 'yes';
		} else {
			$style['single_post_image_show'] = 'no';
		}

		if(isset($lauv_theme['show_social_buttons_header']) && $lauv_theme['show_social_buttons_header'] == '1') {
			$style['header_social_buttons'] = 'yes';
		} else {
			$style['header_social_buttons'] = 'no';
		}

		if(isset($lauv_theme['show_cart']) && $lauv_theme['show_cart'] == '1') {
			$style['cart'] = 'yes';
		} else {
			$style['cart'] = 'no';
		}

		if(isset($lauv_theme['header_style']) && !empty($lauv_theme['header_style'])) {
			$style['header_style'] = $lauv_theme['header_style'];
		}

		if(isset($lauv_theme['site_mode']) && !empty($lauv_theme['site_mode'])) {
			$style['site_mode'] = $lauv_theme['site_mode'];
		}

		if(isset($lauv_theme['default_logo']['background-image']) && $lauv_theme['default_logo']['background-image']) { 
			$style['logo_default_url'] = $lauv_theme['default_logo']['background-image'];
		}
		if(isset($lauv_theme['dark_logo']['background-image']) && $lauv_theme['dark_logo']['background-image']) {
			$style['logo_dark_url'] = $lauv_theme['dark_logo']['background-image'];
		}
 		if(isset($lauv_theme['light_logo']['background-image']) && $lauv_theme['light_logo']['background-image']) {
			$style['logo_light_url'] = $lauv_theme['light_logo']['background-image'];
		}

		if(!empty($style['logo_light_url']) && !empty($style['logo_dark_url'])) {
			$style['logo_content'] = '<img class="light" src="'.esc_url($style['logo_light_url']).'" alt="'.get_bloginfo( 'name' ).'"><img class="dark" src="'.esc_url($style['logo_dark_url']).'" alt="'.get_bloginfo( 'name' ).'">';
		} elseif(!empty($style['logo_light_url']) || !empty($style['logo_dark_url'])) {
			if(!empty($style['logo_light_url'])) {
				$style['logo_content'] = '<img src="'.esc_url($style['logo_light_url']).'" alt="'.get_bloginfo( 'name' ).'">';
			}
			if(!empty($style['logo_dark_url'])) {
				$style['logo_content'] = '<img src="'.esc_url($style['logo_dark_url']).'" alt="'.get_bloginfo( 'name' ).'">';
			}
		} elseif(!empty($style['logo_default_url'])) {
			$style['logo_content'] = '<img src="'.esc_url($style['logo_default_url']).'" alt="'.get_bloginfo( 'name' ).'">';
		} elseif(isset($lauv_theme['logo_text']) && $lauv_theme['logo_text']) {
			$style['logo_content'] = esc_html($lauv_theme['logo_text']);
		} else {
			$style['logo_content'] = get_bloginfo( 'name' );
		}

		if(isset($lauv_theme['working_time']) && !empty($lauv_theme['working_time'])) {
			$style['working_time'] = $lauv_theme['working_time'];
		}

		if(isset($lauv_theme['phone_number']) && !empty($lauv_theme['phone_number'])) {
			$style['phone_number'] = $lauv_theme['phone_number'];
		}

		if(isset($lauv_theme['google_maps_api_key']) && !empty($lauv_theme['google_maps_api_key'])) {
			$style['google_maps_api_key'] = $lauv_theme['google_maps_api_key'];
		}

		if(isset($lauv_theme['navigation_type']) && !empty($lauv_theme['navigation_type'])) {
			$style['navigation_type'] = $lauv_theme['navigation_type'];
		}

		if(isset($lauv_theme['header_container']) && !empty($lauv_theme['header_container'])) {
			$style['header_container'] = $lauv_theme['header_container'];
		}

		if(isset($lauv_theme['header_color_mode']) && !empty($lauv_theme['header_color_mode'])) {
			$style['header_color_mode'] = $lauv_theme['header_color_mode'];
		}

		if(isset($lauv_theme['header_color_mode_404']) && !empty($lauv_theme['header_color_mode_404'])) {
			$style['header_color_mode_404'] = $lauv_theme['header_color_mode_404'];
		}

		if(isset($lauv_theme['header_color_mode_coming_soon']) && !empty($lauv_theme['header_color_mode_coming_soon'])) {
			$style['header_color_mode_coming_soon'] = $lauv_theme['header_color_mode_coming_soon'];
		}

		if(isset($lauv_theme['copyright_text']) && !empty($lauv_theme['copyright_text'])) {
			$style['copyright_text'] = $lauv_theme['copyright_text'];
		}

		if(isset($lauv_theme['contacts_text']) && !empty($lauv_theme['contacts_text'])) {
			$style['contacts_text'] = $lauv_theme['contacts_text'];
		}

		if(isset($lauv_theme['address_text']) && !empty($lauv_theme['address_text'])) {
			$style['address_text'] = $lauv_theme['address_text'];
		}

		if(isset($lauv_theme['sidebar_desc']) && !empty($lauv_theme['sidebar_desc'])) {
			$style['sidebar_desc'] = $lauv_theme['sidebar_desc'];
		}

		if(isset($lauv_theme['sidebar_contacts']) && !empty($lauv_theme['sidebar_contacts'])) {
			$style['sidebar_contacts'] = $lauv_theme['sidebar_contacts'];
		}

		if(isset($lauv_theme['sidebar_copyright_text']) && !empty($lauv_theme['sidebar_copyright_text'])) {
			$style['sidebar_copyright_text'] = $lauv_theme['sidebar_copyright_text'];
		}

		if(isset($lauv_theme['footer']) && $lauv_theme['footer']) {
			$style['footer'] = $lauv_theme['footer'];
		}

		if(isset($lauv_theme['footer_social_buttons']) && $lauv_theme['footer_social_buttons']) {
			$style['footer_social_buttons'] = $lauv_theme['footer_social_buttons'];
		}

		if(isset($lauv_theme['right_click_disable'])) {
			$style['right_click_disable'] = $lauv_theme['right_click_disable'];
		}

		if(isset($lauv_theme['right_click_disable_message']) && !empty($lauv_theme['right_click_disable_message'])) {
			$style['right_click_disable_message'] = $lauv_theme['right_click_disable_message'];
		}

		if(isset($lauv_theme['protected_message']) && !empty($lauv_theme['protected_message'])) {
			$style['protected_message'] = $lauv_theme['protected_message'];
		}

		if(isset($lauv_theme['404_bg']) && !empty($lauv_theme['404_bg'])) {
			$style['404_bg'] = "background-image: url(".$lauv_theme['404_bg']['background-image'].")";
		}

		if(isset($lauv_theme['coming_soon_bg']) && !empty($lauv_theme['coming_soon_bg'])) {
			$style['coming_soon_bg'] = "background-image: url(".$lauv_theme['coming_soon_bg']['background-image'].")";
		}

		if(isset($lauv_theme['404_page_text'])) {
			$style['404_page_text'] = $lauv_theme['404_page_text'];
		}

		if(isset($lauv_theme['coming_soon_heading'])) {
			$style['coming_soon_heading'] = $lauv_theme['coming_soon_heading'];
		}

		if(isset($lauv_theme['coming_soon_subscribe_desc'])) {
			$style['coming_soon_subscribe_desc'] = $lauv_theme['coming_soon_subscribe_desc'];
		}

		if(isset($lauv_theme['coming_soon_subscribe_code']) && $lauv_theme['coming_soon_subscribe_code']) {
			$style['coming_soon_subscribe_code'] = $lauv_theme['coming_soon_subscribe_code'];
		}

		if(isset($lauv_theme['project_style']) && $lauv_theme['project_style']) {
			$style['project_style'] = $lauv_theme['project_style'];
		}

		if(isset($lauv_theme['project_image']) && $lauv_theme['project_image']) {
			$style['project_image'] = $lauv_theme['project_image'];
		}

		if(isset($lauv_theme['blog_feature_image']) && $lauv_theme['blog_feature_image']) {
			$style['blog_feature_image'] = $lauv_theme['blog_feature_image'];
		}

		if(isset($lauv_theme['blog_date']) && $lauv_theme['blog_date']) {
			$style['blog_date'] = $lauv_theme['blog_date'];
		}

		if(isset($lauv_theme['blog_like']) && $lauv_theme['blog_like']) {
			$style['blog_like'] = $lauv_theme['blog_like'];
		}

		if(isset($lauv_theme['blog_comment_count']) && $lauv_theme['blog_comment_count']) {
			$style['blog_comment_count'] = $lauv_theme['blog_comment_count'];
		}

		if(isset($lauv_theme['preloader_show'])) {
			$style['preloader_show'] = $lauv_theme['preloader_show'];
		}

		if(isset($lauv_theme['preloader_type'])) {
			$style['preloader_type'] = $lauv_theme['preloader_type'];
		}

		if(isset($lauv_theme['preloader_label1'])) {
			$style['preloader_label1'] = $lauv_theme['preloader_label1'];
		}

		if(isset($lauv_theme['preloader_label2'])) {
			$style['preloader_label2'] = $lauv_theme['preloader_label2'];
		}
		
		if(isset($lauv_theme['preloader_img']) && $lauv_theme['preloader_img']) {
			$style['preloader_img'] = $lauv_theme['preloader_img'];
		}
		
		if(isset($lauv_theme['social_target']) && $lauv_theme['social_target']) {
			$style['social_target'] = $lauv_theme['social_target'];
		}

		if(isset($lauv_theme['social_icon1']) && isset($lauv_theme['social_link1']) && $lauv_theme['social_icon1'] && $lauv_theme['social_link1']) {
			$social_array = explode(',', $lauv_theme['social_icon1']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($lauv_theme['social_link1']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($lauv_theme['social_icon2']) && isset($lauv_theme['social_link2']) && $lauv_theme['social_icon2'] && $lauv_theme['social_link2']) {
			$social_array = explode(',', $lauv_theme['social_icon2']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($lauv_theme['social_link2']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($lauv_theme['social_icon3']) && isset($lauv_theme['social_link3']) && $lauv_theme['social_icon3'] && $lauv_theme['social_link3']) {
			$social_array = explode(',', $lauv_theme['social_icon3']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($lauv_theme['social_link3']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($lauv_theme['social_icon4']) && isset($lauv_theme['social_link4']) && $lauv_theme['social_icon4'] && $lauv_theme['social_link4']) {
			$social_array = explode(',', $lauv_theme['social_icon4']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($lauv_theme['social_link4']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($lauv_theme['social_icon5']) && isset($lauv_theme['social_link5']) && $lauv_theme['social_icon5'] && $lauv_theme['social_link5']) {
			$social_array = explode(',', $lauv_theme['social_icon5']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($lauv_theme['social_link5']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($lauv_theme['social_icon6']) && isset($lauv_theme['social_link6']) && $lauv_theme['social_icon6'] && $lauv_theme['social_link6']) {
			$social_array = explode(',', $lauv_theme['social_icon6']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($lauv_theme['social_link6']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($lauv_theme['social_icon7']) && isset($lauv_theme['social_link7']) && $lauv_theme['social_icon7'] && $lauv_theme['social_link7']) {
			$social_array = explode(',', $lauv_theme['social_icon7']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($lauv_theme['social_link7']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($lauv_theme['download-link']) && !empty($lauv_theme['download-link'])) {
			$style['download_link'] = $lauv_theme['download-link'];
		}

		if(isset($lauv_theme['project-details']) && !empty($lauv_theme['project-details'])) {
			$style['project_details'] = $lauv_theme['project-details'];
		}
	}

	if(function_exists("get_field")) {

		if(get_field('header_container') == 'container') {
			$style['header_container'] = 'container';
		} elseif(get_field('header_container') == 'container-fluid') {
			$style['header_container'] = 'container-fluid';
		}

		if(get_field('header_color_mode') == 'light') {
			$style['header_color_mode'] = 'light';
		}

		if(get_field('header_color_mode') == 'dark') {
			$style['header_color_mode'] = 'dark';
		}

		if(get_field('header_space')) {
			$style['header_space'] = get_field('header_space');
		}

		if(get_field('navigation_type') && get_field('navigation_type') != 'default') {
			$style['navigation_type'] = get_field('navigation_type');
		}

		if(get_field('site_mode') && get_field('site_mode') != 'default') {
			$style['site_mode'] = get_field('site_mode');
		}

		if(get_field('header_style') && get_field('header_style') != 'default') {
			$style['header_style'] = get_field('header_style');
		}

		if(get_field('header_container') && get_field('header_container') != 'default') {
			$style['header_container'] = get_field('header_container');
		}

		if(get_field('footer_social_buttons') && get_field('footer_social_buttons') != 'default') {
			$style['footer_social_buttons'] = get_field('footer_social_buttons');
		}

		if(get_field('footer') && get_field('footer') != 'default') {
			$style['footer'] = get_field('footer');
		}

		if(get_field('project_style') && get_field('project_style') != 'default') {
			$style['project_style'] = get_field('project_style');
		}

		if(get_field('project_image') && get_field('project_image') != 'default') {
			$style['project_image'] = get_field('project_image');
		}

		if(get_field('project_client_name')) {
			$style['project_client_name'] = get_field('project_client_name');
		}

		if(get_field('project_year')) {
			$style['project_year'] = get_field('project_year');
		}
	}


	$style['css_classes'] = 'header_'.$style['header_style'];

	if(is_404()) {
		$style['css_classes'] .= ' '.$style['header_color_mode_404'];
	} else if(is_page_template('page-coming-soon.php')) {
		$style['css_classes'] .= ' '.$style['header_color_mode_coming_soon'];
	} else {
		$style['css_classes'] .= ' '.$style['header_color_mode'];
	}

	if(get_post_type() == 'pt-portfolio' && $style['project_style'] == 'horizontal') {
		$style['header_container'] = 'container-fluid';
	}

	if($style['header_space'] == 'yes' && !is_404() && !is_page_template('page-coming-soon.php')) {
		$style['css_classes'] .= ' header-space-on';
	}

	return $style;
}

add_filter( 'body_class', 'lauv_custom_body_classes');
function lauv_custom_body_classes( $classes ) {
	global $lauv_theme;
	$site_mode = lauv_styles()['site_mode'];

	$classes[] = 'header-type-'.lauv_styles()['header_style'];
	$classes[] = 'header-nav-type-'.lauv_styles()['navigation_type'];
	$classes[] = 'header-space-'.lauv_styles()['header_space'];
    $classes[] = 'popup_download_'.lauv_styles()['download_link'];
    $classes[] = 'project_details_'.lauv_styles()['project_details'];
    $classes[] = 'site-'.$site_mode;

	if(lauv_styles()['right_click_disable'] == '1') {
		$classes[] = 'right-click-disable';
	}

	if(!class_exists('WPBakeryShortCode')) {
		$classes[] = 'site-nav-arr';
	}
 
    return $classes;
}

add_action('wp_footer', 'lauv_right_click_disable'); 
function lauv_right_click_disable() {
	if(function_exists('lauv_styles') && lauv_styles()['right_click_disable'] == '1') {
	    echo '<div class="right-click-disable-message main-row"><div class="container"><div class="cell">'.wp_kses_post(lauv_styles()['right_click_disable_message']).'</div></div></div>';
    } 
}

add_filter( 'the_password_form', 'lauv_custom_password_form' );
function lauv_custom_password_form() {
    global $post;
    $label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
    $o = '<form class="protected-post-form" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post"><div class="cell">'. wp_kses_post(lauv_styles()['protected_message']) .'<div class="area"><input name="post_password" placeholder="'.esc_html__('Type the password', 'lauv').'" id="' . $label . '" type="password" /><button type="submit" name="Submit" class="button"><i class="multimedia-icons-padlock"></i></button></div></div></form>';
    return $o;
}

/**
 * Portfolio widget
 */
class lauv_portfolio_widget extends WP_Widget {
 
	function __construct() {
		parent::__construct(
			'portfolio', 
			'Portfolio'
		);
	}
 
	public function widget( $args, $instance ) {
		$title = $instance['title'];
		$amount = $instance['amount'];
		$cols = $instance['cols'];
 
		switch ($cols) {
			case '1':
			$class = "col-xs-12";
			break;
			case '2':
			$class = "col-xs-6 col-sm-6";
			break;
			case '3':
			$class = "col-xs-4";
			break;
			case '4':
			$class = "col-xs-6 col-md-3";
			break;

			default:
			$class = "";
			break;
		}

		$porfolio_array = get_posts( array(
			'numberposts'     => $amount,
			'post_type'       => 'pt-portfolio',
			'post_status'     => 'publish'
			)
		);

		echo wp_kses_post($args['before_widget']);
		if ( ! empty( $title ) ) echo wp_kses_post($args['before_title'] . strip_tags($title) . $args['after_title']);
		?>
		<div class="gallery-module row">
			<?php foreach ($porfolio_array as $item) {
				setup_postdata($item);
				$id = $item->ID;
				$name = $item->post_title;

				$thumb = get_post_meta( $id, '_thumbnail_id', true );

				$link = get_permalink($id);
			?>
			<div class="<?php echo esc_attr($class) ?> item"><a href="<?php echo esc_url($link) ?>"><?php echo wp_get_attachment_image( $thumb , 'thumbnail', true, array('title'=>$name) ) ?></a></div>
			<?php } ?>
		</div>
		<?php
		echo wp_kses_post($args['after_widget']);
	}
 
	public function form( $instance ) {
		$title = "";
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		$amount = "";
		if ( isset( $instance[ 'amount' ] ) ) {
			$amount = $instance[ 'amount' ];
		}
		$cols = "";
		if ( isset( $instance[ 'cols' ] ) ) {
			$cols = $instance[ 'cols' ];
		}
		?>
		<p>
			<label for="<?php echo esc_html($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Heading:', 'lauv') ?></label> 
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_html($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_html($this->get_field_id( 'amount' )); ?>"><?php esc_html_e( 'Amount:', 'lauv') ?></label> 
			<input id="<?php echo esc_html($this->get_field_id( 'amount' )); ?>" name="<?php echo esc_html($this->get_field_name( 'amount' )); ?>" type="text" value="<?php echo ($amount) ? esc_attr( $amount ) : '9'; ?>" size="3" />
		</p>
		<p>
			<label for="<?php echo esc_html($this->get_field_id( 'cols' )); ?>"><?php esc_html_e( 'Cols:', 'lauv') ?></label> 
			<input id="<?php echo esc_html($this->get_field_id( 'cols' )); ?>" name="<?php echo esc_html($this->get_field_name( 'cols' )); ?>" type="text" value="<?php echo ($cols) ? esc_attr( $cols ) : '3'; ?>" size="3" />
		</p>
		<?php 
	}
 
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['amount'] = ( is_numeric( $new_instance['amount'] ) ) ? $new_instance['amount'] : '8';
		$instance['cols'] = ( is_numeric( $new_instance['cols'] ) ) ? $new_instance['cols'] : '5';
		return $instance;
	}
}

function lauv_portfolio_widget() {
	register_widget( 'lauv_portfolio_widget' );
}
add_action( 'widgets_init', 'lauv_portfolio_widget' );

function fb_mce_before_init( $settings ) {

    $style_formats = array(
        array(
            'title' => 'thin',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '100',
            )
        ),
        array(
            'title' => 'extra-light',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '200',
            )
        ),
        array(
            'title' => 'light',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '300',
            )
        ),
        array(
            'title' => 'regular',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '400',
            )
        ),
        array(
            'title' => 'medium',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '500',
            )
        ),
        array(
            'title' => 'semi-bold',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '600',
            )
        ),
        array(
            'title' => 'bold',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '700',
            )
        ),
        array(
            'title' => 'extra-bold',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '800',
            )
        ),
        array(
            'title' => 'black',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '900',
            )
        ),
        array(
            'title' => 'UPPERCASE',
            'inline' => 'span',
            'styles' => array(
                'textTransform'    => 'uppercase',
            )
        ),
        array(
            'title' => 'Button style 1',
            'inline' => 'a',
            'classes' => 'button-style1',
			'wrapper' => true,
        ),
        array(
            'title' => 'Button style 2',
            'inline' => 'a',
            'classes' => 'button-style2',
			'wrapper' => true,
        )
    );

    $settings['style_formats'] = json_encode( $style_formats );

    return $settings;
}
add_filter( 'tiny_mce_before_init', 'fb_mce_before_init' );

if(function_exists('vc_remove_param')) {
	vc_remove_param( 'vc_btn', 'color' );
}

if(function_exists('vc_add_param')) {
	vc_add_params( 'vc_custom_heading', array(
		array(
		    "type"        => "switch",
		    "heading"     => esc_html__( "Decor text on background", "lauv" ),
		    "param_name"  => "decor_text_switch",
		    "value"       => "off",
		    "options"     => array(
		        "on" => array(
		            "on"    => "On",
		            "off"   => "Off",
		        ),
		    ),
		    "default_set" => false,
		),
		array(
		    "type"        => "textfield",
		    "heading"     => esc_html__( "Enter Decor text", "lauv" ),
		    "param_name"  => "decor_text",
		    "dependency" => Array( "element" => "decor_text_switch", "value" => array( "on" ) ),
		),
		array(
		    "type"        => "textfield",
		    "heading"     => esc_html__( "Enter font size Decor text", "lauv" ),
		    "param_name"  => "decor_font_size_text",
		    "dependency" => Array( "element" => "decor_text_switch", "value" => array( "on" ) ),
		),
		array(
		    "type"        => "colorpicker",
		    "heading"     => esc_html__( "Enter Decor text color", "lauv" ),
		    "param_name"  => "decor_text_color",
		    "dependency" => Array( "element" => "decor_text_switch", "value" => array( "on" ) ),
		),
		array(
		    "type"        => "switch",
		    "class"       => "",
		    "heading"     => esc_html__( "Decor line", "lauv" ),
		    "param_name"  => "decor_line",
		    "value"       => "off",
		    "options"     => array(
		        "on" => array(
		            "on"    => "On",
		            "off"   => "Off",
		        ),
		    ),
		    "default_set" => false,
		),
		array(
		    "type"        => "switch",
		    "class"       => "",
		    "heading"     => esc_html__( "Uppercase", "lauv" ),
		    "param_name"  => "uppercase",
		    "value"       => "off",
		    "options"     => array(
		        "on" => array(
		            "on"    => "On",
		            "off"   => "Off",
		        ),
		    ),
		    "default_set" => false,
		),
	));

	vc_add_params("vc_row", array(
		array(
		    "type"        => "switch",
		    "heading"     => esc_html__( "Stick cols", "lauv" ),
		    "param_name"  => "stick",
		    "value"       => "off",
		    "options"     => array(
		        "on" => array(
		            "on"    => "On",
		            "off"   => "Off",
		        ),
		    ),
		    "default_set" => false,
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom text color', 'lauv' ),
			'param_name' => 'custom_text_color',
		),
		array(
			"type" => "dropdown",
			"class" => "",
			"heading" => esc_html__( "Background position", "lauv" ),
			"param_name" => "background_position",
			"value" => array(
				esc_html__('Auto', 'lauv') => '',
				"left center" => "left center",
				"left top" => "left top",
				"left bottom" => "left bottom",
				"center center" => "center center",
				"center top" => "center top",
				"center bottom" => "center bottom",
				"right center" => "right center",
				"right top" => "right top",
				"right bottom" => "right bottom"
			)
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Gradient background', 'lauv' ),
			'param_name' => 'show_background_gradient',
		),
		array(
			'type' => 'gradient',
			'heading' => esc_html__( 'Gradient', 'lauv' ),
			'param_name' => 'background_gradient',
			'dependency' => array(
				'element' => 'show_background_gradient',
				'not_empty' => true,
			),
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Color overlay', 'lauv' ),
			'param_name' => 'color_overlay',
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Color overlay hex', 'lauv' ),
			'param_name' => 'color_overlay_color',
			'dependency' => array(
				'element' => 'color_overlay',
				'not_empty' => true,
			),
		),
	));

	vc_add_params("vc_row_inner", array(
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom text color', 'lauv' ),
			'param_name' => 'custom_text_color',
		),
		array(
			"type" => "dropdown",
			"class" => "",
			"heading" => esc_html__( "Background position", "lauv" ),
			"param_name" => "background_position",
			"value" => array(
				esc_html__('Auto', 'lauv') => '',
				"left center" => "left center",
				"left top" => "left top",
				"left bottom" => "left bottom",
				"center center" => "center center",
				"center top" => "center top",
				"center bottom" => "center bottom",
				"right center" => "right center",
				"right top" => "right top",
				"right bottom" => "right bottom"
			)
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Gradient background', 'lauv' ),
			'param_name' => 'show_background_gradient',
		),
		array(
			'type' => 'gradient',
			'heading' => esc_html__( 'Gradient', 'lauv' ),
			'param_name' => 'background_gradient',
			'dependency' => array(
				'element' => 'show_background_gradient',
				'not_empty' => true,
			),
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Color overlay', 'lauv' ),
			'param_name' => 'color_overlay',
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Color overlay hex', 'lauv' ),
			'param_name' => 'color_overlay_color',
			'dependency' => array(
				'element' => 'color_overlay',
				'not_empty' => true,
			),
		),
	));

	vc_add_params("vc_column", array(
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom text color', 'lauv' ),
			'param_name' => 'custom_text_color',
		),
		array(
			"type" => "dropdown",
			"class" => "",
			"heading" => esc_html__( "Background position", "lauv" ),
			"param_name" => "background_position",
			"value" => array(
				esc_html__('Auto', 'lauv') => '',
				"left center" => "left center",
				"left top" => "left top",
				"left bottom" => "left bottom",
				"center center" => "center center",
				"center top" => "center top",
				"center bottom" => "center bottom",
				"right center" => "right center",
				"right top" => "right top",
				"right bottom" => "right bottom"
			)
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Gradient background', 'lauv' ),
			'param_name' => 'show_background_gradient',
		),
		array(
			'type' => 'gradient',
			'heading' => esc_html__( 'Gradient', 'lauv' ),
			'param_name' => 'background_gradient',
			'dependency' => array(
				'element' => 'show_background_gradient',
				'not_empty' => true,
			),
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Color overlay', 'lauv' ),
			'param_name' => 'color_overlay',
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Color overlay hex', 'lauv' ),
			'param_name' => 'color_overlay_color',
			'dependency' => array(
				'element' => 'color_overlay',
				'not_empty' => true,
			),
		),
	));

	vc_remove_param( "vc_icon", "background_color" );
	vc_remove_param( "vc_icon", "custom_color" );
	vc_remove_param( "vc_icon", "background_style" );
	vc_remove_param( "vc_icon", "background_color" );
	vc_remove_param( "vc_icon", "custom_background_color" );
	vc_remove_param( "vc_icon", "size" );
	vc_remove_param( "vc_icon", "align" );
	vc_remove_param( "vc_icon", "link" );
	vc_remove_param( "vc_icon", "el_id" );
	vc_remove_param( "vc_icon", "el_class" );
	vc_remove_param( "vc_icon", "css" );

	vc_add_params("vc_icon", array(
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom color', 'lauv' ),
			'param_name' => 'custom_color',
			'description' => esc_html__( 'Select custom icon color.', 'lauv' ),
			'dependency' => array(
				'element' => 'color',
				'value' => 'custom',
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Background shape', 'lauv' ),
			'param_name' => 'background_style',
			'value' => array(
				esc_html__( 'None', 'lauv' ) => '',
				esc_html__( 'Circle', 'lauv' ) => 'rounded',
				esc_html__( 'Square', 'lauv' ) => 'boxed',
				esc_html__( 'Rounded', 'lauv' ) => 'rounded-less',
				esc_html__( 'Outline Circle', 'lauv' ) => 'rounded-outline',
				esc_html__( 'Outline Square', 'lauv' ) => 'boxed-outline',
				esc_html__( 'Outline Rounded', 'lauv' ) => 'rounded-less-outline',
			),
			'description' => esc_html__( 'Select background shape and style for icon.', 'lauv' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Background color', 'lauv' ),
			'param_name' => 'background_color',
			'value' => array_merge( getVcShared( 'colors' ), array( esc_html__( 'Custom color', 'lauv' ) => 'custom' ), array( esc_html__( 'Gradient', 'lauv' ) => 'gradient' ) ),
			'std' => 'grey',
			'description' => esc_html__( 'Select background color for icon.', 'lauv' ),
			'param_holder_class' => 'vc_colored-dropdown',
			'dependency' => array(
				'element' => 'background_style',
				'not_empty' => true,
			),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom background color', 'lauv' ),
			'param_name' => 'custom_background_color',
			'description' => esc_html__( 'Select custom icon background color.', 'lauv' ),
			'dependency' => array(
				'element' => 'background_color',
				'value' => 'custom',
			),
		),
		array(
			'type' => 'gradient',
			'heading' => esc_html__( 'Custom background gradient', 'lauv' ),
			'param_name' => 'custom_background_gradient',
			'dependency' => array(
				'element' => 'background_color',
				'value' => 'gradient',
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Size', 'lauv' ),
			'param_name' => 'size',
			'value' => array_merge( getVcShared( 'sizes' ), array( 'Extra Large' => 'xl' ) ),
			'std' => 'md',
			'description' => esc_html__( 'Icon size.', 'lauv' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Icon alignment', 'lauv' ),
			'param_name' => 'align',
			'value' => array(
				__( 'Left', 'lauv' ) => 'left',
				__( 'Right', 'lauv' ) => 'right',
				__( 'Center', 'lauv' ) => 'center',
			),
			'description' => esc_html__( 'Select icon alignment.', 'lauv' ),
		),
		array(
			'type' => 'vc_link',
			'heading' => esc_html__( 'URL (Link)', 'lauv' ),
			'param_name' => 'link',
			'description' => esc_html__( 'Add link to icon.', 'lauv' ),
		),
		vc_map_add_css_animation(),
		array(
			'type' => 'el_id',
			'heading' => esc_html__( 'Element ID', 'lauv' ),
			'param_name' => 'el_id',
			'description' => sprintf( __( 'Enter element ID (Note: make sure it is unique and valid according to <a href="%s" target="_blank">w3c specification</a>).', 'lauv' ), 'http://www.w3schools.com/tags/att_global_id.asp' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Extra class name', 'lauv' ),
			'param_name' => 'el_class',
			'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'lauv' ),
		),
		array(
			'type' => 'css_editor',
			'heading' => esc_html__( 'CSS box', 'lauv' ),
			'param_name' => 'css',
			'group' => esc_html__( 'Design Options', 'lauv' ),
		),
	));

	vc_remove_param( "vc_tta_accordion", "no_fill" );
	vc_remove_param( "vc_tta_accordion", "spacing" );
	vc_remove_param( "vc_tta_accordion", "gap" );
	vc_remove_param( "vc_tta_accordion", "c_align" );
	vc_remove_param( "vc_tta_accordion", "autoplay" );
	vc_remove_param( "vc_tta_accordion", "collapsible_all" );
	vc_remove_param( "vc_tta_accordion", "c_icon" );
	vc_remove_param( "vc_tta_accordion", "c_position" );
	vc_remove_param( "vc_tta_accordion", "active_section" );
	vc_remove_param( "vc_tta_accordion", "el_id" );
	vc_remove_param( "vc_tta_accordion", "el_class" );
	vc_remove_param( "vc_tta_accordion", "css" );

	vc_add_params("vc_tta_accordion", array(
        array(
            "type" => "gradient",
            "base_gradient" => "#ff6884 0%,#620044 100%",
            "base_orientation" => "horizontal",
            "heading" => esc_html__("Gradient on active", "lauv"),
            "param_name" => "active_gradient",
			'dependency' => array(
				'element' => 'style',
				'value' => 'classic',
			),
        ),
        array(
            "type" => "colorpicker",
            "heading" => esc_html__("Text color active block", "lauv"),
            "param_name" => "active_color",
			'dependency' => array(
				'element' => 'style',
				'value' => 'classic',
			),
        ),
		array(
			'type' => 'checkbox',
			'param_name' => 'no_fill',
			'heading' => esc_html__( 'Do not fill content area?', 'lauv' ),
			'description' => esc_html__( 'Do not fill content area with color.', 'lauv' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'spacing',
			'value' => array(
				esc_html__( 'None', 'lauv' ) => '',
				'1px' => '1',
				'2px' => '2',
				'3px' => '3',
				'4px' => '4',
				'5px' => '5',
				'10px' => '10',
				'15px' => '15',
				'20px' => '20',
				'25px' => '25',
				'30px' => '30',
				'35px' => '35',
			),
			'heading' => esc_html__( 'Spacing', 'lauv' ),
			'description' => esc_html__( 'Select accordion spacing.', 'lauv' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'gap',
			'value' => array(
				esc_html__( 'None', 'lauv' ) => '',
				'1px' => '1',
				'2px' => '2',
				'3px' => '3',
				'4px' => '4',
				'5px' => '5',
				'10px' => '10',
				'15px' => '15',
				'20px' => '20',
				'25px' => '25',
				'30px' => '30',
				'35px' => '35',
			),
			'heading' => esc_html__( 'Gap', 'lauv' ),
			'description' => esc_html__( 'Select accordion gap.', 'lauv' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'c_align',
			'value' => array(
				esc_html__( 'Left', 'lauv' ) => 'left',
				esc_html__( 'Right', 'lauv' ) => 'right',
				esc_html__( 'Center', 'lauv' ) => 'center',
			),
			'heading' => esc_html__( 'Alignment', 'lauv' ),
			'description' => esc_html__( 'Select accordion section title alignment.', 'lauv' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'autoplay',
			'value' => array(
				esc_html__( 'None', 'lauv' ) => 'none',
				'1' => '1',
				'2' => '2',
				'3' => '3',
				'4' => '4',
				'5' => '5',
				'10' => '10',
				'20' => '20',
				'30' => '30',
				'40' => '40',
				'50' => '50',
				'60' => '60',
			),
			'std' => 'none',
			'heading' => esc_html__( 'Autoplay', 'lauv' ),
			'description' => esc_html__( 'Select auto rotate for accordion in seconds (Note: disabled by default).', 'lauv' ),
		),
		array(
			'type' => 'checkbox',
			'param_name' => 'collapsible_all',
			'heading' => esc_html__( 'Allow collapse all?', 'lauv' ),
			'description' => esc_html__( 'Allow collapse all accordion sections.', 'lauv' ),
		),
		// Control Icons
		array(
			'type' => 'dropdown',
			'param_name' => 'c_icon',
			'value' => array(
				esc_html__( 'None', 'lauv' ) => '',
				esc_html__( 'Chevron', 'lauv' ) => 'chevron',
				esc_html__( 'Plus', 'lauv' ) => 'plus',
				esc_html__( 'Triangle', 'lauv' ) => 'triangle',
			),
			'std' => 'plus',
			'heading' => esc_html__( 'Icon', 'lauv' ),
			'description' => esc_html__( 'Select accordion navigation icon.', 'lauv' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'c_position',
			'value' => array(
				esc_html__( 'Left', 'lauv' ) => 'left',
				esc_html__( 'Right', 'lauv' ) => 'right',
			),
			'dependency' => array(
				'element' => 'c_icon',
				'not_empty' => true,
			),
			'heading' => esc_html__( 'Position', 'lauv' ),
			'description' => esc_html__( 'Select accordion navigation icon position.', 'lauv' ),
		),
		// Control Icons END
		array(
			'type' => 'textfield',
			'param_name' => 'active_section',
			'heading' => esc_html__( 'Active section', 'lauv' ),
			'value' => 1,
			'description' => esc_html__( 'Enter active section number (Note: to have all sections closed on initial load enter non-existing number).', 'lauv' ),
		),
		vc_map_add_css_animation(),
		array(
			'type' => 'el_id',
			'heading' => esc_html__( 'Element ID', 'lauv' ),
			'param_name' => 'el_id',
			'description' => sprintf( __( 'Enter element ID (Note: make sure it is unique and valid according to <a href="%s" target="_blank">w3c specification</a>).', 'lauv' ), 'http://www.w3schools.com/tags/att_global_id.asp' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Extra class name', 'lauv' ),
			'param_name' => 'el_class',
			'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'lauv' ),
		),
		array(
			'type' => 'css_editor',
			'heading' => esc_html__( 'CSS box', 'lauv' ),
			'param_name' => 'css',
			'group' => esc_html__( 'Design Options', 'lauv' ),
		),
	));
}

add_action( 'vc_before_init', 'lauv_vc_before_init' );

class lauv_social_buttons_widget extends WP_Widget {
 
	function __construct() {
		parent::__construct(
			'social_buttons', 
			'Social buttons'
		);
	}
 
	public function widget( $args, $instance ) {
		$title = $instance['title'];
		if(function_exists('lauv_styles') && !empty(lauv_styles()['social_buttons_content'])) {
			echo '<div class="social-buttons-widget widget">';
				if ( ! empty( $title ) ) echo wp_kses_post($args['before_title'] . $title . $args['after_title']);
				
				echo '<div class="social-buttons">'.lauv_styles()['social_buttons_content'].'</div>';

			echo '</div>';
		}
	}

	public function form( $instance ) {
		$title = "";
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		?>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Heading:', 'lauv') ?></label> 
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<?php 
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		return $instance;
	}
}

function lauv_social_buttons_widget() {
	register_widget( 'lauv_social_buttons_widget' );
}
add_action( 'widgets_init', 'lauv_social_buttons_widget' );

function lauv_vc_before_init() {
    if( function_exists('vc_set_shortcodes_templates_dir') ){
        vc_set_shortcodes_templates_dir( get_template_directory() . '/vc_templates' );
    }
}

add_filter( 'jpeg_quality', 'lauv_filter_theme_image_full_quality' );
add_filter( 'wp_editor_set_quality', 'lauv_filter_theme_image_full_quality' );

function lauv_filter_theme_image_full_quality( $quality ) {
    return 100;
}

/**
 * The order of the blocks
 **/

class Child_Wrap extends Walker_Nav_Menu {
    function start_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        $output .= "\n$indent<ul class=\"sub-menu\"><li class=\"back base-icons-left-arrow\"></li>\n";
    }
    function end_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        $output .= "$indent</ul>\n";
    }
}

add_action( 'vc_before_init', 'lauv_vcSetAsTheme' );
function lauv_vcSetAsTheme() {
	if(function_exists('vc_set_as_theme')) {
    	vc_set_as_theme();
	}
}


/**
 * Blog post widget
 */
class lauv_blog_post_widget extends WP_Widget {
 
	function __construct() {
		parent::__construct(
			'blog_post', 
			'Blog posts'
		);
	}
 
	public function widget( $args, $instance ) {
		$title = $instance['title'];
		$amount = $instance['amount'];
		$orderby = $instance['orderby'];
		$order = $instance['order'];
		$display_image = $instance['display_image'];
		$display_date = $instance['display_date'];


		$post_array = get_posts( array(
			'numberposts'     => $amount,
			'orderby'         => $orderby,
			'order'           => $order,
			'post_type'       => 'post',
			'post_status'     => 'publish'
			)
		);

		if ( ! empty( $title ) ) echo wp_kses_post($args['before_title'] . strip_tags($title) . $args['after_title']);
		?>
		<div class="blog-post-widget widget">
			<?php foreach ($post_array as $item) {
				setup_postdata($item);
				$id = $item->ID;
				$name = $item->post_title;

				$thumb = get_post_meta( $id, '_thumbnail_id', true );
				$image_array = wp_get_attachment_image_src( $thumb , 'thumbnail' )[0];
			?>
			<div class="item">
				<?php if($display_image == "yes" && isset($image_array) && !empty($image_array)) { ?>
				<a href="<?php echo esc_url(get_permalink($id)) ?>" class="image" style="background-image: url(<?php echo esc_url($image_array) ?>)"></a>
				<?php } ?>
				<div class="text">
					<?php if($display_date == "yes") { ?>
						<div class="blog-detail"><span><?php echo get_the_date('', $id) ?></span></div>
					<?php } ?>
					<a href="<?php echo esc_url(get_permalink($id)) ?>" class="name"><?php echo esc_html($name) ?></a>
				</div>
			</div>
			<?php } ?>
		</div>
		<?php
	}
 
	public function form( $instance ) {
		$title = "";
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		$amount = "";
		if ( isset( $instance[ 'amount' ] ) ) {
			$amount = $instance[ 'amount' ];
		}
		$orderby = "";
		if ( isset( $instance[ 'orderby' ] ) ) {
			$orderby = $instance[ 'orderby' ];
		}
		$order = "";
		if ( isset( $instance[ 'order' ] ) ) {
			$order = $instance[ 'order' ];
		}
		$display_image = "";
		if ( isset( $instance[ 'display_image' ] ) ) {
			$display_image = $instance[ 'display_image' ];
		}
		$display_date = "";
		if ( isset( $instance[ 'display_date' ] ) ) {
			$display_date = $instance[ 'display_date' ];
		}
		?>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Heading:', 'lauv') ?></label> 
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'amount' )); ?>"><?php esc_html_e( 'Number posts:', 'lauv') ?></label> 
			<input id="<?php echo esc_attr($this->get_field_id( 'amount' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'amount' )); ?>" type="number" value="<?php echo ($amount) ? esc_attr( $amount ) : '3'; ?>" size="3" />
		</p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'orderby' )); ?>"><?php esc_html_e( 'Order by:', 'lauv') ?></label>
			<select name="<?php echo esc_attr($this->get_field_name( 'orderby' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'orderby' )); ?>">
				<option value="date" <?php echo ($orderby =='date')?'selected':''; ?>><?php echo esc_html__('Date' ,'lauv') ?></option>
				<option value="author" <?php echo ($orderby =='author')?'selected':''; ?>><?php echo esc_html__('Author' ,'lauv') ?></option>
				<option value="category" <?php echo ($orderby =='category')?'selected':''; ?>><?php echo esc_html__('Category' ,'lauv') ?></option>
				<option value="ID" <?php echo ($orderby =='ID')?'selected':''; ?>><?php echo esc_html__('ID' ,'lauv') ?></option>
				<option value="title" <?php echo ($orderby =='title')?'selected':''; ?>><?php echo esc_html__('Title' ,'lauv') ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'order' )); ?>"><?php esc_html_e( 'Order:', 'lauv') ?></label>
			<select name="<?php echo esc_attr($this->get_field_name( 'order' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'order' )); ?>">
				<option value="DESC"<?php echo ($order =='DESC')?'selected':''; ?>><?php echo esc_html__('Descending order' ,'lauv') ?></option>
				<option value="ASC"<?php echo ($order =='ASC')?'selected':''; ?>><?php echo esc_html__('Ascending order' ,'lauv') ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'display_image' )); ?>"><?php esc_html_e( 'Image:', 'lauv') ?></label>
			<select name="<?php echo esc_attr($this->get_field_name( 'display_image' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'display_image' )); ?>">
				<option value="yes"<?php echo ($display_image =='yes')?'selected':''; ?>><?php echo esc_html__('Yes' ,'lauv') ?></option>
				<option value="no"<?php echo ($display_image =='no')?'selected':''; ?>><?php echo esc_html__('No' ,'lauv') ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'display_date' )); ?>"><?php esc_html_e( 'Date:', 'lauv') ?></label>
			<select name="<?php echo esc_attr($this->get_field_name( 'display_date' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'display_date' )); ?>">
				<option value="yes"<?php echo ($display_date =='yes')?'selected':''; ?>><?php echo esc_html__('Yes' ,'lauv') ?></option>
				<option value="no"<?php echo ($display_date =='no')?'selected':''; ?>><?php echo esc_html__('No' ,'lauv') ?></option>
			</select>
		</p>

		<?php 
	}
 
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['amount'] = ( is_numeric( $new_instance['amount'] ) ) ? $new_instance['amount'] : '2';
		$instance['orderby'] = ( is_numeric( $new_instance['orderby'] ) ) ? $new_instance['orderby'] : 'date';
		$instance['order'] = ( is_numeric( $new_instance['order'] ) ) ? $new_instance['order'] : 'DESC';
		$instance['display_image'] = ( is_numeric( $new_instance['display_image'] ) ) ? $new_instance['display_image'] : 'yes';
		$instance['display_date'] = ( is_numeric( $new_instance['display_date'] ) ) ? $new_instance['display_date'] : 'yes';
		return $instance;
	}
}

function lauv_blog_post_widget() {
	register_widget( 'lauv_blog_post_widget' );
}
add_action( 'widgets_init', 'lauv_blog_post_widget' );

function lauv_browser_body_class($classes) {
        global $is_lynx, $is_gecko, $is_IE, $is_edge, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;
        if($is_lynx) $classes[] = 'lynx';
        elseif($is_gecko) $classes[] = 'gecko';
        elseif($is_opera) $classes[] = 'opera';
        elseif($is_NS4) $classes[] = 'ns4';
        elseif($is_safari) $classes[] = 'safari';
        elseif($is_chrome) $classes[] = 'chrome';
        elseif($is_edge) $classes[] = 'edge';
        elseif($is_IE) {
                $classes[] = 'ie';
                if(preg_match('/MSIE ([0-9]+)([a-zA-Z0-9.]+)/', $_SERVER['HTTP_USER_AGENT'], $browser_version))
                $classes[] = 'ie'.$browser_version[1];
        } else $classes[] = 'unknown';
        if($is_iphone) $classes[] = 'iphone';
        if ( stristr( $_SERVER['HTTP_USER_AGENT'],"mac") ) {
                 $classes[] = 'osx';
           } elseif ( stristr( $_SERVER['HTTP_USER_AGENT'],"linux") ) {
                 $classes[] = 'linux';
           } elseif ( stristr( $_SERVER['HTTP_USER_AGENT'],"windows") ) {
                 $classes[] = 'windows';
           }
        return $classes;
}
add_filter('body_class','lauv_browser_body_class');

function lauv_phpinfo2array() {
    $entitiesToUtf8 = function($input) {
        // http://php.net/manual/en/function.html-entity-decode.php#104617
        return preg_replace_callback("/(&#[0-9]+;)/", function($m) { return mb_convert_encoding($m[1], "UTF-8", "HTML-ENTITIES"); }, $input);
    };
    $plainText = function($input) use ($entitiesToUtf8) {
        return trim(html_entity_decode($entitiesToUtf8(strip_tags($input))));
    };
    $titlePlainText = function($input) use ($plainText) {
        return '# '.$plainText($input);
    };
    
    ob_start();
    phpinfo(-1);
    
    $phpinfo = array('phpinfo' => array());

    // Strip everything after the <h1>Configuration</h1> tag (other h1's)
    if (!preg_match('#(.*<h1[^>]*>\s*Configuration.*)<h1#s', ob_get_clean(), $matches)) {
        return array();
    }
    
    $input = $matches[1];
    $matches = array();

    if(preg_match_all(
        '#(?:<h2.*?>(?:<a.*?>)?(.*?)(?:<\/a>)?<\/h2>)|'.
        '(?:<tr.*?><t[hd].*?>(.*?)\s*</t[hd]>(?:<t[hd].*?>(.*?)\s*</t[hd]>(?:<t[hd].*?>(.*?)\s*</t[hd]>)?)?</tr>)#s',
        $input, 
        $matches, 
        PREG_SET_ORDER
    )) {
        foreach ($matches as $match) {
            $fn = strpos($match[0], '<th') === false ? $plainText : $titlePlainText;
            if (strlen($match[1])) {
                $phpinfo[$match[1]] = array();
            } elseif (isset($match[3])) {
                $keys1 = array_keys($phpinfo);
                $phpinfo[end($keys1)][$fn($match[2])] = isset($match[4]) ? array($fn($match[3]), $fn($match[4])) : $fn($match[3]);
            } else {
                $keys1 = array_keys($phpinfo);
                $phpinfo[end($keys1)][] = $fn($match[2]);
            }

        }
    }
    
    return $phpinfo;
}

function lauv_let_to_num( $size ) {
	$l    = substr( $size, -1 );
	$ret  = substr( $size, 0, -1 );
	$byte = 1024;

	switch ( strtoupper( $l ) ) {
		case 'P':
			$ret *= 1024;
		case 'T':
			$ret *= 1024;
		case 'G':
			$ret *= 1024;
		case 'M':
			$ret *= 1024;
		case 'K':
			$ret *= 1024;
	}
	return $ret;
}