<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package lauv
 */

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">

		<?php wp_head(); ?>

	</head>

	<body <?php body_class(); ?>>
		<div id="all" class="site">

			<?php if(lauv_styles()['preloader_show'] == '1' && lauv_styles()['preloader_type'] == 'default') { ?>
				<div class="preloader-type2 main-row">
					<div class="text-container">
						<div class="h"><span><?php echo wp_kses_post(lauv_styles()['preloader_label1']) ?></span></div>
						<div class="sub-h"><span><?php echo wp_kses_post(lauv_styles()['preloader_label2']) ?></span></div>
					</div>
				</div>
			<?php } else if(lauv_styles()['preloader_show'] == '1' && isset(lauv_styles()['preloader_img']['background-image']) && !empty(lauv_styles()['preloader_img']['background-image'])) { ?>
				<div class="preloader">
					<div class="preloader_img"><img src="<?php echo esc_url(lauv_styles()['preloader_img']['background-image']) ?>" alt="<?php echo get_bloginfo( 'name' ) ?>"></div>
				</div>
			<?php } else if(lauv_styles()['preloader_show'] == '1') { ?>
				<div class="preloader-area">
					<div class="preloader-folding-cube">
						<div class="preloader-cube1 preloader-cube"></div>
						<div class="preloader-cube2 preloader-cube"></div>
						<div class="preloader-cube4 preloader-cube"></div>
						<div class="preloader-cube3 preloader-cube"></div>
					</div>
				</div>
			<?php } ?>
			<?php if(lauv_styles()['header_style'] != 'left_side') { ?>
				<header class="site-header <?php echo esc_attr(lauv_styles()['css_classes']) ?> main-row">
					<div class="<?php echo esc_attr(lauv_styles()['header_container']) ?>">
						<div class="logo"><a href="<?php echo esc_url(home_url('/')) ?>"><?php echo wp_kses_post(lauv_styles()['logo_content']) ?></a></div>
						<div class="fr">
							<?php if(has_nav_menu('navigation') && lauv_styles()['navigation_type'] != 'disabled') { ?>
								<?php if(lauv_styles()['navigation_type'] != 'on_side') { ?>
									<nav class="navigation <?php echo esc_attr(lauv_styles()['navigation_type']) ?>"><?php wp_nav_menu( array( 'theme_location' => 'navigation', 'container' => 'ul', 'menu_class' => 'menu', 'link_before' => '<span>', 'link_after' => '</span>' ) ); ?></nav>
								<?php } ?>
								<div class="nav-button <?php echo esc_attr(lauv_styles()['navigation_type']) ?>" data-close-label="<?php echo esc_attr__('close', 'lauv') ?>"><?php echo esc_html__('menu', 'lauv') ?></div>
							<?php } ?>
						</div>
					</div>
				</header>
				<?php if(lauv_styles()['navigation_type'] == 'on_side') { ?>
					<div class="right-side-nav main-row">
						<div class="close"><?php echo esc_html__('close', 'lauv') ?></div>
						<div class="wrap">
							<div>
								<?php if(has_nav_menu('side-navigation')) { ?>
									<nav class="right-side-navigation <?php echo esc_attr(lauv_styles()['navigation_type']) ?>"><?php wp_nav_menu( array( 'theme_location' => 'side-navigation', 'container' => 'ul', 'menu_class' => 'menu', 'link_before' => '<span>', 'link_after' => '</span>' ) ); ?></nav>
								<?php } ?>
							</div>
						</div>
						<?php if(!empty(lauv_styles()['copyright_text']) || !empty(lauv_styles()['sidebar_contacts'])) { ?>
							<div class="bottom">
								<?php if(!empty(lauv_styles()['sidebar_contacts'])) { ?>
									<div class="contacts">
										<?php echo nl2br(wp_kses_post(lauv_styles()['sidebar_contacts'])) ?>
									</div>
								<?php } if(!empty(lauv_styles()['sidebar_copyright_text'])) { ?>
									<div class="copyright">
										<?php echo nl2br(wp_kses_post(lauv_styles()['sidebar_copyright_text'])) ?>
									</div>
								<?php } ?>
							</div>
						<?php } ?>
					</div>
				<?php } ?>
			<?php } else if(lauv_styles()['header_style'] == 'left_side') { ?>
				<header class="site-header with-side <?php echo esc_attr(lauv_styles()['css_classes']) ?> main-row">
					<div class="<?php echo esc_attr(lauv_styles()['header_container']) ?>">
						<div class="logo"><a href="<?php echo esc_url(home_url('/')) ?>"><?php echo wp_kses_post(lauv_styles()['logo_content']) ?></a></div>
						<div class="fr">
							<?php if(has_nav_menu('navigation') && lauv_styles()['navigation_type'] != 'disabled') { ?>
								<nav class="navigation hidden-menu"><?php wp_nav_menu( array( 'theme_location' => 'navigation', 'container' => 'ul', 'menu_class' => 'menu', 'link_before' => '<span>', 'link_after' => '</span>' ) ); ?></nav>
								<div class="nav-button hidden_menu" data-close-label="<?php echo esc_attr__('close', 'lauv') ?>"><?php echo esc_html__('menu', 'lauv') ?></div>
							<?php } ?>
						</div>
					</div>
				</header>
				<div class="side-header main-row <?php echo esc_attr(lauv_styles()['css_classes']) ?>">
					<div class="logo"><a href="<?php echo esc_url(home_url('/')) ?>"><?php echo wp_kses_post(lauv_styles()['logo_content']) ?></a></div>
					<div class="wrap">
						<div class="cell">
							<?php if(has_nav_menu('side-navigation')) { ?>
								<nav class="side-navigation"><?php wp_nav_menu( array( 'theme_location' => 'side-navigation', 'container' => 'ul', 'menu_class' => 'menu', 'link_before' => '<span>', 'link_after' => '</span>', 'walker' => new Child_Wrap(), ) ); ?></nav>
							<?php } ?>
						</div>
					</div>
					<?php if(!empty(lauv_styles()['copyright_text']) || !empty(lauv_styles()['social_buttons_content'])) { ?>
						<div class="bottom">
							<?php if(!empty(lauv_styles()['sidebar_desc'])) { ?>
								<div class="desc">
									<?php echo nl2br(wp_kses_post(lauv_styles()['sidebar_desc'])) ?>
								</div>
							<?php } if(!empty(lauv_styles()['sidebar_contacts'])) { ?>
								<div class="contacts">
									<?php echo nl2br(wp_kses_post(lauv_styles()['sidebar_contacts'])) ?>
								</div>
							<?php } if(lauv_styles()['footer_social_buttons'] == 'show' && !empty(lauv_styles()['social_buttons_content'])) { ?>
								<div class="social-buttons-text">
									<?php echo wp_kses_post(lauv_styles()['social_buttons_content']); ?>
								</div>
							<?php } if(!empty(lauv_styles()['sidebar_copyright_text'])) { ?>
								<div class="copyright">
									<?php echo nl2br(wp_kses_post(lauv_styles()['sidebar_copyright_text'])) ?>
								</div>
							<?php } ?>
						</div>
					<?php } ?>
				</div>
			<?php } ?>
			<?php if(lauv_styles()['header_space'] == 'yes' && !is_404() || is_page_template('page-coming-soon.php')) { ?>
				<div class="header-space"></div>
			<?php } else { ?>
				<div class="header-space hide"></div>
			<?php } if(is_active_sidebar('sidebar')) { ?>
				<div class="side-bar-area main-row">
					<div class="close base-icons-remove"></div>
					<div class="wrap">
						<?php dynamic_sidebar( 'sidebar' ); ?>
					</div>
					<?php if(!empty(lauv_styles()['sidebar_copyright_text'])) { ?>
						<div class="copyright"><?php echo lauv_styles()['sidebar_copyright_text'] ?></div>
					<?php } ?>
				</div>
			<?php } if(has_nav_menu('navigation') && lauv_styles()['navigation_type'] == 'full_screen') { ?>
				<nav class="full-screen-nav main-row">
					<div class="close base-icons-remove"></div>
					<div class="fsn-container">
						<?php wp_nav_menu( array( 'theme_location' => 'navigation', 'container' => 'ul', 'menu_class' => 'cell' ) ); ?>
					</div>
				</nav>
			<?php } ?>