<?php

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    $opt_name = "lauv_theme";
    $opt_name = apply_filters( 'lauv_theme/opt_name', $opt_name );

    $theme = wp_get_theme();

    $args = array(
        'opt_name'             => $opt_name,
        'display_name'         => $theme->get( 'Name' ),
        'display_version'      => $theme->get( 'Version' ),
        'menu_type'            => 'menu',
        'allow_sub_menu'       => true,
        'menu_title'           => esc_html__( 'Theme Options', 'lauv' ),
        'page_title'           => esc_html__( 'Theme Options', 'lauv' ),
        'google_api_key'       => '',
        'google_update_weekly' => false,
        'async_typography'     => true,
        'admin_bar'            => true,
        'admin_bar_icon'       => 'dashicons-portfolio',
        'admin_bar_priority'   => 50,
        'global_variable'      => '',
        'dev_mode'             => false,
        'update_notice'        => true,
        'customizer'           => true,
        'page_priority'        => null,
        'page_parent'          => 'themes.php',
        'page_permissions'     => 'manage_options',
        'menu_icon'            => '',
        'last_tab'             => '',
        'page_icon'            => 'icon-themes',
        'page_slug'            => '',
        'save_defaults'        => true,
        'default_show'         => false,
        'default_mark'         => '',
        'show_import_export'   => true,
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        'output_tag'           => true,
        'database'             => '',
        'use_cdn'              => true,
        'show_options_object'  => false
    );

    Redux::setArgs( $opt_name, $args );

    // Memory use

    if(function_exists('memory_get_usage')) {
        $memory_get_usage = max( lauv_let_to_num( WP_MEMORY_LIMIT ), lauv_let_to_num( @ini_get( 'memory_limit' ) ) );
        if ( $memory_get_usage < 67108864 ) {
            /* Translators: %1$s: Memory limit, %2$s: Docs link. */
            $memory_get_usage = '<span class="error"><i class="fa fa-exclamation-circle"></i> ' . sprintf( esc_html__( '%1$s - We recommend setting memory to at least 64MB. See: %2$s', 'lauv' ), esc_html( size_format( $memory_get_usage ) ), '<a href="https://codex.wordpress.org/Editing_wp-config.php#Increasing_memory_allocated_to_PHP" target="_blank">' . esc_html__( 'Increasing memory allocated to PHP', 'lauv' ) . '</a>' ) . '</span>';
        } else {
            $memory_get_usage = '<span class="green">' . esc_html( size_format( $memory_get_usage ) ) . '</span>';
        }
    } else {
        $memory_get_usage = '-';
    }

    // Debug mode

    if(( defined( 'WP_DEBUG' ) && WP_DEBUG ) == 1) {
        $debug_mode = '<i class="fa fa-check green"></i>';
    } else {
        $debug_mode = '<i class="fa fa-times red"></i>';
    }

    // Language

    if(function_exists('get_locale')) {
        $language = get_locale();
    } else {
        $language = '-';
    }

    // php version
    if ( version_compare( phpversion(), '7.2', '>=' ) ) {
        $phpversion = '<span class="green">' . esc_html( phpversion() ) . '</span>';
    } else {
        $update_link = ' <a href="https://wordpress.org/support/upgrade-php/" target="_blank">' . esc_html__( 'How to update your PHP version', 'lauv' ) . '</a>';
        $notice = '';
        if ( version_compare( phpversion(), '5.4', '<' ) ) {
            $notice = esc_html__( 'WooCommerce will run under this version of PHP, however, some features such as geolocation are not compatible. Support for this version will be dropped in the next major release. We recommend using PHP version 7.2 or above for greater performance and security.', 'lauv' ) . $update_link;
        } elseif ( version_compare( phpversion(), '5.6', '<' ) ) {
            $notice = esc_html__( 'WooCommerce will run under this version of PHP, however, it has reached end of life. We recommend using PHP version 7.2 or above for greater performance and security.', 'lauv' ) . $update_link;
        } elseif ( version_compare( phpversion(), '7.2', '<' ) ) {
            $notice = esc_html__( 'We recommend using PHP version 7.2 or above for greater performance and security.', 'lauv' ) . $update_link;
        }

        $phpversion = '<span class="error"><i class="fa fa-exclamation-circle"></i> ' . esc_html( phpversion() ) . ' - ' . wp_kses_post( $notice ) . '</span>';
    }

    // max execution time

    if(ini_get( 'max_execution_time' ) < 600 && ini_get( 'max_execution_time' ) != 0 && ini_get( 'max_execution_time' ) != -1) {
        $max_execution_time = ini_get( 'max_execution_time' ).' - <i class="fa fa-times red"></i> '.esc_html__('We recommended 600 and more.', 'lauv');
    } else {
        $max_execution_time = ini_get( 'max_execution_time' );
    }

    // post max size

    if(lauv_let_to_num( ini_get( 'post_max_size' ) ) < 52428800) {
        $post_max_size = '<span class="error">'.size_format(lauv_let_to_num( ini_get( 'post_max_size' ) )).' - <i class="fa fa-times red"></i> '.esc_html__('We recommended  50MB and more.', 'lauv').'</span>';
    } else {
        $post_max_size = '<span class="green">'.size_format(lauv_let_to_num( ini_get( 'post_max_size' ) )).'</span>';
    }

    // max upload size

    if(wp_max_upload_size() < 104857600) {
        $max_upload_size = '<span class="error">'.size_format(wp_max_upload_size()).' - <i class="fa fa-times red"></i> '.esc_html__('We recommended 100MB and more.', 'lauv').'</span>';
    } else {
        $max_upload_size = '<span class="green">'.size_format(wp_max_upload_size()).'</span>';
    }

    $info_html = '
<table class="redux-info-table" cellspacing="0">
    <thead>
        <tr>
            <th colspan="3">'.esc_html__('WordPress Environment', 'lauv').'</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="title">'.esc_html__('Home URL:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The URL of your site`s homepage.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(get_option( 'home' )).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Site URL:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The root URL of your site.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(get_option( 'siteurl' )).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('WP Version:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The version of WordPress installed on your site.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post(get_bloginfo( 'version' )).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('WP Memory Limit:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The maximum amount of memory (RAM) that your site can use at one time.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($memory_get_usage).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('WP Debug Mode:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('Displays whether or not WordPress is in Debug Mode.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($debug_mode).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Language:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The current language used by WordPress. Default = English', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags($language).'</td>
        </tr>
    </tbody>
</table>

<table class="redux-info-table" cellspacing="0">
    <thead>
        <tr>
            <th colspan="3">'.esc_html__('Server Environment', 'lauv').'</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="title">'.esc_html__('Server Info:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('Information about the web server that is currently hosting your site.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags($_SERVER['SERVER_SOFTWARE']).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('PHP Version:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The version of PHP installed on your hosting server.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($phpversion).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('PHP Post Max Size:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The largest file size that can be contained in one post.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($post_max_size).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('PHP Max Execution Time:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The amount of time (in seconds) that your site will spend on a single operation before timing out (to avoid server lockups)', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($max_execution_time).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Max Upload Size:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The largest filesize that can be uploaded to your WordPress installation.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($max_upload_size).'</td>
        </tr>
    </tbody>
</table>
<table class="redux-info-table" cellspacing="0">
    <thead>
        <tr>
            <th colspan="3">'.esc_html__('Theme', 'lauv').'</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="title">'.esc_html__('Name:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The name of the current active theme.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(wp_get_theme()->get('Name')).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Version:', 'lauv').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The installed version of the current active theme.', 'lauv').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(wp_get_theme()->get('Version')).'</td>
        </tr>
    </tbody>
</table>
    ';


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'General', 'lauv' ),
        'id'               => 'general',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-home',
        'fields'     => array(
            array(
                'id'       => 'site_mode',
                'type'     => 'select',
                'title'    => esc_html__('Color mode', 'lauv'), 
                'options'  => array(
                    'dark' => esc_html__('Dark', 'lauv'),
                    'light' => esc_html__('Light', 'lauv'),
                ),
                'default'  => 'light',
            ),
            array(
                'id'       => 'color_scheme',
                'type'     => 'color',
                'title'    => esc_html__('Site color 1', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array(
                    'background-color' => '',
                    
                    'background' => '.hover-style2 .portfolio-item h6:before, .hover-style3 .portfolio-item h6:before, .blog-item .wrap .like, .wpb_text_column ul li:before, .site-content ul li:before, .button-style3, .portfolio-by-category .left-side .current-num',
                    
                    'border-color' => '.filter-button-group button.active, .filter-button-group a.active, .category-buttons a.active, .time-line-item .date',
                    
                    'color' => '.banner .text span, .button-style2, .button-style2:after, .banner .owl-dots .owl-dot.active, .banner-categories ul li a:hover, .social-buttons-text a:hover span, .banner .owl-prev:hover, .banner .owl-next:hover, .navigation li:hover > a, .navigation li.current-menu-item > a, .navigation li.current-menu-ancestor > a, .navigation li.current_page_item > a, .navigation li.current-menu-ancestor > a, .navigation .sub-menu li:hover > a, .navigation .sub-menu li.current-menu-item.menu-item-has-children:after, .navigation .sub-menu li:hover.menu-item-has-children:after, .navigation .children li.current_page_item > a, .navigation .children li.current-menu-ancestor > a, .navigation .children li:hover > a, .navigation .children li.current_page_item.page_item_has_children:after, .navigation .children li:hover.page_item_has_children:after, .navigation .sub-menu li.menu-item-has-children > a:after, .navigation .children li.page_item_has_children > a:after, .portfolio-categories .categories-links ul li.active, .portfolio-categories .categories-links ul li:hover, .filter-button-group button.active, .filter-button-group a.active, .category-buttons a.active, .button-style1, .side-navigation li.current-menu-item > a, .side-navigation li.current-menu-parent > a, .side-navigation li.current-menu-ancestor > a, .side-navigation li.current_page_item > a, .side-navigation li:hover > a, .side-header .social-buttons-text a, .project-slider .owl-prev:hover, .project-slider .owl-next:hover, .project-slider .owl-dots .owl-dot.active, .social-buttons-text.label-on a span, .social-buttons-text a:hover span, .about-img-text .button-style2:after, .time-line-items .owl-prev, .time-line-items .owl-next, .blog-item .wrap .blog-detail, .site-content .blog-detail, .post-nav a, .logged-links, .portfolio-by-category .left-side .tab-h .tab-h-item.active, .portfolio-by-category .left-side .social-buttons-text span, .portfolio-by-category .left-side .text span, .portfolio-by-category .cat-link-item i, .nav-button:hover, .preloader-type2 .sub-h, .contact-row i, .blog-post-widget .item .blog-detail',
                    
                    'stroke' => ''
                ),
            ),
            array(
                'id'       => 'right_click_disable',
                'type'     => 'switch',
                'title'    => esc_html__('Right click disable', 'lauv'),
                'default'  => false,
            ),
            array(
                'id'       => 'right_click_disable_message',
                'type'     => 'editor',
                'title'    => esc_html__('Message', 'lauv'),
                'default'  => __('<p style="text-align: center"><strong><span style="font-size: 18px">Content is protected. Right-click function is disabled.</span></strong></p>', 'lauv'),
                'args'   => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5
                ),
                'required' => array('right_click_disable','=',1)
            ),
            array(
                'id'       => 'protected_message',
                'type'     => 'editor',
                'title'    => esc_html__('Protected Page Message', 'lauv'),
                'default'  => esc_html__( 'This content is password protected. To view it please enter your password below:', 'lauv' ),
                'args'   => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5
                ),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Preloader', 'lauv' ),
        'id'               => 'general_preloader',
        'customizer_width' => '450px',
        'subsection'       => true,
        'icon'             => 'fa fa-spinner',
        'fields'     => array(
            array(
                'id'       => 'preloader_show',
                'type'     => 'switch', 
                'title'    => esc_html__('Preloader', 'lauv'),
                'default'  => true,
            ),
            array(
                'id'       => 'preloader_type',
                'type'     => 'select', 
                'title'    => esc_html__('Preloader type', 'lauv'),
                'options'  => array(
                    'default' => esc_html__('Default', 'lauv'),
                    'cube' => esc_html__('Cube', 'lauv'),
                    'custom_image' => esc_html__('Custom image', 'lauv'),
                ),
                'default'  => 'default',
                'required' => array('preloader_show','=',1)
            ),
            array(
                'id'       => 'preloader_label1',
                'type'     => 'text', 
                'title'    => esc_html__('Preloader label 1', 'lauv'),
                'required' => array('preloader_type','=','default')
            ),
            array(
                'id'       => 'preloader_label2',
                'type'     => 'text', 
                'title'    => esc_html__('Preloader label 2', 'lauv'),
                'required' => array('preloader_type','=','default')
            ),
            array(
                'id'       => 'preloader_bg_color',
                'type'     => 'color',
                'title'    => esc_html__('Preloader background color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background' => '.preloader, .preloader-area, .preloader-type2, .site-dark .preloader-type2'),
                'required' => array('preloader_show','=',1)
            ),
            array(
                'id'       => 'preloader_color',
                'type'     => 'color',
                'title'    => esc_html__('Preloader color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background' => '.preloader-folding-cube .preloader-cube:before, .preloader-type2, .site-dark .preloader-type2'),
                'required' => array('preloader_show','=',1)
            ),
            array( 
                'id'       => 'preloader_img',
                'type'     => 'background',
                'title'    => esc_html__('Prelaoder image', 'lauv'),
                'desc'     => esc_html__('Choose a default logo image to display' ,'lauv'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
                'required' => array('preloader_type','=','custom_image')
            ),
        )
    ) );


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Header', 'lauv' ),
        'id'               => 'header',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-header',
        'fields'           => array(
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Logo', 'lauv' ),
        'id'               => 'header_logo',
        'customizer_width' => '450px',
        'subsection'       => true,
        'icon'             => 'fa fa-flag',
        'fields'     => array(
            array(
                'id'       => 'logo_text',
                'type'     => 'text',
                'title'    => esc_html__('Logo text', 'lauv'),
            ),
            array( 
                'id'       => 'default_logo',
                'type'     => 'background',
                'title'    => esc_html__('Logo Image - normal', 'lauv'),
                'desc'     => esc_html__('Choose a default logo image to display' ,'lauv'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array( 
                'id'       => 'light_logo',
                'type'     => 'background',
                'title'    => esc_html__('Logo Image - light', 'lauv'),
                'desc'     => esc_html__('Choose a logo image to display for "Light" header skin' ,'lauv'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array( 
                'id'       => 'dark_logo',
                'type'     => 'background',
                'title'    => esc_html__('Logo Image - Dark', 'lauv'),
                'desc'     => esc_html__('Choose a logo image to display for "Dark" header skin' ,'lauv'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => 'logo_size',
                'units'    => 'px',
                'type'     => 'dimensions',
                'units_extended' => 'false',
                'title'    => esc_html__('Logo max width', 'lauv'),
                'output'      => array('.site-header .logo img, .side-header .logo img, .site-header .logo a, .side-header .logo a'),
                'height'   => true,
                'default'  => array(
                    'Width'   => '85'
                ),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Header style', 'lauv' ),
        'id'               => 'header_style',
        'customizer_width' => '450px',
        'subsection'       => true,
        'icon'             => 'fa fa-sliders',
        'fields'     => array(
            array(
                'id'       => 'header_container',
                'type'     => 'select',
                'title'    => esc_html__('Header container', 'lauv'), 
                'options'  => array(
                    'container' => esc_html__('Center container', 'lauv'),
                    'container-fluid' => esc_html__('Full witdh', 'lauv'),
                ),
                'default'  => 'container',
            ),
            array(
                'id'       => 'header_color_mode',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'lauv'), 
                'options'  => array(
                    'dark' => esc_html__('Dark', 'lauv'),
                    'light' => esc_html__('Light', 'lauv'),
                ),
                'default'  => 'light',
            ),
            array(
                'id'       => 'header_bg_color_light',
                'type'     => 'color',
                'title'    => esc_html__('Header Background Color for Light', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background-color' => '.site-header.light:before'),
            ),
            array(
                'id'       => 'header_bg_color_dark',
                'type'     => 'color',
                'title'    => esc_html__('Header Background Color for Dark', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background-color' => '.site-header.dark:before'),
            ),
            array(
                'id'       => 'header_text_light_color',
                'type'     => 'color',
                'title'    => esc_html__('Header Text Color for Light', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.site-header.light'),
            ),
            array(
                'id'       => 'header_text_dark_color',
                'type'     => 'color',
                'title'    => esc_html__('Header Text Color for Dark', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.site-header.dark'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Navigation', 'lauv' ),
        'id'               => 'header_navigation',
        'customizer_width' => '450px',
        'subsection'       => true,
        'icon'             => 'fa fa-bars',
        'fields'     => array(
            array(
                'id'       => 'navigation_type',
                'type'     => 'select',
                'title'    => esc_html__('Navigation type', 'lauv'), 
                'options'  => array(
                    'disabled' => esc_html__('Disabled', 'lauv'),
                    'hidden_menu' => esc_html__('Hidden menu', 'lauv'),
                    'visible_menu' => esc_html__('Visible menu', 'lauv'),
                    'full_screen' => esc_html__('Full screen menu', 'lauv'),
                    'side' => esc_html__('Side', 'lauv'),
                ),
                'default'  => 'visible_menu',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Sidebar', 'lauv' ),
        'id'               => 'header_sidebar',
        'customizer_width' => '450px',
        'subsection'       => true,
        'icon'             => 'fa fa-list',
        'fields'     => array(
            array(
                'id'       => 'sidebar_desc',
                'type'     => 'textarea',
                'title'    => esc_html__('Desc', 'lauv'),
            ),
            array(
                'id'       => 'sidebar_contacts',
                'type'     => 'textarea',
                'title'    => esc_html__('Contacts', 'lauv'),
            ),
            array(
                'id'       => 'sidebar_copyright_text',
                'type'     => 'textarea',
                'title'    => esc_html__('Copyright', 'lauv'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Typography', 'lauv' ),
        'id'               => 'typography',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-font',
        'fields'     => array(
            array(
                'id'          => 'body-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('Body', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('body'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'all_styles' => true,
                'default'     => array(
                    'color'       => '#121212', 
                    'font-style'  => '400', 
                    'font-family' => 'Roboto', 
                    'google'      => true,
                    'font-size'   => '16px',
                ),
            ),
            array(
                'id'          => 'h1-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H1', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h1, .h1'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Roboto', 
                    'google'      => true,
                    'font-size'   => '60px',
                ),
            ),
            array(
                'id'          => 'h2-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H2', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h2, .h2'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Roboto', 
                    'google'      => true,
                    'font-size'   => '48px',
                ),
            ),
            array(
                'id'          => 'h3-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H3', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h3, .h3'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Roboto', 
                    'google'      => true,
                    'font-size'   => '36px',
                ),
            ),
            array(
                'id'          => 'h4-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H4', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h4, .h4'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Roboto', 
                    'google'      => true,
                    'font-size'   => '30px',
                ),
            ),
            array(
                'id'          => 'h5-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H5', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h5, .h5'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Roboto', 
                    'google'      => true,
                    'font-size'   => '24px',
                ),
            ),
            array(
                'id'          => 'h6-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H6', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h6, .h6'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Roboto', 
                    'google'      => true,
                    'font-size'   => '18px',
                ),
            ),
            array(
                'id'          => 'additional-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
            array(
                'id'          => 'additional-font-face2',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face 2', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
            array(
                'id'          => 'additional-font-face3',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face 3', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
            array(
                'id'          => 'additional-font-face4',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face 4', 'lauv'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Social buttons', 'lauv' ),
        'id'               => 'social_buttons',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-twitter',
        'fields'     => array(
            array(
                'id'       => 'social_target',
                'type'     => 'select',
                'title'    => esc_html__('Open link in', 'lauv'), 
                'options'  => array(
                    '_self' => esc_html__('Current Tab', 'lauv'),
                    '_blank' => esc_html__('New Tab', 'lauv'),
                ),
            ),
            array(
                'id'       => 'sl1',
                'type'     => 'label',
                'title'    => esc_html__('Social button 1', 'lauv'),
            ),
            array(
                'id'       => 'social_icon1',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'lauv'), 
                'options'  => array(
                    '' => esc_html__('---', 'lauv'),
                    'fa fa-500px,500px' => esc_html__('500px', 'lauv'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'lauv'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'lauv'),
                    'social-media-icons-dropbox,Dropbox' => esc_html__('Dropbox', 'lauv'),
                    'social-media-icons-facebook,Facebook' => esc_html__('Facebook', 'lauv'),
                    'social-media-icons-flickr,Flickr' => esc_html__('Flickr', 'lauv'),
                    'fa fa-foursquare,Foursquare' => esc_html__('Foursquare', 'lauv'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'lauv'),
                    'fa fa-google,Google' => esc_html__('Google', 'lauv'),
                    'social-media-icons-instagram,Instagram' => esc_html__('Instagram', 'lauv'),
                    'social-media-icons-linkedin,LinkedIn' => esc_html__('LinkedIn', 'lauv'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'lauv'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'lauv'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'lauv'),
                    'social-media-icons-pinterest,Pinterest' => esc_html__('Pinterest', 'lauv'),
                    'social-media-icons-reddit,Reddit' => esc_html__('Reddit', 'lauv'),
                    'social-media-icons-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'lauv'),
                    'social-media-icons-tumblr,Tumblr' => esc_html__('Tumblr', 'lauv'),
                    'social-media-icons-twitter,Twitter' => esc_html__('Twitter', 'lauv'),
                    'social-media-icons-vimeo,Vimeo' => esc_html__('Vimeo', 'lauv'),
                    'fa fa-vk,VK' => esc_html__('VK', 'lauv'),
                    'social-media-icons-yahoo,Yahoo' => esc_html__('Yahoo', 'lauv'),
                    'social-media-icons-youtube,Youtube' => esc_html__('Youtube', 'lauv'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link1',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'lauv'),
            ),
            array(
                'id'       => 'sb2',
                'type'     => 'label',
                'title'    => esc_html__('Social button 2', 'lauv'),
            ),
            array(
                'id'       => 'social_icon2',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'lauv'), 
                'options'  => array(
                    '' => esc_html__('---', 'lauv'),
                    'fa fa-500px,500px' => esc_html__('500px', 'lauv'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'lauv'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'lauv'),
                    'social-media-icons-dropbox,Dropbox' => esc_html__('Dropbox', 'lauv'),
                    'social-media-icons-facebook,Facebook' => esc_html__('Facebook', 'lauv'),
                    'social-media-icons-flickr,Flickr' => esc_html__('Flickr', 'lauv'),
                    'fa fa-foursquare,Foursquare' => esc_html__('Foursquare', 'lauv'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'lauv'),
                    'fa fa-google,Google' => esc_html__('Google', 'lauv'),
                    'social-media-icons-instagram,Instagram' => esc_html__('Instagram', 'lauv'),
                    'social-media-icons-linkedin,LinkedIn' => esc_html__('LinkedIn', 'lauv'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'lauv'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'lauv'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'lauv'),
                    'social-media-icons-pinterest,Pinterest' => esc_html__('Pinterest', 'lauv'),
                    'social-media-icons-reddit,Reddit' => esc_html__('Reddit', 'lauv'),
                    'social-media-icons-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'lauv'),
                    'social-media-icons-tumblr,Tumblr' => esc_html__('Tumblr', 'lauv'),
                    'social-media-icons-twitter,Twitter' => esc_html__('Twitter', 'lauv'),
                    'social-media-icons-vimeo,Vimeo' => esc_html__('Vimeo', 'lauv'),
                    'fa fa-vk,VK' => esc_html__('VK', 'lauv'),
                    'social-media-icons-yahoo,Yahoo' => esc_html__('Yahoo', 'lauv'),
                    'social-media-icons-youtube,Youtube' => esc_html__('Youtube', 'lauv'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link2',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'lauv'),
            ),
            array(
                'id'       => 'sb3',
                'type'     => 'label',
                'title'    => esc_html__('Social button 3', 'lauv'),
            ),
            array(
                'id'       => 'social_icon3',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'lauv'), 
                'options'  => array(
                    '' => esc_html__('---', 'lauv'),
                    'fa fa-500px,500px' => esc_html__('500px', 'lauv'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'lauv'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'lauv'),
                    'social-media-icons-dropbox,Dropbox' => esc_html__('Dropbox', 'lauv'),
                    'social-media-icons-facebook,Facebook' => esc_html__('Facebook', 'lauv'),
                    'social-media-icons-flickr,Flickr' => esc_html__('Flickr', 'lauv'),
                    'fa fa-foursquare,Foursquare' => esc_html__('Foursquare', 'lauv'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'lauv'),
                    'fa fa-google,Google' => esc_html__('Google', 'lauv'),
                    'social-media-icons-instagram,Instagram' => esc_html__('Instagram', 'lauv'),
                    'social-media-icons-linkedin,LinkedIn' => esc_html__('LinkedIn', 'lauv'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'lauv'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'lauv'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'lauv'),
                    'social-media-icons-pinterest,Pinterest' => esc_html__('Pinterest', 'lauv'),
                    'social-media-icons-reddit,Reddit' => esc_html__('Reddit', 'lauv'),
                    'social-media-icons-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'lauv'),
                    'social-media-icons-tumblr,Tumblr' => esc_html__('Tumblr', 'lauv'),
                    'social-media-icons-twitter,Twitter' => esc_html__('Twitter', 'lauv'),
                    'social-media-icons-vimeo,Vimeo' => esc_html__('Vimeo', 'lauv'),
                    'fa fa-vk,VK' => esc_html__('VK', 'lauv'),
                    'social-media-icons-yahoo,Yahoo' => esc_html__('Yahoo', 'lauv'),
                    'social-media-icons-youtube,Youtube' => esc_html__('Youtube', 'lauv'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link3',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'lauv'),
            ),
            array(
                'id'       => 'sb4',
                'type'     => 'label',
                'title'    => esc_html__('Social button 4', 'lauv'),
            ),
            array(
                'id'       => 'social_icon4',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'lauv'), 
                'options'  => array(
                    '' => esc_html__('---', 'lauv'),
                    'fa fa-500px,500px' => esc_html__('500px', 'lauv'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'lauv'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'lauv'),
                    'social-media-icons-dropbox,Dropbox' => esc_html__('Dropbox', 'lauv'),
                    'social-media-icons-facebook,Facebook' => esc_html__('Facebook', 'lauv'),
                    'social-media-icons-flickr,Flickr' => esc_html__('Flickr', 'lauv'),
                    'fa fa-foursquare,Foursquare' => esc_html__('Foursquare', 'lauv'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'lauv'),
                    'fa fa-google,Google' => esc_html__('Google', 'lauv'),
                    'social-media-icons-instagram,Instagram' => esc_html__('Instagram', 'lauv'),
                    'social-media-icons-linkedin,LinkedIn' => esc_html__('LinkedIn', 'lauv'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'lauv'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'lauv'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'lauv'),
                    'social-media-icons-pinterest,Pinterest' => esc_html__('Pinterest', 'lauv'),
                    'social-media-icons-reddit,Reddit' => esc_html__('Reddit', 'lauv'),
                    'social-media-icons-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'lauv'),
                    'social-media-icons-tumblr,Tumblr' => esc_html__('Tumblr', 'lauv'),
                    'social-media-icons-twitter,Twitter' => esc_html__('Twitter', 'lauv'),
                    'social-media-icons-vimeo,Vimeo' => esc_html__('Vimeo', 'lauv'),
                    'fa fa-vk,VK' => esc_html__('VK', 'lauv'),
                    'social-media-icons-yahoo,Yahoo' => esc_html__('Yahoo', 'lauv'),
                    'social-media-icons-youtube,Youtube' => esc_html__('Youtube', 'lauv'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link4',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'lauv'),
            ),
            array(
                'id'       => 'sb5',
                'type'     => 'label',
                'title'    => esc_html__('Social button 5', 'lauv'),
            ),
            array(
                'id'       => 'social_icon5',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'lauv'), 
                'options'  => array(
                    '' => esc_html__('---', 'lauv'),
                    'fa fa-500px,500px' => esc_html__('500px', 'lauv'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'lauv'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'lauv'),
                    'social-media-icons-dropbox,Dropbox' => esc_html__('Dropbox', 'lauv'),
                    'social-media-icons-facebook,Facebook' => esc_html__('Facebook', 'lauv'),
                    'social-media-icons-flickr,Flickr' => esc_html__('Flickr', 'lauv'),
                    'fa fa-foursquare,Foursquare' => esc_html__('Foursquare', 'lauv'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'lauv'),
                    'fa fa-google,Google' => esc_html__('Google', 'lauv'),
                    'social-media-icons-instagram,Instagram' => esc_html__('Instagram', 'lauv'),
                    'social-media-icons-linkedin,LinkedIn' => esc_html__('LinkedIn', 'lauv'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'lauv'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'lauv'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'lauv'),
                    'social-media-icons-pinterest,Pinterest' => esc_html__('Pinterest', 'lauv'),
                    'social-media-icons-reddit,Reddit' => esc_html__('Reddit', 'lauv'),
                    'social-media-icons-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'lauv'),
                    'social-media-icons-tumblr,Tumblr' => esc_html__('Tumblr', 'lauv'),
                    'social-media-icons-twitter,Twitter' => esc_html__('Twitter', 'lauv'),
                    'social-media-icons-vimeo,Vimeo' => esc_html__('Vimeo', 'lauv'),
                    'fa fa-vk,VK' => esc_html__('VK', 'lauv'),
                    'social-media-icons-yahoo,Yahoo' => esc_html__('Yahoo', 'lauv'),
                    'social-media-icons-youtube,Youtube' => esc_html__('Youtube', 'lauv'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link5',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'lauv'),
            ),
            array(
                'id'       => 'sb6',
                'type'     => 'label',
                'title'    => esc_html__('Social button 6', 'lauv'),
            ),
            array(
                'id'       => 'social_icon6',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'lauv'), 
                'options'  => array(
                    '' => esc_html__('---', 'lauv'),
                    'fa fa-500px,500px' => esc_html__('500px', 'lauv'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'lauv'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'lauv'),
                    'social-media-icons-dropbox,Dropbox' => esc_html__('Dropbox', 'lauv'),
                    'social-media-icons-facebook,Facebook' => esc_html__('Facebook', 'lauv'),
                    'social-media-icons-flickr,Flickr' => esc_html__('Flickr', 'lauv'),
                    'fa fa-foursquare,Foursquare' => esc_html__('Foursquare', 'lauv'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'lauv'),
                    'fa fa-google,Google' => esc_html__('Google', 'lauv'),
                    'social-media-icons-instagram,Instagram' => esc_html__('Instagram', 'lauv'),
                    'social-media-icons-linkedin,LinkedIn' => esc_html__('LinkedIn', 'lauv'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'lauv'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'lauv'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'lauv'),
                    'social-media-icons-pinterest,Pinterest' => esc_html__('Pinterest', 'lauv'),
                    'social-media-icons-reddit,Reddit' => esc_html__('Reddit', 'lauv'),
                    'social-media-icons-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'lauv'),
                    'social-media-icons-tumblr,Tumblr' => esc_html__('Tumblr', 'lauv'),
                    'social-media-icons-twitter,Twitter' => esc_html__('Twitter', 'lauv'),
                    'social-media-icons-vimeo,Vimeo' => esc_html__('Vimeo', 'lauv'),
                    'fa fa-vk,VK' => esc_html__('VK', 'lauv'),
                    'social-media-icons-yahoo,Yahoo' => esc_html__('Yahoo', 'lauv'),
                    'social-media-icons-youtube,Youtube' => esc_html__('Youtube', 'lauv'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link6',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'lauv'),
            ),
            array(
                'id'       => 'sb7',
                'type'     => 'label',
                'title'    => esc_html__('Social button 7', 'lauv'),
            ),
            array(
                'id'       => 'social_icon7',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'lauv'), 
                'options'  => array(
                    '' => esc_html__('---', 'lauv'),
                    'fa fa-500px,500px' => esc_html__('500px', 'lauv'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'lauv'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'lauv'),
                    'social-media-icons-dropbox,Dropbox' => esc_html__('Dropbox', 'lauv'),
                    'social-media-icons-facebook,Facebook' => esc_html__('Facebook', 'lauv'),
                    'social-media-icons-flickr,Flickr' => esc_html__('Flickr', 'lauv'),
                    'fa fa-foursquare,Foursquare' => esc_html__('Foursquare', 'lauv'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'lauv'),
                    'fa fa-google,Google' => esc_html__('Google', 'lauv'),
                    'social-media-icons-instagram,Instagram' => esc_html__('Instagram', 'lauv'),
                    'social-media-icons-linkedin,LinkedIn' => esc_html__('LinkedIn', 'lauv'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'lauv'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'lauv'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'lauv'),
                    'social-media-icons-pinterest,Pinterest' => esc_html__('Pinterest', 'lauv'),
                    'social-media-icons-reddit,Reddit' => esc_html__('Reddit', 'lauv'),
                    'social-media-icons-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'lauv'),
                    'social-media-icons-tumblr,Tumblr' => esc_html__('Tumblr', 'lauv'),
                    'social-media-icons-twitter,Twitter' => esc_html__('Twitter', 'lauv'),
                    'social-media-icons-vimeo,Vimeo' => esc_html__('Vimeo', 'lauv'),
                    'fa fa-vk,VK' => esc_html__('VK', 'lauv'),
                    'social-media-icons-yahoo,Yahoo' => esc_html__('Yahoo', 'lauv'),
                    'social-media-icons-youtube,Youtube' => esc_html__('Youtube', 'lauv'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link7',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'lauv'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Footer', 'lauv' ),
        'id'               => 'footer',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-th-list',
        'fields'     => array(
            array(
                'id'       => 'footer',
                'type'     => 'select',
                'title'    => esc_html__('Footer', 'lauv'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'lauv'),
                    'hide' => esc_html__('Hide', 'lauv'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'footer_social_buttons',
                'type'     => 'select',
                'title'    => esc_html__('Footer Social Buttons', 'lauv'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'lauv'),
                    'hide' => esc_html__('Hide', 'lauv'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'copyright_text',
                'type'     => 'textarea',
                'title'    => esc_html__('Copyright text', 'lauv'),
            ),
            array(
                'id'       => 'contacts_text',
                'type'     => 'textarea',
                'title'    => esc_html__('Contacts text', 'lauv'),
            ),
            array(
                'id'       => 'address_text',
                'type'     => 'textarea',
                'title'    => esc_html__('Address text', 'lauv'),
            ),
            array(
                'id'       => 'footer_logo_size',
                'units'    => 'px',
                'type'     => 'dimensions',
                'units_extended' => 'false',
                'title'    => esc_html__('Logo max width', 'lauv'),
                'output'      => array('.site-footer .logo img'),
                'height'   => false,
                'default'  => array(
                    'Width'   => '46'
                ),
            ),
            array(
                'id'       => 'footer_bg_color',
                'type'     => 'color',
                'title'    => esc_html__('Footer Background Color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background-color' => '.site-footer .footer-wrap'),
            ),
            array(
                'id'       => 'footer_text_color',
                'type'     => 'color',
                'title'    => esc_html__('Footer Text Color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.site-footer .footer-wrap'),
            ),
            array(
                'id'       => 'footer_bottom_bg_color',
                'type'     => 'color',
                'title'    => esc_html__('Footer Bottom Background Color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background-color' => '.site-footer'),
            ),
            array(
                'id'       => 'footer_bottom_text_color',
                'type'     => 'color',
                'title'    => esc_html__('Footer Bottom Text Color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.site-footer'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( '404 Page', 'lauv' ),
        'id'               => '404_page',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-exclamation-circle',
        'fields'     => array(
            array(
                'id'       => 'header_color_mode_404',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'lauv'), 
                'options'  => array(
                    'dark' => esc_html__('Dark', 'lauv'),
                    'light' => esc_html__('Light', 'lauv'),
                ),
                'default'  => 'light',
            ),
            array( 
                'id'       => '404_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background image', 'lauv'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => '404_page_color',
                'type'     => 'color',
                'title'    => esc_html__('Text color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-404'),
            ),
            array(
                'id'       => '404_page_heading_color',
                'type'     => 'color',
                'title'    => esc_html__('Heading color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-404 .b-404-heading'),
            ),
            array(
                'id'       => '404_page_text',
                'type'     => 'textarea',
                'title'    => esc_html__('Text', 'lauv'),
                'default'  => __('<span>404 error</span><br>This page doesn`t exist', 'lauv'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Coming soon page', 'lauv' ),
        'id'               => 'coming_soon',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-clock-o',
        'fields'     => array(
            array(
                'id'       => 'header_color_mode_coming_soon',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'lauv'), 
                'options'  => array(
                    'dark' => esc_html__('Dark', 'lauv'),
                    'light' => esc_html__('Light', 'lauv'),
                ),
                'default'  => 'light',
            ),
            array( 
                'id'       => 'coming_soon_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background image', 'lauv'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => 'coming_soon_color',
                'type'     => 'color',
                'title'    => esc_html__('Text color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-coming-soon'),
            ),
            array(
                'id'       => 'coming_soon_heading_color',
                'type'     => 'color',
                'title'    => esc_html__('Heading color', 'lauv'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-coming-soon .b-coming-heading'),
            ),
            array(
                'id'       => 'coming_soon_heading',
                'type'     => 'textarea',
                'title'    => esc_html__('Heading', 'lauv'),
                'default'  => esc_html__('coming soon', 'lauv'),
            ),
            array(
                'id'       => 'coming_soon_subscribe_desc',
                'type'     => 'textarea',
                'title'    => esc_html__('Subscribe form desc', 'lauv'),
                'default'  => esc_html__('subscribe for more', 'lauv'),
            ),
            array(
                'id'       => 'coming_soon_subscribe_code',
                'type'     => 'text',
                'title'    => esc_html__('Subscribe form code', 'lauv'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Project page', 'lauv' ),
        'id'               => 'project_page',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-file-text',
        'fields'     => array(
            array(
                'id'       => 'project_style',
                'type'     => 'select',
                'title'    => esc_html__('Style project page', 'lauv'), 
                'options'  => array(
                    'left_side' => esc_html__('Images on left side', 'lauv'),
                    'right_side' => esc_html__('Images on right side', 'lauv'),
                    'slider' => esc_html__('Slider', 'lauv'),
                    'masonry' => esc_html__('Masonry', 'lauv'),
                    'horizontal' => esc_html__('Horizontal', 'lauv'),
                ),
                'default'  => 'slider',
            ),
            array(
                'id'       => 'project_image',
                'type'     => 'select',
                'title'    => esc_html__('Project image', 'lauv'), 
                'options'  => array(
                    'disable' => esc_html__('Disable', 'lauv'),
                    'full' => esc_html__('Full', 'lauv'),
                    'adaptive' => esc_html__('Adaptive', 'lauv'),
                ),
                'default'  => 'full',
            ),
            array(
                'id'       => 'download-link',
                'type'     => 'select',
                'title'    => esc_html__('Download link on popup', 'lauv'), 
                'options'  => array(
                    'yes' => esc_html__('Show', 'lauv'),
                    'no' => esc_html__('Hide', 'lauv'),
                ),
                'default'  => 'yes',
            ),
            array(
                'id'       => 'project-details',
                'type'     => 'select',
                'title'    => esc_html__('Project details', 'lauv'), 
                'options'  => array(
                    'yes' => esc_html__('Show', 'lauv'),
                    'no' => esc_html__('Hide', 'lauv'),
                ),
                'default'  => 'yes',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Blog post', 'lauv' ),
        'id'               => 'blog_post',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-wordpress',
        'fields'     => array(
            array(
                'id'       => 'blog_feature_image',
                'type'     => 'select',
                'title'    => esc_html__('Blog feature image', 'lauv'), 
                'options'  => array(
                    'hide' => esc_html__('Hide', 'lauv'),
                    'show' => esc_html__('Show', 'lauv'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_date',
                'type'     => 'select',
                'title'    => esc_html__('Show date', 'lauv'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'lauv'),
                    'hide' => esc_html__('Hide', 'lauv'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_like',
                'type'     => 'select',
                'title'    => esc_html__('Show like', 'lauv'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'lauv'),
                    'hide' => esc_html__('Hide', 'lauv'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_comment_count',
                'type'     => 'select',
                'title'    => esc_html__('Show comment count', 'lauv'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'lauv'),
                    'hide' => esc_html__('Hide', 'lauv'),
                ),
                'default'  => 'show',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Google Maps API', 'lauv' ),
        'id'               => 'google_maps_api',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-map-pin',
        'fields'     => array(
            array(
                'id'       => 'google_maps_api_key',
                'type'     => 'text',
                'title'    => esc_html__('Google Map API Key', 'lauv'), 
                'description' => __('Create an application in <a href="https://console.developers.google.com/flows/enableapi?apiid=places_backend,maps_backend,geocoding_backend,directions_backend,distance_matrix_backend,elevation_backend&keyType=CLIENT_SIDE&reusekey=true" target="_blank">Google Console</a> and add the Key here.', 'lauv'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Site info', 'lauv' ),
        'id'               => 'site_info',
        'customizer_width' => '400px',
        'icon'             => 'el el-info-circle',
        'fields'     => array(
            array(
                'id'       => 'opt-raw_info_4',
                'type'     => 'raw',
                'title'    => false,
                'content'  => $info_html,
            ),
        )
    ) );

    if(!function_exists('redux_register_custom_extension_loader')) :
        function redux_register_custom_extension_loader($ReduxFramework) {

            $extension_class = 'ReduxFramework_Extension_tlm';
            if ( ! class_exists( $extension_class ) ) {
                $class_file = dirname( __FILE__ ) . '/extensions/tlm/extension_tlm.php';
                $class_file = apply_filters( 'redux/extension/' . $ReduxFramework->args['opt_name'] . '/tlm', $class_file );
                if ( $class_file ) {
                    require_once( $class_file );
                }
            }
            if ( ! isset( $ReduxFramework->extensions[ 'tlm' ] ) ) {
                $ReduxFramework->extensions[ 'tlm' ] = new $extension_class( $ReduxFramework );
            }
        }

        add_action("redux/extensions/{$opt_name}/before", 'redux_register_custom_extension_loader', 0);
    endif;
