<?php

// Element Description: PT Banner

class PT_Banner extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_banner_mapping' ) );
        add_shortcode( 'pt_banner', array( $this, 'pt_banner_html' ) );
        add_shortcode( 'pt_banner_item', array( $this, 'pt_banner_item_html' ) );
    }

    public static function get_all_post_category( $param = 'All' ) {
        $taxonomy = 'category';
        $args     = array(
            'hide_empty' => true,
        );

        $terms     = get_terms( $taxonomy, $args );
        $result    = array();
        //$result[0] = $param;

        if ( ! empty( $terms ) && !is_wp_error( $terms ) ) {
            foreach ( $terms as $term ) {
                $name = get_category_parents($term->term_id);
                $name = trim($name, '/');
                $result[ 'ID ['.$term->term_id.'] '.$name ] = $term->term_id;
            }
        }

        return $result;
    }
    public static function get_all_portfolio_category( $param = 'All' ) {
        $taxonomy = 'pt-portfolio-category';
        $args     = array(
            'hide_empty' => true,
        );

        $terms     = get_terms( $taxonomy, $args );
        $result    = array();
        //$result[0] = $param;

        if ( ! empty( $terms ) && !is_wp_error( $terms ) ) {
            foreach ( $terms as $term ) {
                $name = $term->name;
                $result[ 'ID ['.$term->term_id.'] '.$name ] = $term->term_id;
            }
        }

        return $result;
    }
     
    // Element Mapping
    public function pt_banner_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Banner", "lauv"),
            "base" => "pt_banner",
            "as_parent" => array('only' => 'pt_banner_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "is_container" => true,
            "icon" => "shortcode-icon-banner",
            "category" => esc_html__("By PT", "lauv"),
            "params" => array(
                array(
                    "type"        => "el_id",
                    "heading"     => esc_html__( "Uniq ID", "lauv" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                    "group"       => esc_html__("General", "lauv"),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Infinite loop", "lauv" ),
                    "param_name"  => "infinite_loop",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Restart the slider automatically as it passes the last slide.", "lauv" ),
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "dependency"  => "",
                    "default_set" => true,
                    "group"       => esc_html__("General", "lauv"),
                ),
                array(
                    "type"        => "number",
                    "class"       => "",
                    "heading"     => esc_html__( "Transition speed", "lauv" ),
                    "param_name"  => "speed",
                    "value"       => "300",
                    "min"         => "100",
                    "max"         => "10000",
                    "step"        => "100",
                    "suffix"      => "ms",
                    "description" => esc_html__( "Speed at which next slide comes.", "lauv" ),
                    "group"       => esc_html__("General", "lauv"),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Autoplay Slides", "lauv" ),
                    "param_name"  => "autoplay",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Enable Autoplay", "lauv" ),
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "dependency"  => "",
                    "default_set" => true,
                    "group"       => esc_html__("General", "lauv"),
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Autoplay Speed", "lauv" ),
                    "param_name" => "autoplay_speed",
                    "value"      => "5000",
                    "min"        => "100",
                    "max"        => "10000",
                    "step"       => "10",
                    "suffix"     => "ms",
                    "dependency" => Array( "element" => "autoplay", "value" => array( "on" ) ),
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Adaptive Height", "lauv" ),
                    "param_name" => "adaptive_height",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "label" => esc_html__( "Turn on Adaptive Height", "lauv" ),
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Height", "lauv" ),
                    "param_name" => "height",
                    "min"        => "540",
                    "max"        => "1500",
                    "step"       => "10",
                    "suffix"     => "px",
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Content container type", "lauv" ),
                    "param_name"  => "container",
                    "value"       => array(
                        esc_html__( "Container", "lauv" ) => "container",
                        esc_html__( "Container fluid", "lauv" ) => "container-fluid",
                    ),
                    "std"         => "container-fluid",
                    "group"       => esc_html__("General", "lauv"),
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Paddings", "lauv" ),
                    "param_name" => "paddings",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Show categories", "lauv" ),
                    "param_name"  => "categories",
                    "value"       => "off",
                    "dependency"  => Array( "element" => "paddings", "value" => array( "on" ) ),
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => false,
                    "group"       => esc_html__("General", "lauv"),
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Social buttons", "lauv" ),
                    "param_name" => "social_buttons",
                    "value"      => "on",
                    "dependency"  => Array( "element" => "paddings", "value" => array( "on" ) ),
                    "options"    => array(
                        "on" => array(
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Social buttons color", "lauv"),
                    "param_name" => "social_buttons_color",
                    "dependency" => Array( "element" => "social_buttons", "value" => array( "on" ) ),
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Navigation Buttons", "lauv" ),
                    "param_name"  => "arrows",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__("Navigation", "lauv"),
                ),
                array(
                    "type"       => "colorpicker",
                    "heading"    => esc_html__( "Navigation Buttons Color", "lauv" ),
                    "param_name" => "arrow_color",
                    "dependency" => Array( "element" => "arrows", "value" => array( "on" ) ),
                    "group"      => esc_html__("Navigation", "lauv"),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Pagination", "lauv" ),
                    "param_name"  => "dots",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__("Navigation", "lauv"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Pagination Style", "lauv" ),
                    "param_name"  => "dots_style",
                    "dependency" => Array( "element" => "dots", "value" => array( "on" ) ),
                    "value"      => array(
                        esc_html__( "On bottom", "lauv" ) => "style1",
                        esc_html__( "On side", "lauv" ) => "style2",
                    ),
                    "group"       => esc_html__("Navigation", "lauv"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Pagination color", "lauv"),
                    "param_name" => "dots_color",
                    "dependency" => Array( "element" => "dots", "value" => array( "on" ) ),
                    "group"      => esc_html__("Navigation", "lauv"),
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Pause on hover", "lauv" ),
                    "param_name" => "pauseohover",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "label" => esc_html__( "Pause the slider on hover", "lauv" ),
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                    "dependency" => Array("element" => "autoplay", "value" => "on" ),
                    "group"      => esc_html__("Navigation", "lauv"),
                ),
                array(
                    "type"       => "textfield",
                    "heading"    => esc_html__( "Button label", "lauv" ),
                    "param_name" => "categories_label",
                    "value"      => "categories",
                    "group"      => esc_html__("Category", "lauv"),
                    "dependency" => Array( "element" => "categories", "value" => array( "on" ) ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Categories source", "lauv" ),
                    "param_name"  => "categories_source",
                    "dependency" => Array( "element" => "categories", "value" => array( "on" ) ),
                    "value"      => array(
                        esc_html__( "---", "lauv" ) => "",
                        esc_html__( "Blog", "lauv" ) => "blog",
                        esc_html__( "Portfolio", "lauv" ) => "portfolio",
                        esc_html__( "Custom", "lauv" ) => "custom",
                    ),
                    "group"       => esc_html__("Category", "lauv"),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Categories", "lauv" ),
                    "param_name"  => "categories_blog_items",
                    "dependency"  => Array( "element" => "categories_source", "value" => array( "blog" ) ),
                    "value"       => PT_Banner::get_all_post_category(),
                    "group"       => esc_html__("Category", "lauv"),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Categories", "lauv" ),
                    "param_name"  => "categories_portfolio_items",
                    "dependency"  => Array( "element" => "categories_source", "value" => array( "portfolio" ) ),
                    "value"       => PT_Banner::get_all_portfolio_category(),
                    "group"       => esc_html__("Category", "lauv"),
                ),
                array(
                    "type"       => "vc_link",
                    "heading"    => esc_html__( "1 Category link", "lauv" ),
                    "param_name" => "category_link1",
                    "group"      => esc_html__("Category", "lauv"),
                    "dependency" => Array( "element" => "categories_source", "value" => array( "custom" ) ),
                ),
                array(
                    "type"       => "vc_link",
                    "heading"    => esc_html__( "2 Category link", "lauv" ),
                    "param_name" => "category_link2",
                    "group"      => esc_html__("Category", "lauv"),
                    "dependency" => Array( "element" => "categories_source", "value" => array( "custom" ) ),
                ),
                array(
                    "type"       => "vc_link",
                    "heading"    => esc_html__( "3 Category link", "lauv" ),
                    "param_name" => "category_link3",
                    "group"      => esc_html__("Category", "lauv"),
                    "dependency" => Array( "element" => "categories_source", "value" => array( "custom" ) ),
                ),
                array(
                    "type"       => "vc_link",
                    "heading"    => esc_html__( "4 Category link", "lauv" ),
                    "param_name" => "category_link4",
                    "group"      => esc_html__("Category", "lauv"),
                    "dependency" => Array( "element" => "categories_source", "value" => array( "custom" ) ),
                ),
                array(
                    "type"       => "vc_link",
                    "heading"    => esc_html__( "5 Category link", "lauv" ),
                    "param_name" => "category_link5",
                    "group"      => esc_html__("Category", "lauv"),
                    "dependency" => Array( "element" => "categories_source", "value" => array( "custom" ) ),
                ),
                array(
                    "type"       => "vc_link",
                    "heading"    => esc_html__( "6 Category link", "lauv" ),
                    "param_name" => "category_link6",
                    "group"      => esc_html__("Category", "lauv"),
                    "dependency" => Array( "element" => "categories_source", "value" => array( "custom" ) ),
                ),
                array(
                    "type"       => "vc_link",
                    "heading"    => esc_html__( "7 Category link", "lauv" ),
                    "param_name" => "category_link7",
                    "group"      => esc_html__("Category", "lauv"),
                    "dependency" => Array( "element" => "categories_source", "value" => array( "custom" ) ),
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Banner item", "lauv"),
            "base" => "pt_banner_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-banner",
            "as_child" => array('only' => 'pt_banner'),
            "params" => array(
                array(
                    "type"        => "el_id",
                    "heading"     => esc_html__( "Uniq ID", "lauv" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                    "group"       => esc_html__("General", "lauv"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Background type", "lauv" ),
                    "param_name"  => "background_type",
                    "value"      => array(
                        esc_html__( "Image", "lauv" ) => "image",
                        esc_html__( "Gradient", "lauv" ) => "gradient",
                        esc_html__( "Color", "lauv" ) => "color",
                    ),
                    "group"       => esc_html__("General", "lauv"),
                ),
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Background image", "lauv"),
                    "param_name" => "background_image",
                    "dependency" => Array("element" => "background_type", "value" => "image" ),
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type" => "gradient",
                    "base_gradient" => "#feb332 0%,#d38d14 100%",
                    "base_orientation" => "vertical",
                    "heading" => esc_html__("Background gradient", "lauv"),
                    "param_name" => "background_gradient",
                    "dependency" => Array("element" => "background_type", "value" => "gradient" ),
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Background color", "lauv"),
                    "param_name" => "background_color",
                    "dependency" => Array("element" => "background_type", "value" => "color" ),
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Heading", "lauv"),
                    "param_name" => "heading",
                    "admin_label" => true,
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Text", "lauv"),
                    "param_name" => "text",
                    "admin_label" => true,
                    "description" => wp_kses(__('Wrap the text in { } if you want the text to be another color.<br>Example: Minds your work {level}','lauv'),'post'),
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Link", "lauv"),
                    "param_name" => "link",
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Color overlay", "lauv" ),
                    "param_name"  => "color_overlay",
                    "value"      => array(
                        esc_html__( "None", "lauv" ) => "none",
                        esc_html__( "Gradient", "lauv" ) => "gradient",
                        esc_html__( "Color", "lauv" ) => "color",
                    ),
                    "group"       => esc_html__("Design", "lauv"),
                ),
                array(
                    "type" => "gradient",
                    "base_gradient" => "#112f76 0%,#003ae1 100%",
                    "base_orientation" => "vertical",
                    "heading" => esc_html__("Color overlay gradient", "lauv"),
                    "param_name" => "color_overlay_gradient",
                    "dependency" => Array("element" => "color_overlay", "value" => "gradient" ),
                    "group"      => esc_html__("Design", "lauv"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Color overlay color", "lauv"),
                    "param_name" => "color_overlay_color",
                    "dependency" => Array("element" => "color_overlay", "value" => "color" ),
                    "group"      => esc_html__("Design", "lauv"),
                ),
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__( "Overlay opacity", "lauv" ),
                    "param_name"  => "opacity_overlay",
                    "value"       => "0.3",
                    "description" => esc_html__("Min 0, Max 1. Example: 0.45", "lauv"),
                    "dependency" => Array("element" => "color_overlay", "value" => array('gradient', 'color') ),
                    "group"       => esc_html__("Design", "lauv"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Item color", "lauv" ),
                    "param_name"  => "text_color",
                    "value"      => array(
                        esc_html__( "Black", "lauv" ) => "black",
                        esc_html__( "White", "lauv" ) => "white",
                        esc_html__( "Custom", "lauv" ) => "custom",
                    ),
                    "group"       => esc_html__("Design", "lauv"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Vertical align", "lauv" ),
                    "param_name"  => "vertical_align",
                    "value"      => array(
                        esc_html__( "Top", "lauv" ) => "top",
                        esc_html__( "Middle", "lauv" ) => "middle",
                        esc_html__( "Bottom", "lauv" ) => "bottom",
                    ),
                    "std" => "bottom",
                    "group"       => esc_html__("Design", "lauv"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Select Item color", "lauv"),
                    "param_name" => "text_color_hex",
                    "dependency" => Array("element" => "text_color", "value" => "custom" ),
                    "group"      => esc_html__("Design", "lauv"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Heading font size", "lauv"),
                    "param_name" => "heading_size",
                    "group"      => esc_html__("Design", "lauv"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Text font size", "lauv"),
                    "param_name" => "text_size",
                    "group"      => esc_html__("Design", "lauv"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Select text color", "lauv"),
                    "param_name" => "custom_text_color_hex",
                    "group"      => esc_html__("Design", "lauv"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Social buttons color", "lauv"),
                    "param_name" => "social_buttons_color_hex",
                    "group"      => esc_html__("Design", "lauv"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Pagination color", "lauv"),
                    "param_name" => "pagination_color_hex",
                    "group"      => esc_html__("Design", "lauv"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Button color", "lauv"),
                    "param_name" => "button_text_color",
                    "dependency" => Array("element" => "link_button", "value" => "on" ),
                    "group"      => esc_html__( "Button Design", "lauv" ),
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_banner_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'infinite_loop' => 'on',
                    'speed' => '300',
                    'autoplay' => 'on',
                    'autoplay_speed' => '5000',
                    'adaptive_height' => 'on',
                    'height' => '',
                    'container' => 'container-fluid',
                    'paddings' => 'on',
                    'arrows' => 'on',
                    'arrow_color' => '',
                    'pauseohover' => 'on',
                    'social_buttons' => 'on',
                    'social_buttons_color' => '',
                    'dots' => 'on',
                    'dots_color' => '',
                    'categories' => 'off',
                    'dots_style' => 'style1',
                    'categories_label' => 'categories',
                    'categories_source' => '',
                    'categories_blog_items' => '',
                    'categories_portfolio_items' => '',
                    'category_link1' => '',
                    'category_link2' => '',
                    'category_link3' => '',
                    'category_link4' => '',
                    'category_link5' => '',
                    'category_link6' => '',
                    'category_link7' => '',
                ), 
                $atts
            )
        );


        $banner_area_class = $id = 'banner-'.$uniq_id;
        $banner_class = $banner_style = $pagination_buttons = '';

        if($paddings == 'off') {
            $social_buttons = 'off';
            $categories = 'off';
            $banner_area_class .= ' paddings-off';
        }

        if(!empty($height)) {
            $banner_style .= 'height: '.$height.'px;';
            $banner_class .= ' fixed-height';
        }

        if($dots_style != 'style1') {
            $banner_class .= ' pagination-'.$dots_style;
        }

        if($autoplay == 'on') {
            $autoplay = 'true';
        } else {
            $autoplay = 'false';
        }

        if($arrows == 'on') {
            $arrows = 'true';
        } else {
            $arrows = 'false';
        }

        if($dots == 'on') {
            $dots = 'true';
        } else {
            $dots = 'false';
        }

        if($pauseohover == 'on') {
            $pauseohover = 'true';
        } else {
            $pauseohover = 'false';
        }

        wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
        wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), true );
        wp_enqueue_script( 'lauv-script', get_template_directory_uri() . '/js/script.js' );

        wp_add_inline_script('lauv-script', "
        jQuery('body').addClass('page-with-offset');
        jQuery(document).ready(function(jQuery) {
            jQuery('.".esc_attr($id)." .banner').each(function(){
                var head_slider = jQuery(this);

                jQuery(this).on('initialize.owl.carousel',function(property){
                    jQuery(this).find('.item').each(function() {
                        var num = leadZero(jQuery(this).index()+1);
                        jQuery(this).find('.num').text(num);
                    });
                });
                
                if(jQuery(this).find('.item').length > 1){

                    head_slider.on('initialized.owl.carousel translated.owl.carousel', function(event) {
                        var index = event.item.index-1,
                            count = event.item.count;

                        if(index > count) {
                            index = 1;
                        }
                        head_slider.parent().find('.banner-pagination .current').text(leadZero(index));
                        head_slider.parent().find('.banner-pagination .total').text(leadZero(count));
                    });

                    head_slider.addClass('owl-carousel').owlCarousel({
                        loop:true,
                        items:1,
                        nav: ".esc_js($arrows).",
                        dots: false,
                        autoplay: ".esc_js($autoplay).",
                        autoplayTimeout: ".esc_js($autoplay_speed).",
                        autoplayHoverPause: ".esc_js($pauseohover).",
                        smartSpeed: ".esc_js($speed).",
                        navText: ['".esc_html__('prev', 'lauv')."', '".esc_html__('next', 'lauv')."'],
                        responsive:{
                            0:{
                                nav: false,
                                dots: false,
                            },
                            768:{
                                nav: ".esc_js($arrows).",
                                dots: ".esc_js($dots).",
                            },
                        },
                    });
                }
            });
        });");

        $custom_css = "";

        if(isset($social_buttons_color) && !empty($social_buttons_color)) {
            $custom_css .= '.'.$id.' .social-buttons-text {
                color: '.$social_buttons_color.';
            }';
        }

        if(isset($arrow_color) && !empty($arrow_color)) {
            $custom_css .= '.'.$id.' .owl-prev, .'.$id.' .owl-next {
                color: '.$arrow_color.';
            }';
        }

        if(isset($dots_color) && !empty($dots_color)) {
            $custom_css .= '.'.$id.' .owl-dots, .'.$id.' .banner-pagination {
                color: '.$dots_color.';
            }';
        }

        wp_enqueue_style('lauv-custom-style', get_template_directory_uri() . '/css/custom_script.css');
        wp_add_inline_style( 'lauv-custom-style', $custom_css );
 
        if(!empty($content)) {
            $content = str_replace('[pt_banner_item', '[pt_banner_item categories="'.$categories.'" categories_label="'.$categories_label.'" container="'.$container.'" social_buttons="'.$social_buttons.'" dots="'.$dots.'" dots_style="'.$dots_style.'"', $content);
        }

        $html = '<div class="banner-area '.esc_attr($banner_area_class).'">';
            if($social_buttons == 'on' && !empty(lauv_styles()['social_buttons_content'])) {
                $html .= '<div class="social-buttons-text"><div><div class="h">'.esc_html__('follow me', 'lauv').'</div> '.wp_kses(lauv_styles()['social_buttons_content'] ,'post').'</div></div>';
            }
            $html .= '<div class="banner '.esc_attr($banner_class).'" style="'.esc_attr($banner_style).'">';
                $html .= do_shortcode($content);
            $html .= '</div>';

            if($categories == 'on') {
                if(!empty($categories_portfolio_items) || !empty($categories_blog_items) || !empty($category_link1) || !empty($category_link2) || !empty($category_link3) || !empty($category_link4) || !empty($category_link5) || !empty($category_link6) || !empty($category_link7)) {
                    $html .= '<div class="banner-categories-button button-style2 back"><span>'.$categories_label.'</span></div>';
                    $html .= '<div class="banner-categories">';
                        $html .= '<ul>';
                            if(!empty($categories_blog_items)) {
                                foreach(explode(',', $categories_blog_items) as $item) {
                                    $id = $item;

                                    $term = get_term( (int) $id, 'category' );
                                    $term_link = get_term_link( (int) $id, 'category' );

                                    $html .= '<li>';
                                        $html .= '<a href="'.esc_url($term_link).'">'.esc_html($term->name).'</a>';
                                    $html .= '</li>';
                                }
                            }
                            if(!empty($categories_portfolio_items)) {
                                foreach(explode(',', $categories_portfolio_items) as $item) {
                                    $id = $item;

                                    $term = get_term( (int) $id, 'pt-portfolio-category' );
                                    $term_link = get_term_link( (int) $id, 'pt-portfolio-category' );

                                    $html .= '<li>';
                                        $html .= '<a href="'.esc_url($term_link).'">'.esc_html($term->name).'</a>';
                                    $html .= '</li>';
                                }
                            }
                            if(!empty($category_link1) || !empty($category_link2) || !empty($category_link3) || !empty($category_link4) || !empty($category_link5) || !empty($category_link6) || !empty($category_link7)) {
                                if(!empty($category_link1)) {
                                    $term_link = vc_build_link($category_link1);

                                    $html .= '<li>';
                                        $html .= '<a href="'.esc_url($term_link['url']).'">'.esc_html($term_link['title']).'</a>';
                                    $html .= '</li>';
                                }
                                if(!empty($category_link2)) {
                                    $term_link = vc_build_link($category_link2);

                                    $html .= '<li>';
                                        $html .= '<a href="'.esc_url($term_link['url']).'">'.esc_html($term_link['title']).'</a>';
                                    $html .= '</li>';
                                }
                                if(!empty($category_link3)) {
                                    $term_link = vc_build_link($category_link3);

                                    $html .= '<li>';
                                        $html .= '<a href="'.esc_url($term_link['url']).'">'.esc_html($term_link['title']).'</a>';
                                    $html .= '</li>';
                                }
                                if(!empty($category_link4)) {
                                    $term_link = vc_build_link($category_link4);

                                    $html .= '<li>';
                                        $html .= '<a href="'.esc_url($term_link['url']).'">'.esc_html($term_link['title']).'</a>';
                                    $html .= '</li>';
                                }
                                if(!empty($category_link5)) {
                                    $term_link = vc_build_link($category_link5);

                                    $html .= '<li>';
                                        $html .= '<a href="'.esc_url($term_link['url']).'">'.esc_html($term_link['title']).'</a>';
                                    $html .= '</li>';
                                }
                                if(!empty($category_link6)) {
                                    $term_link = vc_build_link($category_link6);

                                    $html .= '<li>';
                                        $html .= '<a href="'.esc_url($term_link['url']).'">'.esc_html($term_link['title']).'</a>';
                                    $html .= '</li>';
                                }
                                if(!empty($category_link7)) {
                                    $term_link = vc_build_link($category_link7);

                                    $html .= '<li>';
                                        $html .= '<a href="'.esc_url($term_link['url']).'">'.esc_html($term_link['title']).'</a>';
                                    $html .= '</li>';
                                }
                            }
                        $html .= '</ul>';
                    $html .= '</div>';
                }
            }
        $html .= '</div>';

        return $html;
         
    }

    // Element HTML
    public function pt_banner_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'background_type' => 'image',
                    'background_image' => '',
                    'background_gradient' => '',
                    'background_color' => '',
                    'heading' => '',
                    'text' => '',
                    'link' => '',
                    'color_overlay' => 'none',
                    'color_overlay_gradient' => '',
                    'color_overlay_color' => '',
                    'opacity_overlay' => '0.3',
                    'vertical_align' => 'bottom',
                    'text_color' => 'black',
                    'text_color_hex' => '',
                    'custom_text_color_hex' => '',
                    'social_buttons_color_hex' => '',
                    'pagination_color_hex' => '',
                    'button_text_color' => '',
                    'social_buttons' => 'on',
                    'heading_size' => '',
                    'text_size' => '',
                    'container' => 'container-fluid',
                    'dots' => 'true',
                    'dots_style' => 'style1',
                    'dots_position' => 'bottom',
                ), 
                $atts
            )
        );
         
        // Fill $html var with data
        $item_attr = $custom_css = '';

        $item_class = $id = "banner-item-".uniqid();

        if(isset(vc_build_link($link)['url']) && !empty(vc_build_link($link)['url'])) {
            $link = vc_build_link($link);
            if(empty($link['target'])) {
                $link['target'] = '_self';
            }
            if(empty($link['title'])) {
                $link['title'] = esc_html__('view more', 'lauv');
            }
        }

        if($background_type == 'image' && isset(wp_get_attachment_image_src($background_image, 'full')[0])) {
            $item_attr = 'background-image: url('.esc_url(wp_get_attachment_image_src($background_image, 'full')[0]).');';
        }

        if($background_type == 'gradient' && !empty($background_gradient)) {
            $background_gradient = strip_tags(explode("||", $background_gradient)[1]);
            if(!empty($background_gradient)) {
                $item_attr = $background_gradient;
            }
        }

        if($background_type == 'color' && !empty($background_color)) {
            $item_attr = 'background-color: '.esc_attr($background_color).';';
        }

        $item_class .= ' '.$vertical_align;

        if(isset($text_color) && $text_color != 'custom') {
            $item_class .= ' '.$text_color;
        }

        if(isset($content_align)) {
            $item_class .= ' content-align-'.$content_align;
        }

        if(isset($text_color) && $text_color == 'custom') {
            $custom_css .= '.'.$id.' {
                color: '.$text_color_hex.' !important;
            }';
        }

        if(isset($heading_size) && !empty($heading_size)) {
            $custom_css .= '.'.$id.' .h {
                font-size: '.$heading_size.' !important;
            }';
        }

        if(isset($custom_text_color_hex) && !empty($custom_text_color_hex)) {
            $custom_css .= '.'.$id.' .text {
                color: '.$custom_text_color_hex.' !important;
            }';
        }

        if(isset($text_size) && !empty($text_size)) {
            $custom_css .= '.'.$id.' .text {
                font-size: '.$text_size.' !important;
            }';
        }

        if(isset($pagination_color_hex) && !empty($pagination_color_hex)) {
            $custom_css .= '.'.$id.' .banner-pagination {
                color: '.$pagination_color_hex.' !important;
            }';
        }

        if(isset($social_buttons_color_hex) && !empty($social_buttons_color_hex)) {
            $custom_css .= '.'.$id.' .social-buttons-text {
                color: '.$social_buttons_color_hex.' !important;
            }';
        }

        if($color_overlay == 'gradient' && !empty($color_overlay_gradient)) {
            $color_overlay_gradient = strip_tags(explode("||", $color_overlay_gradient)[1]);
            if(!empty($color_overlay_gradient)) {
                $custom_css .= '.'.$id.' .overlay {
                    '.$color_overlay_gradient.'
                    opacity: '.$opacity_overlay.' !important;
                }';
            }
        }

        if($color_overlay == 'color' && !empty($color_overlay_color)) {
            $custom_css .= '.'.$id.' .overlay {
                background-color: '.$color_overlay_color.';
                opacity: '.$opacity_overlay.' !important;
            }';
        }

        if(!empty($button_bg_color) || !empty($button_bg_gradient) || !empty($button_text_color)) {
            $custom_css .= '.'.$id.' .button-style1 {';
                if(!empty($button_text_color)) {
                    $custom_css .= 'color: '.$button_text_color.';';
                }
            $custom_css .= '}';
        }

        wp_enqueue_style('lauv-custom-style', get_template_directory_uri() . '/css/custom_script.css');
        wp_add_inline_style( 'lauv-custom-style', $custom_css );
        
        $html = '<div class="item '.esc_attr($item_class).'" style="'.esc_attr($item_attr).'">';
            if(!empty($color_overlay)) {
                $html .= '<div class="overlay"></div>';
            }
            $html .= '<div class="'.esc_attr($container).'">';
                $html .= '<div class="cell">';
                    if(!empty($heading)) {
                        $heading = str_replace(array('{', '}'), array('<span>', '</span>'), $heading);
                        $html .= '<div class="h">'.wp_kses($heading, 'post').'</div>';
                    }
                    if(!empty($text)) {
                        $text = str_replace(array('{', '}'), array('<span>', '</span>'), $text);
                        $html .= '<div class="text">'.wp_kses($text, 'post').'</div>';
                    }
                    if(!empty($link)) {
                        $html .= '<div class="link-area">';
                            $html .= '<a href="'.esc_url($link['url']).'" class="button-style2" title="'.esc_attr($link['title']).'" target="'.esc_attr($link['target']).'"><span>'.strip_tags($link['title']).'</span></a>';
                        $html .= '</div>';
                    }
                $html .= '</div>';
            $html .= '</div>';
        $html .= '</div>';

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Banner();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Banner extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Banner_Item extends WPBakeryShortCode {
    }
}

