<?php

// Element Description: PT Blog

class PT_Blog_Items extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_blog_mapping' ) );
        add_shortcode( 'pt_blog', array( $this, 'pt_blog_html' ) );
    }

    public static function get_all_blog_category() {
        $taxonomy = 'category';
        $args     = array(
            'hide_empty' => true,
        );

        $terms     = get_terms( $taxonomy, $args );
        $result    = array();
        $result[0] = "";

        if ( ! empty( $terms ) && !is_wp_error( $terms ) ) {
            foreach ( $terms as $term ) {
                if(get_category_parents($term->term_id)) {
                    $name = get_category_parents($term->term_id);
                } else {
                    $name = $term->name;
                }
                $name = trim($name, '/');
                $result[ 'ID ['.$term->term_id.'] '.$name ] = $term->term_id;
            }
        }

        return $result;
    }

    public static function get_all_blog_items( $param = 'All' ) {
        $result    = array();
        
        $args = array(
            'post_type'       => 'post',
            'post_status'     => 'publish',
            'posts_per_page'    => '10000'
        );

        $blog_array = new WP_Query( $args );
        $result[0] = "";

        if ( ! empty( $blog_array->posts ) ) {
            foreach ( $blog_array->posts as $item ) {
                $result[ 'ID ['.$item->ID.'] '. $item->post_title ] = $item->ID;
            }
        }

        return $result;
    }
     
    // Element Mapping
    public function pt_blog_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Blog", "lauv"),
            "base" => "pt_blog",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-blog",
            "is_container" => true,
            "category" => esc_html__("By PT", "lauv"),
            "params" => array(
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__( "Uniq ID", "lauv" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Count items", "lauv" ),
                    "param_name"  => "count_items",
                    "value"       => '9',
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Type", "lauv" ),
                    "param_name"  => "type",
                    "value"      => array(
                        esc_html__( "Grid", "lauv" ) => "grid",
                        esc_html__( "Masonry", "lauv" ) => "masonry",
                        esc_html__( "Horizontal", "lauv" ) => "horizontal",
                    ),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Carousel mode", "lauv" ),
                    "param_name"  => "carousel_mode",
                    "value"       => "off",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => false,
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums", "lauv" ),
                    "param_name"  => "cols",
                    "value"      => array(
                        esc_html__( "Col 1", "lauv" ) => "1",
                        esc_html__( "Col 2", "lauv" ) => "2",
                        esc_html__( "Col 3", "lauv" ) => "3",
                        esc_html__( "Col 4", "lauv" ) => "4",
                    ),
                    "std" => '3',
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Filter buttons", "lauv" ),
                    "param_name"  => "filter_buttons",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Filter buttons align", "lauv" ),
                    "param_name"  => "filter_buttons_align",
                    "value"      => array(
                        esc_html__('Left', 'lauv') => 'tal',
                        esc_html__('Center', 'lauv') => 'tac',
                        esc_html__('Right', 'lauv') => 'tar',
                    ),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Navigation", "lauv" ),
                    "param_name"  => "navigation",
                    "value"      => array(
                        esc_html__( "None", "lauv" ) => "none",
                        esc_html__( "Load More", "lauv" ) => "load_more",
                        esc_html__( "Pagination", "lauv" ) => "pagination",
                    ),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Navigation buttons", "lauv" ),
                    "param_name"  => "nav_buttons",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Autoplay", "lauv" ),
                    "param_name"  => "autoplay",
                    "value"       => "off",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => false,
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "lauv" ),
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Autoplay timeout", "lauv" ),
                    "param_name"  => "autoplay_timeout",
                    "value"       => '5000',
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums on desktop", "lauv" ),
                    "param_name"  => "cols_on_desktop",
                    "value"      => array(
                        esc_html__( "Col 1", "lauv" ) => "1",
                        esc_html__( "Col 2", "lauv" ) => "2",
                        esc_html__( "Col 3", "lauv" ) => "3",
                        esc_html__( "Col 4", "lauv" ) => "4",
                    ),
                    "std" => '4',
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums on tablet", "lauv" ),
                    "param_name"  => "cols_on_tablet",
                    "value"      => array(
                        esc_html__( "Col 1", "lauv" ) => "1",
                        esc_html__( "Col 2", "lauv" ) => "2",
                        esc_html__( "Col 3", "lauv" ) => "3",
                        esc_html__( "Col 4", "lauv" ) => "4",
                    ),
                    "std" => '3',
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums on mobile", "lauv" ),
                    "param_name"  => "cols_on_mobile",
                    "value"      => array(
                        esc_html__( "Col 1", "lauv" ) => "1",
                        esc_html__( "Col 2", "lauv" ) => "2",
                        esc_html__( "Col 3", "lauv" ) => "3",
                        esc_html__( "Col 4", "lauv" ) => "4",
                    ),
                    "std" => '2',
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Image", "lauv" ),
                    "param_name"  => "show_image",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Date", "lauv" ),
                    "param_name"  => "show_date",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Categories", "lauv" ),
                    "param_name"  => "show_categories",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Heading", "lauv" ),
                    "param_name"  => "show_heading",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Like", "lauv" ),
                    "param_name"  => "show_like",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Read more", "lauv" ),
                    "param_name"  => "show_read_more",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order by", "lauv" ),
                    "param_name"  => "orderby",
                    "value"      => array(
                        esc_html__('Default', 'lauv') => 'post__in',
                        esc_html__('Author', 'lauv') => 'author',
                        esc_html__('Date', 'lauv') => 'date',
                        esc_html__('ID', 'lauv') => 'ID',
                        esc_html__('Title', 'lauv') => 'title',
                    ),
                    "group"       => esc_html__( "Sorting", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order", "lauv" ),
                    "param_name"  => "order",
                    "value"      => array(
                        esc_html__('Ascending order', 'lauv') => 'ASC',
                        esc_html__('Descending order', 'lauv') => 'DESC',
                    ),
                    "group"       => esc_html__( "Sorting", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Source", "lauv" ),
                    "param_name"  => "source",
                    "value"      => array(
                        esc_html__( "---", "lauv" ) => "",
                        esc_html__( "Items", "lauv" ) => "items",
                        esc_html__( "Categories", "lauv" ) => "categories",
                    ),
                    "group"       => esc_html__( "Source", "lauv" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Items", "lauv" ),
                    "param_name"  => "items",
                    "dependency"  => Array( "element" => "source", "value" => array( "items" ) ),
                    "value"       => PT_Blog_Items::get_all_blog_items(),
                    "group"       => esc_html__( "Source", "lauv" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Category", "lauv" ),
                    "param_name"  => "categories",
                    "dependency"  => Array( "element" => "source", "value" => array( "categories" ) ),
                    "value"       => PT_Blog_Items::get_all_blog_category(),
                    "group"       => esc_html__( "Source", "lauv" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "lauv" ),
                    "param_name" => "animation",
                    "group"       => esc_html__( "General", "lauv" ),
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_blog_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'count_items' => '9', 
                    'type' => 'grid',
                    'cols' => '3',
                    'filter_buttons' => 'on',
                    'filter_buttons_align' => 'tal',
                    'navigation' => 'none',
                    'show_image' => 'on',
					'show_date' => 'on',
					'show_heading' => 'on',
                    'show_categories' => 'on',
                    'show_desc' => 'on',
                    'show_like' => 'on',
                    'show_read_more' => 'on',
                    'orderby' => 'post__in',
                    'order' => 'ASC',
                    'source' => '',
                    'items' => '',
                    'categories' => '',
                    'source' => '',
                    'carousel_mode' => 'off',
                    'nav_buttons' => 'on',
                    'autoplay' => 'off',
                    'autoplay_timeout' => '5000',
                    'cols_on_desktop' => '4',
                    'cols_on_tablet' => '3',
                    'cols_on_mobile' => '2',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $wrap_id = 'blog-'.$uniq_id;

        $animation = $this->getCSSAnimation($animation);

        if(is_front_page()) {
            $paged = (get_query_var('page')) ? get_query_var('page') : 1;
        } else {
            $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        }

        $tax_query = array();

        $categories_s = '';
        if ( !empty($categories) && $categories != '0' ) {
            $categories_s = explode(',', $categories);
            $tax_query = array(
                array(
                    'taxonomy' => 'category',
                    'field'    => 'id',
                    'terms'    => $categories_s
                )
            );
        }
        if($items) {
            $items = explode(',', $items);
        } else {
            $items = '';
        }
        $args = array(
            'post__in'        => $items,
            'posts_per_page'  => $count_items,
            'paged'           => $paged,
            'orderby'         => $orderby,
            'order'           => $order,
            'post_type'       => 'post',
            'post_status'     => 'publish',
            'tax_query'       => $tax_query
        );

        $blog_array = new WP_Query( $args );

        $max_num_pages = 0;
        $max_num_pages = $blog_array->max_num_pages;

        $html = '';

        if($type != 'standart') {
            switch ($cols) {
                case '1':
                    $item_col = "col-xs-12";
                    break;
                case '2':
                    $item_col = "col-xs-12 col-sm-6";
                    break;
                case '3':
                    $item_col = "col-xs-12 col-sm-4";
                    break;
                case '4':
                    $item_col = "col-xs-12 col-sm-4 col-md-3";
                    break;
                
                default:
                    $item_col = "";
                    break;
            }
        } else {
            switch ($cols) {
                case '1':
                    $item_col = "col-xs-12";
                    break;
                case '2':
                    $item_col = "col-xs-12 col-md-6";
                    break;
                case '3':
                    $item_col = "col-xs-12 col-md-4";
                    break;
                case '4':
                    $item_col = "col-xs-12 col-md-6 col-lg-3";
                    break;
                
                default:
                    $item_col = "";
                    break;
            }
        }

        $item_num = 0;

        $category_array = array();
        if($items) {
            $i = 0;
            while ( $blog_array->have_posts() ) : $blog_array->the_post();
                $id = get_the_ID();
                $category_array[$i] = array();
                foreach (wp_get_post_terms( $id, 'category') as $key2 => $s_item) {
                    $category_array[$i][$key2] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
                $i++;
            endwhile;

            $arrOut = array();
            foreach($category_array as $subArr){
                $arrOut = array_merge($arrOut,$subArr);
            }

            $category_array = array_map( 'unserialize', array_unique( array_map( 'serialize', $arrOut)));
        } else if(is_array($categories_s) && count($categories_s) > 0) {
            $args     = array(
                'hide_empty' => true,
                'include' => $categories_s
            );
            $taxonomy = 'category';
            $terms     = get_terms( $taxonomy, $args );
            if(!empty($terms) && !is_wp_error( $terms )) {
                foreach($terms as $s_item) { 
                    $category_array[] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
            }
        } else {
            $args     = array(
                'hide_empty' => true,
            );
            $taxonomy = 'category';
            $terms     = get_terms( $taxonomy, $args );
            if(!empty($terms)) {
                foreach($terms as $s_item) { 
                    $category_array[] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
            }
        }

        $wrap_classes = "";

        $html = "";

        if(isset($carousel_mode) && $carousel_mode == "on") {
            $filter_buttons = "off";
            $item_col = '';
            
            if($nav_buttons == 'on') {
                $arrows = 'true';
            } else {
                $arrow = 'false';
            }

            if($autoplay == 'on') {
                $autoplay = 'true';
            } else {
                $autoplay = 'false';
            }

            $wrap_classes .= ' disable-iso';

            $navigation = 'disable';

            wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
            wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), true );
            wp_enqueue_script( 'lauv-script', get_template_directory_uri() . '/js/script.js' );

            wp_add_inline_script('lauv-script', "jQuery(document).ready(function(jQuery) {
                jQuery('.".esc_attr($wrap_id)."').each(function(){
                    var head_slider = jQuery(this);
                    if(jQuery(this).find('.blog-item').length > 1){
                        head_slider.addClass('owl-carousel').owlCarousel({
                            loop:true,
                            items:1,
                            nav: ".esc_js($arrows).",
                            dots: false,
                            autoplay: ".esc_js($autoplay).",
                            autoplayTimeout: ".esc_js($autoplay_timeout).",
                            autoplayHoverPause: true,
                            navClass: ['owl-prev base-icons-prev','owl-next base-icons-next'],
                            navText: false,
                            responsive:{
                                0:{
                                    nav: false,
                                    items: 1
                                },
                                768:{
                                    nav: ".esc_js($arrows).",
                                    items: ".esc_js($cols_on_mobile)."
                                },
                                992:{
                                    items: ".esc_js($cols_on_tablet)."
                                },
                                1200:{
                                    items: ".esc_js($cols_on_desktop)."
                                },
                            },
                        });
                    }
                });
            });");
        }

        if(is_array($blog_array->posts) && count($blog_array->posts) > 0) {
            if(is_array($category_array) && $filter_buttons == "on" && count($category_array) > 1) {
                $html .= '<div class="filter-button-group '.esc_attr($filter_buttons_align).'">';
                    $html .= '<div class="wrap">';
                        $html .= '<button data-filter="*" class="active">'.esc_html__('All', 'lauv').'</button>';
                        foreach($category_array as $item) { 
                            $name = $item["name"];
                            $slug = $item["slug"];
                            $html .= '<button data-filter=".category-'.esc_attr($slug).'">'.esc_html($name).'</button>';
                        }
                    $html .= '</div>';
                $html .= '</div>';
            }
            $html .= '<div class="blog-items row blog-type-'.$type.' '.$wrap_id.' '.$wrap_classes.'">';
                while ( $blog_array->have_posts() ) : $blog_array->the_post();
                    $id = get_the_ID();
                    $item = get_post($id);
                    $item_num++;
                    $name = $item->post_title;
                    $item_class = $category = "";
                    if(is_array(wp_get_post_terms( $id, 'category'))) {
                        for ($i=0; $i < count(wp_get_post_terms( $id, 'category')); $i++) {
                            $category .= wp_get_post_terms( $id, 'category')[$i]->name.', ';
                            $item_class .= 'category-'.wp_get_post_terms( $id, 'category')[$i]->slug.' ';
                        }
                        $item_class = trim($item_class, ' ');
                        $category = trim($category, ', ');
                    }

                    $thumb = get_post_meta( $id, '_thumbnail_id', true );
                    $image = wp_get_attachment_image_src( $thumb , 'full' );

                    if($show_desc == 'on') {
                        if(get_field('short_desc')) {
                            $desc = get_field('short_desc', $id);
                        } else {
                            $desc = strip_tags(strip_shortcodes($item->post_content));
                        }
                    } else {
                        $desc = "";
                    }

                    if($desc && $show_desc == 'on') {
                        if($type == 'horizontal') {
                            if(iconv_strlen ($desc, 'UTF-8') > 315) {
                                $desc = substr($desc, 0, 315).'...';
                            }
                        } else {
                        	if(iconv_strlen ($desc, 'UTF-8') > 180) {
                                $desc = substr($desc, 0, 180).'...';
                            }
                        }
                    }

                    if(isset($image[0]) && !empty($image[0])) {
                    	$item_class .= ' with-image';
                    }

                    $html .= '<article class="blog-item '.esc_attr($item_class.' '.$item_col).'">';
                    	$html .= '<div class="wrap '.esc_attr($animation).'">';
                    		if($show_image == 'on' && isset($image[0]) && !empty($image[0])) {
	                            if($type == 'masonry') {
	                                $html .= '<div class="img"><a href="'.esc_url(get_permalink($id)).'"><img width="'.esc_attr($image[1]).'" height="'.esc_attr($image[2]).'" src="'.esc_url($image[0]).'" alt="'.esc_html($name).'"></a>';
                                        if($show_like == 'on' && function_exists('zilla_likes')){
                                            $html .= '<div class="like">'.zilla_likes($id).'</div>';
                                        }
                                    $html .= '</div>';
	                            } else {
	                                $html .= '<div class="img"><a href="'.esc_url(get_permalink($id)).'" style="background-image: url('.esc_url($image[0]).');"></a>';
                                        if($show_like == 'on' && function_exists('zilla_likes')){
                                            $html .= '<div class="like">'.zilla_likes($id).'</div>';
                                        }
                                    $html .= '</div>';
	                            }
	                        }
                            $html .= '<div class="content">';
                                if($show_heading == 'on') {
                                    $html .= '<h5><a href="'.esc_url(get_permalink($id)).'">'.esc_html($name).'</a></h5>';
                                }
                                if($show_date == 'on' || $show_categories == 'on') {
                                    $html .= '<div class="blog-detail">';
                                        if($show_date == 'on') {
                                            $html .= '<div class="date"><i class="ui-icons-calendar"></i> <span>'.get_the_date('', $id).'</span></div>';
                                        }
                                        if($show_categories == 'on') {
                                            $html .= '<div class="categories"><i class="ui-icons-tag"></i> <span>'.wp_kses_post($category).'</span></div>';
                                        }
                                    $html .= '</div>';
                                }
                                if($show_desc == 'on') {
                                    $html .= '<div class="text">'.wp_kses($desc, 'post').'</div>';
                                }
                                if($show_read_more == 'on') {
                                    $html .= '<a class="button-style2" href="'.esc_url(get_permalink($id)).'">'.esc_html__('read more','lauv').'</a>';
                                }
                            $html .= '</div>';
                        $html .= '</div>';
                    $html .= '</article>';
                endwhile;
                wp_reset_postdata();
            $html .= '</div>';
        }

        if($navigation == "pagination") {
            if (function_exists('lauv_wp_corenavi')) {
                $html .= lauv_wp_corenavi($max_num_pages);
            } else {
                $html .= wp_link_pages();
            };
        }
        if(is_array($blog_array->posts) && $navigation == "load_more" && $max_num_pages > 1) {
            $html .= '<div class="load-button tac"><a href="#" data-wrap=".'.esc_attr($wrap_id).'" data-max="'.esc_attr($max_num_pages).'" data-start-page="'.esc_attr($paged).'" data-next-link="'.esc_url(next_posts($max_num_pages, false)).'" class="button-style1"><span>'.esc_html('Load more', 'lauv').'</span></a></div>';
        }

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Blog_Items();