<?php

// Element Description: PT Google map

class PT_Google_Maps extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_google_map_mapping' ) );
        add_shortcode( 'pt_google_map', array( $this, 'pt_google_map_html' ) );
    }
     
    // Element Mapping
    public function pt_google_map_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Google map", "lauv"),
            "base" => "pt_google_map",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-google-map",
            "category" => esc_html__("By PT", "lauv"),
            "params" => array(
                array(
                    "type" => "textfield",
                    "class" => "",
                    "heading" => esc_html__("Google Maps API Key", "lauv"),
                    "description" => __("Create an application in <a href='https://console.developers.google.com/flows/enableapi?apiid=places_backend,maps_backend,geocoding_backend,directions_backend,distance_matrix_backend,elevation_backend&keyType=CLIENT_SIDE&reusekey=true' target='_blank'>Google Console</a> and add the Key here.", "lauv"),
                    "param_name" => "key",
                    "group" => esc_html__('General', 'lauv')
                ),
                array(
                    "type" => "textfield",
                    "class" => "",
                    "heading" => esc_html__("Width", "lauv"),
                    "descroption" => esc_html__("in %", "lauv"),
                    "param_name" => "width",
                    "admin_label" => true,
                    "value" => "100",
                    "group" => esc_html__('General', 'lauv')
                ),
                array(
                    "type" => "textfield",
                    "class" => "",
                    "heading" => esc_html__("Height", "lauv"),
                    "descroption" => esc_html__("in px", "lauv"),
                    "param_name" => "height",
                    "admin_label" => true,
                    "value" => "345",
                    "group" => esc_html__('General', 'lauv')
                ),
                array(
                    "type" => "dropdown",
                    "class" => "",
                    "heading" => esc_html__("Map type", "lauv"),
                    "param_name" => "map_type",
                    "admin_label" => true,
                    "value" => array(
                        esc_html__("Roadmap", "lauv") => "ROADMAP", 
                        esc_html__("Satellite", "lauv") => "SATELLITE", 
                        esc_html__("Hybrid", "lauv") => "HYBRID", 
                        esc_html__("Terrain", "lauv") => "TERRAIN"
                    ),
                    "group" => esc_html__('General', 'lauv')
                ),
                array(
                    "type" => "textfield",
                    "class" => "",
                    "heading" => esc_html__("Latitude", "lauv"),
                    "param_name" => "lat",
                    "admin_label" => true,
                    "description" => '<a href="http://labs.mondeca.com/geo/anyplace.html" target="_blank">'.esc_html__('Here is a tool','lauv').'</a> '.esc_html__('where you can find Latitude & Longitude of your location', 'lauv'),
                    "group" => esc_html__('General', 'lauv')
                ),
                array(
                    "type" => "textfield",
                    "class" => "",
                    "heading" => esc_html__("Longitude", "lauv"),
                    "param_name" => "lng",
                    "admin_label" => true,
                    "description" => '<a href="http://labs.mondeca.com/geo/anyplace.html" target="_blank">'.esc_html__('Here is a tool','lauv').'</a> '.esc_html__('where you can find Latitude & Longitude of your location', "lauv"),
                    "group" => esc_html__('General', 'lauv')
                ),
                array(
                    "type" => "dropdown",
                    "heading" => esc_html__("Map Zoom", "lauv"),
                    "param_name" => "zoom",
                    "value" => array(
                        esc_html__("16 - Default", "lauv") => 16, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 13, 14, 15, 16, 17, 18, 19, 20
                    ),
                    "group" => esc_html__('General', 'lauv')
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Mouse wheel scroll", "lauv" ),
                    "param_name"  => "scrollwheel",
                    "value"       => "off",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => false,
                    "group"       => esc_html__( "General", "lauv" ),
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_google_map_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'key' => '',
                    'include_contact_form' => 'off',
                    'background_image' => '',
                    'text_color' => '',
                    'heading' => '',
                    'shortcode' => '',
                    'width' => '100',
                    'height' => '345',
                    'map_type' => 'ROADMAP',
                    'lat' => '',
                    'lng' => '',
                    'zoom' => '16',
                    'scrollwheel' => 'off',
                ), 
                $atts
            )
        );

        $id = 'map-'.uniqid();

        $html = $style = "";

        if($scrollwheel == "on") {
            $scrollwheel = "true";
        } else {
            $scrollwheel = "false";
        }

        if(!empty($background_image) && isset(wp_get_attachment_image_src($background_image, 'full')[0])) {
            $style = 'background-image: url('.esc_url(wp_get_attachment_image_src($background_image, 'full')[0]).');';
        }

        if(!empty($text_color)) {
            $style .= 'color: '.$text_color.';';
        }

        if(!empty($lat) && !empty($lng) && !empty($key)) {
            if(!empty(lauv_styles()['google_maps_api_key'])) {
                $html .= '<div class="map" id="'.esc_attr($id).'" style="width: '.esc_attr($width).'%; height: '.esc_attr($height).'px;"></div>';
            } else {
                $html = esc_html__('No Api Keys,', 'lauv').' <a href="'.admin_url('admin.php?page=Lauv').'">'.esc_html__('Add key in Theme Options').'</a>';
            }

            wp_enqueue_script( 'googleapis', 'https://maps.googleapis.com/maps/api/js?v=3.exp&amp;key='.lauv_styles()['google_maps_api_key'].'&amp;sensor=false', array('jquery') );
            wp_enqueue_script( 'lauv-script', get_template_directory_uri() . '/js/script.js' );

            wp_add_inline_script('lauv-script', "jQuery(document).ready(function(jQuery) {
                jQuery('#".esc_attr($id)."').each(function(){
                    function initialize() {
                        var myLatlng = new google.maps.LatLng(".$lat.",".$lng.");
                        var mapOptions = {
                            zoom: ".$zoom.",
                            center: myLatlng,
                            disableDefaultUI: true,
                            scrollwheel: ".$scrollwheel.",
                            mapTypeId: google.maps.MapTypeId.".$map_type.",
                            styles: [
                                {
                                    'featureType': 'all',
                                    'stylers': [
                                        {
                                            'saturation': 0
                                        },
                                        {
                                            'hue': '#01a2dd'
                                        }
                                    ]
                                },
                                {
                                    'featureType': 'road',
                                    'stylers': [
                                        {
                                            'saturation': -70
                                        }
                                    ]
                                },
                                {
                                    'featureType': 'transit',
                                    'stylers': [
                                        {
                                            'visibility': 'off'
                                        }
                                    ]
                                },
                                {
                                    'featureType': 'poi',
                                    'stylers': [
                                        {
                                            'visibility': 'off'
                                        }
                                    ]
                                },
                                {
                                    'featureType': 'water',
                                    'stylers': [
                                        {
                                            'visibility': 'simplified'
                                        },
                                        {
                                            'saturation': -60
                                        }
                                    ]
                                }
                            ]
                        }
                        var map = new google.maps.Map(document.getElementById('".$id."'), mapOptions);

                        var myLatLng = new google.maps.LatLng(".$lat.",".$lng.");
                        var beachMarker = new google.maps.Marker({
                            position: myLatLng,
                            icon: '".get_template_directory_uri() . '/images/marker.png'."',
                            map: map
                        });
                        google.maps.event.addDomListener(window, 'resize', function() {
                            var center = map.getCenter();
                            google.maps.event.trigger(map, 'resize');
                            map.setCenter(center); 
                        });
                    }
                    google.maps.event.addDomListener(window, 'load', initialize);
                });
            });");
        }

        

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Google_Maps();