<?php

// Element Description: PT Portfolio By Category

class PT_Portfolio_By_Category extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_portfolio_by_category_mapping' ) );
        add_shortcode( 'pt_portfolio_by_category', array( $this, 'pt_portfolio_by_category_html' ) );
        add_shortcode( 'pt_portfolio_by_category_item', array( $this, 'pt_portfolio_by_category_item_html' ) );
    }

    public static function get_all_portfolio_category() {
        $taxonomy = 'pt-portfolio-category';
        $args     = array(
            'hide_empty' => true,
        );

        $terms     = get_terms( $taxonomy, $args );
        $result    = array();
        $result[0] = esc_html__('Select', 'lauv');

        if ( ! empty( $terms ) && !is_wp_error( $terms ) ) {
            foreach ( $terms as $term ) {
                $name = $term->name;
                $result[ 'ID ['.$term->term_id.'] '.$name ] = 'items'.$term->term_id;
            }
        }

        return $result;
    }
     
    // Element Mapping
    public function pt_portfolio_by_category_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Portfolio By Category", "lauv"),
            "base" => "pt_portfolio_by_category",
            "as_parent" => array('only' => 'pt_portfolio_by_category_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "is_container" => true,
            "icon" => "shortcode-icon-portfolio",
            "category" => esc_html__("By PT", "lauv"),
            "params" => array(
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Text", "lauv"),
                    "param_name" => "heading",
                    "admin_label" => true,
                    "description" => wp_kses(__('Wrap the text in { } if you want the text to be another color.<br>Example: Minds your work {level}','lauv'),'post'),
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Social buttons", "lauv" ),
                    "param_name" => "social_buttons",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Contacts text", "lauv"),
                    "param_name" => "contacts",
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Copyright text", "lauv"),
                    "param_name" => "copyright",
                    "group"      => esc_html__("General", "lauv"),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Navigation Arrows", "lauv" ),
                    "param_name"  => "arrows",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__("Navigation", "lauv"),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Serial number", "lauv" ),
                    "param_name"  => "serial_number",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__("Navigation", "lauv"),
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );

        $item_array = array(
            "name" => esc_html__("Banner item", "lauv"),
            "base" => "pt_portfolio_by_category_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-portfolio",
            "as_child" => array('only' => 'pt_portfolio_by_category'),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Position type of elements", "lauv" ),
                    "param_name"  => "position_type",
                    "admin_label" => true,
                    "value"      => array(
                        esc_html__( "Type 1", "lauv" ) => "type1",
                        esc_html__( "Type 2", "lauv" ) => "type2",
                        esc_html__( "Type 3", "lauv" ) => "type3",
                        esc_html__( "Type 4", "lauv" ) => "type4",
                        esc_html__( "Type 5", "lauv" ) => "type5",
                    ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Category", "lauv" ),
                    "param_name"  => "categories_portfolio_items",
                    "admin_label" => true,
                    "value"       => PT_Portfolio_By_Category::get_all_portfolio_category(),
                ),
            )
        );

        $taxonomy = 'pt-portfolio-category';
        $args     = array(
            'hide_empty' => true,
        );

        $terms     = get_terms( $taxonomy, $args );
        $result_array = '';

        if ( ! empty( $terms ) && !is_wp_error( $terms ) ) {
            foreach ( $terms as $term ) {
                $result    = array();

                $tax_query = array(
                    array(
                        'taxonomy' => 'pt-portfolio-category',
                        'field'    => 'id',
                        'terms'    => $term->term_id
                    )
                );

                $args = array(
                    'posts_per_page'  => '100000',
                    'post_type'       => 'pt-portfolio',
                    'post_status'     => 'publish',
                    'tax_query'       => $tax_query
                );

                $porfolio_array = new WP_Query( $args );

                foreach ($porfolio_array->posts as $item) {
                    $result[ 'ID ['.$item->ID.'] '.$item->post_title ] = $item->ID;
                }

                $item_array['params'][] = array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Items", "lauv" ),
                    "param_name"  => "items".$term->term_id,
                    "dependency"  => Array( "element" => "categories_portfolio_items", "value" => array( 'items'.$term->term_id ) ),
                    "value"       => $result,
                );
            }
        }

        vc_map( $item_array );
    }
     
     
    // Element HTML
    public function pt_portfolio_by_category_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'heading' => '',
                    'social_buttons' => 'on',
                    'contacts' => '',
                    'copyright' => '',
                    'arrows' => 'on',
                    'serial_number' => 'on',
                ), 
                $atts
            )
        );

        $html = '';

        $portfolio_area_class = $id = 'portfolio-'.$uniq_id;

        $html = '<div class="portfolio-by-category">';
            $html .= '<div class="left-side">';
                if(!empty($heading)) {
                    $heading = str_replace(array('{', '}'), array('<span>', '</span>'), $heading);
                    $html .= '<div class="text">'.wp_kses_post($heading).'</div>';
                }
                $html .= '<div class="tab-h"></div>';
                if(!empty($contacts) || ($social_buttons == 'on' && !empty(lauv_styles()['social_buttons_content'])) || !empty($copyright)) {
                    $html .= '<div class="bottom">';
                        if(!empty($contacts)) {
                            $html .= '<div class="contacts">'.wp_kses_post($contacts).'</div>';
                        }
                        if($social_buttons == 'on' && !empty(lauv_styles()['social_buttons_content'])) {
                            $html .= '<div class="social-buttons-text">'.lauv_styles()['social_buttons_content'].'</div>';
                        }
                        if(!empty($copyright)) {
                            $html .= '<div class="copyright">'.wp_kses_post($copyright).'</div>';
                        }
                    $html .= '</div>';
                }
                if($arrows == 'on') {
                    $html .= '<div class="nav-buttons"><div class="prev base-icons-prev"></div><div class="next base-icons-next"></div></div>';
                }
                if($serial_number == 'on') {
                    $html .= '<div class="current-num">01</div>';
                }
            $html .= '</div>';
            $html .= '<div class="right-side">';
                $html .= do_shortcode($content);
            $html .= '</div>';
        $html .= '</div>';

        return $html;
         
    }

    // Element HTML
    public function pt_portfolio_by_category_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'position_type' => 'type1',
                    'categories_portfolio_items' => '',
                ), 
                $atts
            )
        );
         
        // Fill $html var with data
        $item_attr = $custom_css = $html = '';

        $item_class = $id = "portfolio-item-".uniqid();

        if(!empty($categories_portfolio_items)) {
            $category_id = str_replace('items', '', $categories_portfolio_items);
            $category = get_term($category_id, 'pt-portfolio-category', 'ARRAY_A');
            $items_id = $atts[$categories_portfolio_items];

            if($items_id) {
                $items_id = explode(',', $items_id);
            }


            $args = array(
                'post__in'        => $items_id,
                'posts_per_page'  => '100000',
                'post_type'       => 'pt-portfolio',
                'post_status'     => 'publish',
                'orderby'         => 'post__in',
            );

            $porfolio_array = new WP_Query( $args );
            //var_dump($category);

            $html = '<div class="item" data-name="'.$category['name'].'">';
                $html .= '<div class="scroll-mouse"></div>';
                $html .= '<div class="wrap">';
                    $html .= '<div class="cat-link-item">';
                        $html .= '<a class="cell" href="'.get_term_link($category['term_id']).'">';
                            $html .= '<span>'.$category['name'].'</span><i class="base-icons-right-arrow"></i>';
                        $html .= '</a>';
                    $html .= '</div>';
                    $html .= '<div class="p-items position-'.$position_type.'">';
                        foreach($porfolio_array->posts as $item) {
                            $thumb = get_post_meta( $item->ID, '_thumbnail_id', true );
                            $image = wp_get_attachment_image_src( $thumb , 'large' )[0];

                            $html .= '<div class="p-item">';
                                $html .= '<a href="'.get_permalink($item->ID).'" style="background-image: url('.$image.')"></a>';
                            $html .= '</div>';
                        }
                    $html .= '</div>';
                $html .= '</div>';
            $html .= '</div>';
        }

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Portfolio_By_Category();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Portfolio_By_Category extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Portfolio_By_Category_Item extends WPBakeryShortCode {
    }
}

