<?php

// Element Description: PT Portfolio Categories

class PT_Portfolio_Categories extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_portfolio_categories_mapping' ) );
        add_shortcode( 'pt_portfolio_categories', array( $this, 'pt_portfolio_categories_html' ) );
        add_shortcode( 'pt_portfolio_categories_item', array( $this, 'pt_portfolio_categories_item_html' ) );
    }

    public static function get_all_portfolio_category() {
        $taxonomy = 'pt-portfolio-category';
        $args     = array(
            'hide_empty' => true,
        );

        $terms     = get_terms( $taxonomy, $args );
        $result    = array();
        $result[0] = esc_html__('Select', 'lauv');

        if ( ! empty( $terms ) && !is_wp_error( $terms ) ) {
            foreach ( $terms as $term ) {
                $name = $term->name;
                $result[ 'ID ['.$term->term_id.'] '.$name ] = 'items'.$term->term_id;
            }
        }

        return $result;
    }
     
    // Element Mapping
    public function pt_portfolio_categories_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Portfolio Categories", "lauv"),
            "base" => "pt_portfolio_categories",
            "as_parent" => array('only' => 'pt_portfolio_categories_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "is_container" => true,
            "icon" => "shortcode-icon-portfolio",
            "category" => esc_html__("By PT", "lauv"),
            "params" => array(
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Social buttons", "lauv" ),
                    "param_name" => "social_buttons",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "on"    => esc_html__("On", "lauv"),
                            "off"   => esc_html__("Off", "lauv"),
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Contacts text", "lauv"),
                    "param_name" => "contacts",
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Copyright text", "lauv"),
                    "param_name" => "copyright",
                ),
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Custom link 1", "lauv"),
                    "param_name" => "custom_link1",
                ),
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Custom link 2", "lauv"),
                    "param_name" => "custom_link2",
                ),
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Custom link 3", "lauv"),
                    "param_name" => "custom_link3",
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );

        $item_array = array(
            "name" => esc_html__("Banner item", "lauv"),
            "base" => "pt_portfolio_categories_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-portfolio",
            "as_child" => array('only' => 'pt_portfolio_categories'),
            "params" => array(
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Custom link \"All projects\"", "lauv"),
                    "param_name" => "custom_link",
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Category", "lauv" ),
                    "param_name"  => "categories_portfolio_items",
                    "admin_label" => true,
                    "value"       => PT_Portfolio_Categories::get_all_portfolio_category(),
                ),
            )
        );

        $taxonomy = 'pt-portfolio-category';
        $args     = array(
            'hide_empty' => true,
        );

        $terms     = get_terms( $taxonomy, $args );
        $result_array = '';

        if ( ! empty( $terms ) && !is_wp_error( $terms ) ) {
            foreach ( $terms as $term ) {
                $result    = array();

                $tax_query = array(
                    array(
                        'taxonomy' => 'pt-portfolio-category',
                        'field'    => 'id',
                        'terms'    => $term->term_id
                    )
                );

                $args = array(
                    'posts_per_page'  => '100000',
                    'post_type'       => 'pt-portfolio',
                    'post_status'     => 'publish',
                    'tax_query'       => $tax_query
                );

                $porfolio_array = new WP_Query( $args );

                foreach ($porfolio_array->posts as $item) {
                    $result[ 'ID ['.$item->ID.'] '.$item->post_title ] = $item->ID;
                }

                $item_array['params'][] = array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Items", "lauv" ),
                    "param_name"  => "items".$term->term_id,
                    "dependency"  => Array( "element" => "categories_portfolio_items", "value" => array( 'items'.$term->term_id ) ),
                    "value"       => $result,
                );
            }
        }

        vc_map( $item_array );
    }
     
     
    // Element HTML
    public function pt_portfolio_categories_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'social_buttons' => 'on',
                    'contacts' => '',
                    'copyright' => '',
                    'custom_link1' => '',
                    'custom_link2' => '',
                    'custom_link3' => '',
                ), 
                $atts
            )
        );

        $html = '';

        $portfolio_area_class = $id = 'portfolio-'.$uniq_id;

        if(isset(vc_build_link($custom_link1)['url']) && !empty(vc_build_link($custom_link1)['url'])) {
            $custom_link1_url = vc_build_link($custom_link1)['url'];
            $custom_link1 = vc_build_link($custom_link1);

            if(empty($custom_link1['target'])) {
                $custom_link1['target'] = '_self';
            }
        } else {
            $custom_link1_url = '';
        }

        if(isset(vc_build_link($custom_link2)['url']) && !empty(vc_build_link($custom_link2)['url'])) {
            $custom_link2_url = vc_build_link($custom_link2)['url'];
            $custom_link2 = vc_build_link($custom_link2);

            if(empty($custom_link2['target'])) {
                $custom_link2['target'] = '_self';
            }
        } else {
            $custom_link2_url = '';
        }

        if(isset(vc_build_link($custom_link3)['url']) && !empty(vc_build_link($custom_link3)['url'])) {
            $custom_link3_url = vc_build_link($custom_link3)['url'];
            $custom_link3 = vc_build_link($custom_link3);

            if(empty($custom_link3['target'])) {
                $custom_link3['target'] = '_self';
            }
        } else {
            $custom_link3_url = '';
        }

        $html = '<div class="portfolio-categories">';
            if($social_buttons == 'on' && !empty(lauv_styles()['social_buttons_content'])) {
                $html .= '<div class="social-buttons-text"><div><div class="h">'.esc_html__('follow me', 'lauv').'</div>'.lauv_styles()['social_buttons_content'].'</div></div>';
            }
            $html .= '<div class="container">';
                $html .= '<div class="left-side">';
                    $html .= '<div class="items">';
                        $html .= do_shortcode($content);
                    $html .= '</div>';
                $html .= '</div>';
                $html .= '<div class="right-side">';
                    $html .= '<div class="wrap">';
                        $html .= '<div class="categories-links">';
                            $html .= '<a href="#" class="h-link">'.esc_html__('all projects', 'lauv').'</a>';
                            $html .= '<ul></ul>';
                        $html .= '</div>';
                        if(!empty($custom_link1_url) || !empty($custom_link2_url) || !empty($custom_link3_url)) {
                            $html .= '<ul class="custom-links">';
                                if(!empty($custom_link1_url)) {
                                    $html .= '<li><a href="'.esc_url($custom_link1_url).'" target="'.$custom_link1['target'].'">'.$custom_link1['title'].'</a></li>';
                                }
                                if(!empty($custom_link2_url)) {
                                    $html .= '<li><a href="'.esc_url($custom_link2_url).'" target="'.$custom_link2['target'].'">'.$custom_link2['title'].'</a></li>';
                                }
                                if(!empty($custom_link3_url)) {
                                    $html .= '<li><a href="'.esc_url($custom_link3_url).'" target="'.$custom_link3['target'].'">'.$custom_link3['title'].'</a></li>';
                                }
                            $html .= '</ul>';
                        }
                    $html .= '</div>';
                    if(!empty($contacts) || !empty($copyright)) {
                        $html .= '<div class="bottom">';
                            if(!empty($contacts)) {
                                $html .= '<div class="contacts">'.wp_kses_post($contacts).'</div>';
                            }
                            if(!empty($copyright)) {
                                $html .= '<div class="copyright">'.wp_kses_post($copyright).'</div>';
                            }
                        $html .= '</div>';
                    }
                $html .= '</div>';
            $html .= '</div>';
        $html .= '</div>';

        return $html;
         
    }

    // Element HTML
    public function pt_portfolio_categories_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'custom_link' => '',
                    'categories_portfolio_items' => '',
                ), 
                $atts
            )
        );
         
        // Fill $html var with data
        $item_attr = $custom_css = $html = '';

        $item_class = $id = "portfolio-item-".uniqid();

        if(!empty($categories_portfolio_items)) {
            $category_id = str_replace('items', '', $categories_portfolio_items);
            $category = get_term($category_id, 'pt-portfolio-category', 'ARRAY_A');
            $items_id = $atts[$categories_portfolio_items];
            $tax_query = array();

            if($items_id) {
                $items_id = explode(',', $items_id);
            } else {
                $items_id = '';

                $tax_query = array(
                    array(
                        'taxonomy' => 'pt-portfolio-category',
                        'field'    => 'id',
                        'terms'    => $category_id
                    )
                );
            }

            

            $args = array(
                'post__in'        => $items_id,
                'posts_per_page'  => '100000',
                'post_type'       => 'pt-portfolio',
                'post_status'     => 'publish',
                'orderby'         => 'post__in',
                'tax_query'       => $tax_query
            );

            $porfolio_array = new WP_Query( $args );

            if(isset(vc_build_link($custom_link)['url']) && !empty(vc_build_link($custom_link)['url'])) {
                $custom_link = vc_build_link('custom_link')['url'];
            } else {
                $custom_link = get_term_link($category['term_id']);
            }
            $name = str_split($category['name'],3);
            $name = implode('<br>', $name);

            $html = '<div class="item" data-name="'.$category['name'].'" data-custom-link="'.$custom_link.'">';
                $html .= '<div class="cat-h">'.$name.'</div>';
                $html .= '<div class="wrap">';
                    $html .= '<div class="p-items">';
                        foreach($porfolio_array->posts as $item) {
                            $thumb = get_post_meta( $item->ID, '_thumbnail_id', true );
                            $image = wp_get_attachment_image( $thumb , 'large' );

                            $html .= '<div class="p-item"><a href="'.esc_url(get_permalink($item->ID)).'">'.$image.'</a></div>';
                        }
                    $html .= '</div>';
                $html .= '</div>';
            $html .= '</div>';
        }

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Portfolio_Categories();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Portfolio_Categories extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Portfolio_Categories_Item extends WPBakeryShortCode {
    }
}

