<?php

// Element Description: PT Portfolio

class PT_Portfolio_Items extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_portfolio_mapping' ) );
        add_shortcode( 'pt_portfolio', array( $this, 'pt_portfolio_html' ) );
    }

    public static function get_all_portfolio_category() {
        $taxonomy = 'pt-portfolio-category';
        $args     = array(
            'hide_empty' => true,
        );

        $terms     = get_terms( $taxonomy, $args );
        $result    = array();
        $result[0] = "";

        if ( ! empty( $terms ) && !is_wp_error( $terms ) ) {
            foreach ( $terms as $term ) {
                if(get_category_parents($term->term_id)) {
                    $name = get_category_parents($term->term_id);
                } else {
                    $name = $term->name;
                }
                $name = trim($name, '/');
                $result[ 'ID ['.$term->term_id.'] '.$name ] = $term->term_id;
            }
        }

        return $result;
    }

    public static function get_all_portfolio_items( $param = 'All' ) {
        $result    = array();
        
        $args = array(
            'post_type'       => 'pt-portfolio',
            'post_status'     => 'publish',
            'posts_per_page'    => '10000'
        );

        $porfolio_array = new WP_Query( $args );
        $result[0] = "";

        if ( ! empty( $porfolio_array->posts ) ) {
            foreach ( $porfolio_array->posts as $item ) {
                $result[ 'ID ['.$item->ID.'] '. $item->post_title ] = $item->ID;
            }
        }

        return $result;
    }
     
    // Element Mapping
    public function pt_portfolio_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Portfolio", "lauv"),
            "base" => "pt_portfolio",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-portfolio",
            "is_container" => true,
            "category" => esc_html__("By PT", "lauv"),
            "params" => array(
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__( "Uniq ID", "lauv" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Count items", "lauv" ),
                    "param_name"  => "count_items",
                    "value"       => '9',
                    "admin_label" => true,
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Type", "lauv" ),
                    "param_name"  => "type",
                    "admin_label" => true,
                    "value"      => array(
                        esc_html__( "Grid", "lauv" ) => "grid",
                        esc_html__( "Masonry", "lauv" ) => "masonry",
                        esc_html__( "Packery", "lauv" ) => "packery",
                        esc_html__( "Justified", "lauv" ) => "justified",
                    ),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Hover effect", "lauv" ),
                    "param_name"  => "hover_effect",
                    "admin_label" => true,
                    "value"      => array(
                        esc_html__( "Hover 1", "lauv" ) => "style1",
                        esc_html__( "Hover 2", "lauv" ) => "style2",
                        esc_html__( "Hover 3", "lauv" ) => "style3",
                        esc_html__( "Hover 4", "lauv" ) => "style4",
                        esc_html__( "Hover 5", "lauv" ) => "style5",
                        esc_html__( "Hover 6", "lauv" ) => "style6",
                    ),
                    //"dependency"  => Array( "element" => "type", "value" => array( "grid", "masonry", "packery" ) ),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums", "lauv" ),
                    "param_name"  => "cols",
                    "admin_label" => true,
                    "value"      => array(
                        esc_html__( "Col 1", "lauv" ) => "1",
                        esc_html__( "Col 2", "lauv" ) => "2",
                        esc_html__( "Col 3", "lauv" ) => "3",
                        esc_html__( "Col 4", "lauv" ) => "4",
                    ),
                    "std" => '3',
                    "dependency"  => Array( "element" => "type", "value" => array( "grid", "masonry", "packery" ) ),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Gap", "lauv" ),
                    "param_name"  => "gap",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency"  => "",
                    "default_set" => true,
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Filter buttons", "lauv" ),
                    "param_name"  => "filter_buttons",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "dependency"  => Array( "element" => "type", "value" => array( "grid", "masonry", "packery" ) ),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Filter buttons align", "lauv" ),
                    "param_name"  => "filter_buttons_align",
                    "dependency"  => Array( "element" => "filter_buttons", "value" => array( "on" ) ),
                    "value"      => array(
                        esc_html__('Left', 'lauv') => 'tal',
                        esc_html__('Center', 'lauv') => 'tac',
                        esc_html__('Right', 'lauv') => 'tar',
                    ),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Navigation", "lauv" ),
                    "param_name"  => "navigation",
                    "value"      => array(
                        esc_html__( "None", "lauv" ) => "none",
                        esc_html__( "Load More", "lauv" ) => "load_more",
                        esc_html__( "Pagination", "lauv" ) => "pagination",
                    ),
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Popup mode", "lauv" ),
                    "param_name"  => "popup_mode",
                    "value"       => "on",
                    "admin_label" => true,
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "General", "lauv" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Heading", "lauv" ),
                    "param_name"  => "show_heading",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "lauv" ),
                            "off"   => esc_html__( "Off", "lauv" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order by", "lauv" ),
                    "param_name"  => "orderby",
                    "value"      => array(
                        esc_html__('Default', 'lauv') => 'post__in',
                        esc_html__('Author', 'lauv') => 'author',
                        esc_html__('Date', 'lauv') => 'date',
                        esc_html__('ID', 'lauv') => 'ID',
                        esc_html__('Title', 'lauv') => 'title',
                    ),
                    "group"       => esc_html__( "Sorting", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order", "lauv" ),
                    "param_name"  => "order",
                    "value"      => array(
                        esc_html__('Ascending order', 'lauv') => 'ASC',
                        esc_html__('Descending order', 'lauv') => 'DESC',
                    ),
                    "group"       => esc_html__( "Sorting", "lauv" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Source", "lauv" ),
                    "param_name"  => "source",
                    "value"      => array(
                        esc_html__( "---", "lauv" ) => "",
                        esc_html__( "Items", "lauv" ) => "items",
                        esc_html__( "Categories", "lauv" ) => "categories",
                    ),
                    "group"       => esc_html__( "Source", "lauv" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Items", "lauv" ),
                    "param_name"  => "items",
                    "dependency"  => Array( "element" => "source", "value" => array( "items" ) ),
                    "value"       => PT_Portfolio_Items::get_all_portfolio_items(),
                    "group"       => esc_html__( "Source", "lauv" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Category", "lauv" ),
                    "param_name"  => "categories",
                    "dependency"  => Array( "element" => "source", "value" => array( "categories" ) ),
                    "value"       => PT_Portfolio_Items::get_all_portfolio_category(),
                    "group"       => esc_html__( "Source", "lauv" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "lauv" ),
                    "param_name" => "animation",
                    "group"       => esc_html__( "General", "lauv" ),
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_portfolio_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'count_items' => '9', 
                    'type' => 'grid',
                    'gap' => 'on',
                    'cols' => '3',
                    'popup_mode' => 'on',
                    'hover_effect' => 'style1',
                    'filter_buttons' => 'on',
                    'filter_buttons_align' => 'tal',
                    'navigation' => 'none',
                    'show_heading' => 'on',
                    'orderby' => 'post__in',
                    'order' => 'ASC',
                    'source' => '',
                    'items' => '',
                    'categories' => '',
                    'source' => '',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $animation = $this->getCSSAnimation($animation);

        $wrap_id = 'portfolio-'.$uniq_id;

        if(is_front_page()) {
            $paged = (get_query_var('page')) ? get_query_var('page') : 1;
        } else {
            $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        }

        $tax_query = array();

        $categories_s = '';
        if ( !empty($categories) && $categories != '0' ) {
            $categories_s = explode(',', $categories);
            $tax_query = array(
                array(
                    'taxonomy' => 'pt-portfolio-category',
                    'field'    => 'id',
                    'terms'    => $categories_s
                )
            );
        }
        if($items) {
            $items = explode(',', $items);
        } else {
            $items = '';
        }
        $args = array(
            'post__in'        => $items,
            'posts_per_page'  => $count_items,
            'paged'           => $paged,
            'orderby'         => $orderby,
            'order'           => $order,
            'post_type'       => 'pt-portfolio',
            'post_status'     => 'publish',
            'tax_query'       => $tax_query
        );

        $porfolio_array = new WP_Query( $args );

        $item_num = $max_num_pages = 0;
        $max_num_pages = $porfolio_array->max_num_pages;

        $html = $wrap_classes = $custom_css = "";

        switch ($cols) {
            case '1':
                $item_col = "col-xs-12";
                break;
            case '2':
                $item_col = "col-xs-12 col-sm-6 col-md-6";
                $mobile_cols = "1";
                $tablet_cols = "2";
                $desktop_cols = "2";
                break;
            case '3':
                $item_col = "col-xs-12 col-sm-4 col-md-4";
                $mobile_cols = "1";
                $tablet_cols = "2";
                $desktop_cols = "3";
                break;
            case '4':
                $item_col = "col-xs-12 col-sm-4 col-md-3";
                $mobile_cols = "1";
                $tablet_cols = "2";
                $desktop_cols = "4";
                break;
            
            default:
                $item_col = "";
                break;
        }

        $category_array = array();
        if($items) {
            $i = 0;
            while ( $porfolio_array->have_posts() ) : $porfolio_array->the_post();
                $id = get_the_ID();
                $category_array[$i] = array();
                foreach (wp_get_post_terms( $id, 'pt-portfolio-category') as $key2 => $s_item) {
                    $category_array[$i][$key2] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
                $i++;
            endwhile;

            $arrOut = array();
            foreach($category_array as $subArr){
                $arrOut = array_merge($arrOut,$subArr);
            }

            $category_array = array_map( 'unserialize', array_unique( array_map( 'serialize', $arrOut)));
        } else if(is_array($categories_s) && count($categories_s) > 0) {
            $args     = array(
                'hide_empty' => true,
                'include' => $categories_s
            );
            $taxonomy = 'pt-portfolio-category';
            $terms     = get_terms( $taxonomy, $args );
            if(!empty($terms) && !is_wp_error( $terms )) {
                foreach($terms as $s_item) { 
                    $category_array[] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
            }
        } else {
            $args     = array(
                'hide_empty' => true,
            );
            $taxonomy = 'pt-portfolio-category';
            $terms     = get_terms( $taxonomy, $args );
            if(!empty($terms)) {
                foreach($terms as $s_item) { 
                    $category_array[] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
            }
        }

        if($popup_mode == 'on') {
            $wrap_classes .= 'popup-gallery';
        }

        wp_enqueue_style('lauv-custom-style', get_template_directory_uri() . '/css/custom_script.css');
        wp_add_inline_style( 'lauv-custom-style', $custom_css );

        $html = "";

        if($type == 'justified') {
            wp_enqueue_script( 'justifiedGallery', get_template_directory_uri() . '/js/jquery.justifiedGallery.js', array('jquery'), true );

            $wrap_classes .= ' disable-iso';
            $filter_buttons = 'off';
        }

        if(empty($gap)) {
            $gap = 'on';
        }

        if(is_array($porfolio_array->posts) && count($porfolio_array->posts) > 0) {
            if(is_array($category_array) && $filter_buttons == "on" && count($category_array) > 1) {
                $html .= '<div class="filter-button-group '.esc_attr($filter_buttons_align).'">';
                    $html .= '<div class="wrap">';
                        $html .= '<button data-filter="*" class="active">'.esc_html__('All', 'lauv').'</button>';
                        foreach($category_array as $item) { 
                            $name = $item["name"];
                            $slug = $item["slug"];
                            $html .= '<button data-filter=".category-'.esc_attr($slug).'">'.esc_html($name).'</button>';
                        }
                    $html .= '</div>';
                $html .= '</div>';
            }
            $html .= '<div class="portfolio-items row portfolio-type-'.$type.' gap-'.$gap.' cols-'.$cols.' hover-'.$hover_effect.' '.$wrap_id.' '.$wrap_classes.'">';
                while ( $porfolio_array->have_posts() ) : $porfolio_array->the_post();
                    $id = get_the_ID();
                    $item = get_post($id);
                    $item_num++;
                    $name = $item->post_title;
                    $item_class = "";
                    if(is_array(wp_get_post_terms( $id, 'pt-portfolio-category'))) {
                        for ($i=0; $i < count(wp_get_post_terms( $id, 'pt-portfolio-category')); $i++) { 
                            $item_class .= 'category-'.wp_get_post_terms( $id, 'pt-portfolio-category')[$i]->slug.' ';
                        }
                        $item_class = trim($item_class, ' ');
                    }

                    $thumb = get_post_meta( $id, '_thumbnail_id', true );
                    $image = wp_get_attachment_image_src( $thumb , 'large' );

                    if($popup_mode == 'off') {
                        $link = get_permalink($id);
                    } else {
                        $link = $image[0];
                    }

                    if($paged > 1) {
                        $num = $item_num+$paged*$count_items-$count_items;
                    } else {
                        $num = $item_num;
                    }

                    $num = str_pad($num, 2, '0', STR_PAD_LEFT);

                    $html .= '<article class="portfolio-item '.esc_attr($item_class.' '.$item_col).'">';
                        $html .= '<div class="wrap '.esc_attr($animation).'">';
                            if($type == 'grid' || $type == 'packery') {
                                $html .= '<div class="a-img"><div style="background-image: url('.esc_url($image[0]).');"></div></div>';
                            } else if($type == 'masonry' || $type == 'justified') {
                                $html .= '<div class="a-img"><img width="'.esc_attr($image[1]).'" height="'.esc_attr($image[2]).'" src="'.esc_url($image[0]).'" alt="'.esc_html($name).'"></div>';
                            }
                            if($show_heading == 'on') {
                                $html .= '<h6><span class="cell"><span>'.esc_html($name).'</span></span></h6>';
                            }
                        $html .= '</div>';
                        if($hover_effect == 'style4') {
                            $html .= '<a href="'.esc_url($link).'" data-size="'.esc_attr($image[1].'x'.$image[2]).'"><span></span></a>';
                        } else {
                            $html .= '<a href="'.esc_url($link).'" data-size="'.esc_attr($image[1].'x'.$image[2]).'"></a>';
                        }
                    $html .= '</article>';
                endwhile;
                wp_reset_postdata();
            $html .= '</div>';
        }

        if($navigation == "pagination") {
            if (function_exists('lauv_wp_corenavi')) {
                $html .= lauv_wp_corenavi($max_num_pages);
            } else {
                $html .= wp_link_pages();
            };
        }
        if(is_array($porfolio_array->posts) && $navigation == "load_more" && $max_num_pages > 1) {
            $html .= '<div class="load-button tac"><a href="#" data-wrap=".'.esc_attr($wrap_id).'" data-max="'.esc_attr($max_num_pages).'" data-start-page="'.esc_attr($paged).'" data-next-link="'.esc_url(next_posts($max_num_pages, false)).'" class="button-style1"><span>'.esc_html('Load more', 'lauv').'</span></a></div>';
        }

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Portfolio_Items();