<?php

// Element Description: PT Testimonials

class PT_Testimonials extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_testimonials_mapping' ) );
        add_shortcode( 'pt_testimonials', array( $this, 'pt_testimonials_html' ) );
        add_shortcode( 'pt_testimonials_item', array( $this, 'pt_testimonials_item_html' ) );
    }
     
    // Element Mapping
    public function pt_testimonials_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Testimonials", "lauv"),
            "base" => "pt_testimonials",
            "as_parent" => array('only' => 'pt_testimonials_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-testimonials",
            "is_container" => true,
            "category" => esc_html__("By PT", "lauv"),
            "params" => array(
                array(
                    "type"        => "el_id",
                    "heading"     => esc_html__( "Uniq ID", "lauv" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                ),
                array(
                    "type"        => "number",
                    "class"       => "",
                    "heading"     => esc_html__( "Transition speed", "lauv" ),
                    "param_name"  => "speed",
                    "value"       => "300",
                    "min"         => "100",
                    "max"         => "10000",
                    "step"        => "100",
                    "suffix"      => "ms",
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Autoplay Slides", "lauv" ),
                    "param_name"  => "autoplay",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Enable Autoplay", "lauv" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency"  => "",
                    "default_set" => true,
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Pagination dots", "lauv" ),
                    "param_name"  => "dots",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency"  => "",
                    "default_set" => true,
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Autoplay Speed", "lauv" ),
                    "param_name" => "autoplay_speed",
                    "value"      => "5000",
                    "min"        => "100",
                    "max"        => "10000",
                    "step"       => "10",
                    "suffix"     => "ms",
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Pause on hover", "lauv" ),
                    "param_name" => "pauseohover",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "label" => esc_html__( "Pause the slider on hover", "lauv" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency" => Array("element" => "autoplay", "value" => "on" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "lauv" ),
                    "param_name" => "animation",
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Testimonials item", "lauv"),
            "base" => "pt_testimonials_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-testimonials",
            "as_child" => array('only' => 'pt_testimonials'),
            "params" => array(
                array(
                    "type"        => "el_id",
                    "heading"     => esc_html__( "Uniq ID", "lauv" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Name", "lauv"),
                    "param_name" => "name",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Post", "lauv"),
                    "param_name" => "post",
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Text", "lauv"),
                    "param_name" => "text",
                ),
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Subscribe image", "lauv"),
                    "param_name" => "subscribe_image",
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_testimonials_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'speed' => '500',
                    'dots' => 'on',
                    'autoplay' => 'on',
                    'autoplay_speed' => '3000',
                    'pauseohover' => 'on',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $id = 'testimonials-'.$uniq_id;

        $animation = $this->getCSSAnimation($animation);

        $category_class = $id;

        $html = "";

        // Fill $html var with data
        $custom_css = "";

        wp_enqueue_style('lauv-custom-style', get_template_directory_uri() . '/css/custom_script.css');
        wp_add_inline_style( 'lauv-custom-style', $custom_css );

        
        if($autoplay == 'on') {
            $autoplay = 'true';
        } else {
            $autoplay = 'false';
        }
        if($pauseohover == 'on') {
            $pauseohover = 'true';
        } else {
            $pauseohover = 'false';
        }
        if($dots == 'on') {
            $dots = 'true';
        } else {
            $dots = 'false';
        }

        wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
        wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery') );
        wp_enqueue_script( 'lauv-script', get_template_directory_uri() . '/js/script.js' );

        wp_add_inline_script('lauv-script', "jQuery(document).ready(function(jQuery) {
            jQuery('.".esc_attr($id)."').each(function(){
                var head_slider = jQuery(this);
                if(jQuery(this).find('.testimonial-item').length > 1){
                    head_slider.addClass('owl-carousel').owlCarousel({
                        loop:true,
                        items:1,
                        nav: false,
                        dots: ".esc_js($dots).",
                        autoplay: ".esc_js($autoplay).",
                        autoplayTimeout: ".esc_js($autoplay_speed).",
                        autoplayHoverPause: ".esc_js($pauseohover).",
                        smartSpeed: ".esc_js($speed).",
                        navText: false,
                    });
                }
            });
        });");

        $html = '<div class="testimonials row '.esc_attr($category_class).' '.esc_attr($animation).'">';
            $html .= do_shortcode($content);
        $html .= '</div>';
         
        return $html;
         
    }

    // Element HTML
    public function pt_testimonials_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'name' => '',
                    'post' => '',
                    'text' => '',
                    'subscribe_image' => ''
                ), 
                $atts
            )
        );
        
        // Fill $html var with data

        $html = $subscribe_html = "";

        if(isset(wp_get_attachment_image_src($subscribe_image, 'large')[0])) {
            $subscribe_html = '<div class="subscribe">'.wp_get_attachment_image($subscribe_image, 'large').'</div>';
        }

        $html .= '<div class="testimonial-item">';
            if(!empty($text)) {
                $html .= '<blockquote class="quote">'.wp_kses_post($text).'</blockquote>';
            }
            if(!empty($post) || !empty($name) || !empty($subscribe_html)) {
                $html .= '<div class="bottom">';
                    if(!empty($name)) {
                        $html .= '<h5>'.wp_kses_post($name).'</h5>';
                    }
                    if(!empty($post)) {
                        $html .= '<div class="post">'.wp_kses_post($post).'</div>';
                    }
                    $html .= $subscribe_html;
                $html .= '</div>';
            }
        $html .= '</div>';

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Testimonials();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Testimonials extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Testimonials_Item extends WPBakeryShortCode {
    }
}

