<?php

// Element Description: PT Time Line

class PT_Time_Line extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_time_line_mapping' ) );
        add_shortcode( 'pt_time_line', array( $this, 'pt_time_line_html' ) );
        add_shortcode( 'pt_time_line_item', array( $this, 'pt_time_line_item_html' ) );
    }
     
    // Element Mapping
    public function pt_time_line_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Time Line", "lauv"),
            "base" => "pt_time_line",
            "as_parent" => array('only' => 'pt_time_line_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-icon-box",
            "is_container" => true,
            "category" => esc_html__("By PT", "lauv"),
            "params" => array(
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Carousel", "lauv" ),
                    "param_name"  => "carousel",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency"  => "",
                    "default_set" => true,
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Desktop", "lauv" ),
                    "param_name"  => "desktop_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "lauv" ) => "1",
                        esc_html__( "Col 2", "lauv" ) => "2",
                        esc_html__( "Col 3", "lauv" ) => "3",
                        esc_html__( "Col 4", "lauv" ) => "4",
                    ),
                    "std" => '4',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Tablet", "lauv" ),
                    "param_name"  => "tablet_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "lauv" ) => "1",
                        esc_html__( "Col 2", "lauv" ) => "2",
                        esc_html__( "Col 3", "lauv" ) => "3",
                        esc_html__( "Col 4", "lauv" ) => "4",
                    ),
                    "std" => '2',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Mobile", "lauv" ),
                    "param_name"  => "mobile_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "lauv" ) => "1",
                        esc_html__( "Col 2", "lauv" ) => "2",
                        esc_html__( "Col 3", "lauv" ) => "3",
                        esc_html__( "Col 4", "lauv" ) => "4",
                    ),
                    "std" => '1',
                ),
                array(
                    "type"        => "number",
                    "class"       => "",
                    "heading"     => esc_html__( "Transition speed", "lauv" ),
                    "param_name"  => "speed",
                    "value"       => "300",
                    "min"         => "100",
                    "max"         => "10000",
                    "step"        => "100",
                    "suffix"      => "ms",
                    "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Autoplay Slides", "lauv" ),
                    "param_name"  => "autoplay",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Enable Autoplay", "lauv" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                    "default_set" => true,
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Navigation arrows", "lauv" ),
                    "param_name"  => "nav",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                    "default_set" => true,
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Autoplay Speed", "lauv" ),
                    "param_name" => "autoplay_speed",
                    "value"      => "5000",
                    "min"        => "100",
                    "max"        => "10000",
                    "step"       => "10",
                    "suffix"     => "ms",
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Pause on hover", "lauv" ),
                    "param_name" => "pauseohover",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "label" => esc_html__( "Pause the slider on hover", "lauv" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency" => Array("element" => "autoplay", "value" => "on" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "lauv" ),
                    "param_name" => "animation",
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Time Line item", "lauv"),
            "base" => "pt_time_line_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-icon-box",
            "as_child" => array('only' => 'pt_time_line'),
            "params" => array(
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Date", "lauv"),
                    "param_name" => "date",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Description", "lauv"),
                    "param_name" => "desc",
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "lauv" ),
                    "param_name" => "animation",
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_time_line_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'carousel' => 'on',
                    'desktop_cols' => '4',
					'tablet_cols' => '2',
					'mobile_cols' => '1',
                    'speed' => '500',
                    'nav' => 'on',
                    'autoplay' => 'on',
                    'autoplay_speed' => '3000',
                    'pauseohover' => 'on',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $html = $classes = "";

        $classes = $id = 'time-line-'.$uniq_id;

        $animation = $this->getCSSAnimation($animation);

        if($carousel == 'on') {
            if($autoplay == 'on') {
                $autoplay = 'true';
            } else {
                $autoplay = 'false';
            }
            if($pauseohover == 'on') {
                $pauseohover = 'true';
            } else {
                $pauseohover = 'false';
            }
            if($nav == 'on') {
                $nav = 'true';
            } else {
                $nav = 'false';
            }

            wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
            wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery') );
            wp_enqueue_script( 'lauv-script', get_template_directory_uri() . '/js/script.js' );

            wp_add_inline_script('lauv-script', "jQuery(document).ready(function(jQuery) {
                jQuery('.".esc_attr($id)."').each(function(){
                    var head_slider = jQuery(this);
                    if(jQuery(this).find('.time-line-item').length > 1){
                        head_slider.addClass('owl-carousel').owlCarousel({
                            loop:true,
                            items:1,
                            nav: ".esc_js($nav).",
                            dots: false,
                            autoplay: ".esc_js($autoplay).",
                            autoplayTimeout: ".esc_js($autoplay_speed).",
                            autoplayHoverPause: ".esc_js($pauseohover).",
                            smartSpeed: ".esc_js($speed).",
                            navClass: ['owl-prev base-icons-prev','owl-next base-icons-next'],
                            navText: false,
                            margin: 55,
                            responsive:{
                                0:{
                                    items:1
                                },
                                440:{
                                    items: ".esc_js($mobile_cols)."
                                },
                                992:{
                                    items: ".esc_js($tablet_cols)."
                                },
                                1200:{
                                    items: ".esc_js($desktop_cols)."
                                }
                            }
                        });
                    }
                });
            });");
        }

        // Fill $html var with data
        if(!empty($content)) {
            $content = str_replace('[pt_time_line_item ', '[pt_time_line_item carousel="'.$carousel.'" desktop_cols="'.$desktop_cols.'" tablet_cols="'.$tablet_cols.'" mobile_cols="'.$mobile_cols.'" ', $content);
        }

        $html = '<div class="time-line-items row '.esc_attr($classes).' '.esc_attr($animation).'">';
            $html .= do_shortcode($content);
        $html .= '</div>';
         
        return $html;
         
    }

    // Element HTML
    public function pt_time_line_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'carousel' => 'on',
                    'desktop_cols' => '4',
					'tablet_cols' => '2',
					'mobile_cols' => '1',
                    'date' => '',
                    'desc' => '',
                    'animation' => ''
                ), 
                $atts
            )
        );
        
        // Fill $html var with data

        $html = $custom_css = "";

        $animation = $this->getCSSAnimation($animation);

        $item_css = $item_id = uniqid('time-line-item-');

        if($carousel != 'on') {
            $item_css = 'col-xs-'.esc_attr(12/$mobile_cols).' col-sm-'.esc_attr(12/$tablet_cols).' col-md-'.esc_attr(12/$desktop_cols).' '.esc_attr($animation);
        }

        $html .= '<div class="time-line-item '.esc_attr($item_css).'">';
            if(!empty($date)) {
                $html .= '<div class="date">'.wp_kses_post($date).'</div>';
            }
            if(!empty($desc)) {
                $html .= '<div class="desc">'.wp_kses_post($desc).'</div>';
            }
        $html .= '</div>';
        
        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Time_Line();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Time_Line extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Time_Line_Item extends WPBakeryShortCode {
    }
}
